<?php
/**
 * FavBlog Pro: Color Patterns
 *
 * @package WordPress
 * @subpackage FavBlog Pro
 * @since 1.0
 */

/**
 * Generate the CSS for the current custom color scheme.
 */
function favblog_pro_custom_colors_css() {
  	$options= favblog_pro_get_theme_options();

	$color_value = $options['colorscheme_hue'];
	
	$css = '
	/*--------------------------------------------------------------
	# Background Color
	--------------------------------------------------------------*/
	.backtotop,
	.main-navigation .count,
	.pagination .page-numbers.current,
	.pagination .page-numbers:hover,
	.pagination .page-numbers:focus,
	input[type="submit"],
	.author-name:after,
	.reply a,
	.btn,
	.slick-prev, 
	.slick-next,
	.slick-dots li.slick-active button,
	#subscribe-now button[type="submit"],
	.widget_instagram button[type="submit"],
	.single-wrapper .entry-meta > span.tags-links a:hover,
	.single-wrapper .entry-meta > span.tags-links a:focus,
	.slick-prev:hover,
	.slick-next:hover,
	.slick-prev:focus,
	.slick-next:focus,
	.slick-dots li.slick-active button,
	#testimonial-section .slick-arrow:hover,
	#testimonial-section .slick-arrow:focus,
	.woocommerce ul.products li.product .onsale,
	.woocommerce span.onsale,
	span.discount-offer,
	.sixth-design #our-services .icon-container a,
	.seventh-design #our-services .icon-container a,
	.eighth-design #our-services .icon-container a {
	    background-color: ' . esc_attr( $color_value ) . ';
	}

	/*--------------------------------------------------------------
	# Text Color
	--------------------------------------------------------------*/
	a,
	.site-title a:hover,
	.site-title a:focus,
	.main-navigation ul.nav-menu li.current-menu-item > a,
	.main-navigation ul.nav-menu li:hover > a,
	.main-navigation ul.nav-menu li:focus > a,
	.main-navigation a:hover,
	.main-navigation a:focus,
	.main-navigation ul.nav-menu > li > a:hover,
	.main-navigation ul.nav-menu > li > a:focus,
	.post-navigation a, 
	.posts-navigation a,
	.navigation.post-navigation a:hover,
	.navigation.posts-navigation a:hover,
	.navigation.post-navigation a:focus,
	.navigation.posts-navigation a:focus,
	#secondary .cat-links a,
	#secondary a:hover,
	#secondary a:focus,
	.page-header small,
	.posted-on a:hover,
	.posted-on a:focus,
	#secondary .posted-on a:hover,
	#secondary .posted-on a:focus,
	.single-wrapper span.tags-links a:hover,
	.single-wrapper span.tags-links a:focus,
	.section-title a:hover,
	.section-title a:focus,
	.entry-title a:hover,
	.entry-title a:focus,
	.admin-profile .admin-name a:hover,
	.admin-profile .admin-name a:focus,
	#subscribe-now .section-subtitle,
	ul.post-categories li a,
	.cat-links a,
	#about-us .section-subtitle,
	.product_meta a:hover,
	.product_meta a:focus,
	.woocommerce div.product p.price, 
	.woocommerce div.product span.price,
	.woocommerce ul.products li.product .price,
	.woocommerce ul.products li.product .price,
	#trending-products .entry-title a:hover,
	#trending-products .entry-title a:focus,
	#trending-products .price,
	#colophon a:hover,
	#colophon a:focus,
	#colophon .site-info a {
		color: ' . esc_attr( $color_value ) . ';
	}

	.loader-container svg,
	.main-navigation ul.nav-menu li:hover > svg,
	.main-navigation ul.nav-menu li:focus > svg,
	.main-navigation li.menu-item-has-children:hover > a > svg,
	.main-navigation li.menu-item-has-children > a:hover > svg,
	.main-navigation li.menu-item-has-children > a:focus > svg,
	.main-navigation ul.nav-menu > li.current-menu-item > a > svg,
	.main-navigation ul.nav-menu > li > a.search:hover svg.icon-search,
	.main-navigation ul.nav-menu > li > a.search:focus svg.icon-search,
	.main-navigation li.search-menu a:hover svg,
	.main-navigation li.search-menu a:focus svg,
	.main-navigation li.search-menu a.search-active svg,
	.navigation.post-navigation a:hover svg,
	.navigation.posts-navigation a:hover svg,
	.navigation.post-navigation a:focus svg,
	.navigation.posts-navigation a:focus svg,
	.widget_search form.search-form button.search-submit:hover svg,
	.widget_search form.search-form button.search-submit:focus svg,
	.single-wrapper span.posted-on svg,
	.single-wrapper span.cat-links svg,
	.loader-container svg {
		fill: ' . esc_attr( $color_value ) . ';
	}

	/*--------------------------------------------------------------
	# Border Color
	--------------------------------------------------------------*/

	.pagination .page-numbers.current,
	.pagination .page-numbers:hover,
	.pagination .page-numbers:focus,
	input[type="submit"],
	.single-wrapper span.tags-links a:hover,
	.single-wrapper span.tags-links a:focus,
	.reply a,
	.btn,
	.slick-prev, 
	.slick-next,
	.slick-dots li button,
	#subscribe-now button[type="submit"],
	.widget_instagram button[type="submit"],
	.single-wrapper .entry-meta > span.tags-links a:hover,
	.single-wrapper .entry-meta > span.tags-links a:focus,
	.slick-prev:hover,
	.slick-next:hover,
	.slick-prev:focus,
	.slick-next:focus,
	.slick-dots li button,
	#testimonial-section .slick-arrow:hover,
	#testimonial-section .slick-arrow:focus {
		border-color: ' . esc_attr( $color_value ) . ';
	}

	/*--------------------------------------------------------------
	# Preloader
	--------------------------------------------------------------*/

	@keyframes preloader {
	    0% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
	    25% {height:30px;transform:translateY(15px);background: ' . esc_attr( $color_value ) . ';}
	    50% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
	    100% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
	}';

	/**
	 * Filters FavBlog Pro custom colors CSS.
	 *
	 * @since FavBlog Pro 1.0.0
	 *
	 * @param string $css        Base theme colors CSS.
	 */
	return apply_filters( 'favblog_pro_custom_colors_css', $css );
}
