<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

if ( ! function_exists( 'favblog_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since FavBlog Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function favblog_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'favblog_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'favblog_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since FavBlog Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function favblog_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'favblog_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'favblog_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since FavBlog Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function favblog_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'favblog_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if secondary nav section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[topbar_section_enable]' )->value() );
}


/*hero_section section*/

/**
 * Check if hero_section section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_hero_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[hero_section_enable]' )->value() );
}

/**
 * Check if hero_section section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_hero_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_hero_content_type' )->value();
	return favblog_pro_is_hero_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if hero_section section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_hero_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_hero_content_type' )->value();
	return favblog_pro_is_hero_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if hero_section section content type is category.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_hero_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_hero_content_type' )->value();
	return favblog_pro_is_hero_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if hero_section section tag options Enable
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_hero_content_tag_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_hero_content_type' )->value();
	return favblog_pro_is_hero_section_enable( $control ) && ( 'page' != $content_type );
}

/**
 * Check if hero_section section background is image.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_hero_section_bg_image_enable( $control ) {
	$background = $control->manager->get_setting( 'favblog_pro_theme_options[style_hero_section_bg_options]' )->value();
	return ( 'image' == $background );
}

/**
 * Check if hero_section section background is color.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_hero_section_bg_color_enable( $control ) {
	$background = $control->manager->get_setting( 'favblog_pro_theme_options[style_hero_section_bg_options]' )->value();
	return favblog_pro_is_hero_section_enable( $control ) && ( 'color' == $background );
}


/*top_read section*/

/**
 * Check if top_read section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_top_read_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[top_read_section_enable]' )->value() );
}

/**
 * Check if top_read section content type is category.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_top_read_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_top_read_content_type' )->value();
	return favblog_pro_is_top_read_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if top_read section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_top_read_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_top_read_content_type' )->value();
	return favblog_pro_is_top_read_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if top_read section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_top_read_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_top_read_content_type' )->value();
	return favblog_pro_is_top_read_section_enable( $control ) && ( 'post' == $content_type );
}


/*featured_post section*/

/**
 * Check if featured_post section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_featured_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[featured_post_section_enable]' )->value() );
}

/**
 * Check if featured_post section content type is category.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_featured_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_featured_post_content_type' )->value();
	return favblog_pro_is_featured_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_post section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_featured_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_featured_post_content_type' )->value();
	return favblog_pro_is_featured_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_post section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_featured_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_featured_post_content_type' )->value();
	return favblog_pro_is_featured_post_section_enable( $control ) && ( 'post' == $content_type );
}

/*popular_post section*/

/**
 * Check if popular_post section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_popular_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[popular_post_section_enable]' )->value() );
}

/**
 * Check if popular_post section content type is category.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_popular_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_popular_post_content_type' )->value();
	return favblog_pro_is_popular_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular_post section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_popular_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_popular_post_content_type' )->value();
	return favblog_pro_is_popular_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_post section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_popular_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_popular_post_content_type' )->value();
	return favblog_pro_is_popular_post_section_enable( $control ) && ( 'post' == $content_type );
}


/*recent_post section*/

/**
 * Check if recent_post section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_recent_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[recent_post_section_enable]' )->value() );
}

/**
 * Check if recent_post section content type is category.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_recent_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_recent_post_content_type' )->value();
	return favblog_pro_is_recent_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if recent_post section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_recent_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_recent_post_content_type' )->value();
	return favblog_pro_is_recent_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent_post section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_recent_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_recent_post_content_type' )->value();
	return favblog_pro_is_recent_post_section_enable( $control ) && ( 'post' == $content_type );
}

/*most_read section*/

/**
 * Check if most_read section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_most_read_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[most_read_section_enable]' )->value() );
}

/**
 * Check if most_read section content type is category.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_most_read_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_most_read_content_type' )->value();
	return favblog_pro_is_most_read_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if most_read section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_most_read_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_most_read_content_type' )->value();
	return favblog_pro_is_most_read_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if most_read section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_most_read_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_most_read_content_type' )->value();
	return favblog_pro_is_most_read_section_enable( $control ) && ( 'post' == $content_type );
}


/**
 * Check if slider section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_slider_content_type' )->value();
	return favblog_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_slider_content_type' )->value();
	return favblog_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is category.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_slider_content_type' )->value();
	return favblog_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if slider separator section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_slider_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'favblog_pro_theme_options_slider_content_type' )->value();
    return favblog_pro_is_slider_section_enable( $control ) && !( 'category' == $content_type );
}
/**
 * Check if about section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_about_content_type' )->value();
	return favblog_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if slider section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_about_content_type' )->value();
	return favblog_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if slider section content type is custom.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_about_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_about_content_type' )->value();
	return favblog_pro_is_about_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if about section content type is custom.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_if_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_about_content_type' )->value();
	return favblog_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_service_content_type' )->value();
	return favblog_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if service section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_service_content_type' )->value();
	return favblog_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if service section content type is category.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_service_content_type' )->value();
	return favblog_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if service separator section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_service_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'favblog_pro_theme_options_service_content_type' )->value();
    return favblog_pro_is_service_section_enable( $control ) && !( 'category' == $content_type );
}
/**
 * Check if service btn url section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_service_section_btn_url_enable( $control ) {
    $content_type = $control->manager->get_setting( 'favblog_pro_theme_options_service_content_type' )->value();
    return favblog_pro_is_service_section_enable( $control ) && !( 'category' == $content_type );
}


/*gallery section*/

/**
 * Check if gallery section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is category.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_gallery_content_type' )->value();
	return favblog_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_gallery_content_type' )->value();
	return favblog_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_gallery_content_type' )->value();
	return favblog_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}



/*gallery_slider section*/

/**
 * Check if gallery_slider section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_gallery_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[gallery_slider_section_enable]' )->value() );
}

/**
 * Check if gallery_slider section content type is category.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_gallery_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_gallery_slider_content_type' )->value();
	return favblog_pro_is_gallery_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery_slider section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_gallery_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_gallery_slider_content_type' )->value();
	return favblog_pro_is_gallery_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery_slider section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_gallery_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_gallery_slider_content_type' )->value();
	return favblog_pro_is_gallery_slider_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if testimonial section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_testimonial_section_enable( $control ) {
    return ( $control->manager->get_setting( 'favblog_pro_theme_options[testimonial_section_enable]' )->value() );
}
/**
 * Check if testimonial section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_testimonial_section_content_page_enable( $control ) {
    $content_type = $control->manager->get_setting( 'favblog_pro_theme_options_testimonial_content_type' )->value();
    return favblog_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if testimonial section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_testimonial_section_content_post_enable( $control ) {
    $content_type = $control->manager->get_setting( 'favblog_pro_theme_options_testimonial_content_type' )->value();
    return favblog_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if testimonial section content type is category.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_testimonial_section_content_category_enable( $control ) {
    $content_type = $control->manager->get_setting( 'favblog_pro_theme_options_testimonial_content_type' )->value();
    return favblog_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_if_subscription_enable( $control ) {
    return ( $control->manager->get_setting( 'favblog_pro_theme_options[subscription_section_enable]' )->value() );
}


/**
 * Check if team section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section seperator.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_team_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_team_content_type' )->value();
	return favblog_pro_is_team_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_team_content_type' )->value();
	return favblog_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_team_content_type' )->value();
	return favblog_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_team_content_type' )->value();
	return favblog_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is custom.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_team_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_team_content_type' )->value();
	return favblog_pro_is_team_section_enable( $control ) && ( 'custom' == $content_type );
}


/**
 * Check if counter section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[counter_section_enable]' )->value() );
}


/**
 * Check if cta section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[cta_section_enable]' )->value() );
}


/**
 * Check if cta section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_cta_content_type' )->value();
	return favblog_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_cta_content_type' )->value();
	return favblog_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is category.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_cta_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_cta_content_type' )->value();
	return favblog_pro_is_cta_section_enable( $control ) && ( 'category' == $content_type );
}

/*recent latest_product*/

/**
 * Check if latest_product section is enabled.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_latest_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[latest_product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if latest_product section content type is latest_product.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_latest_product_section_content_latest_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_latest_product_content_type' )->value();
	return favblog_pro_is_latest_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if latest_product section content type is latest_product category.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_latest_product_section_content_latest_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_latest_product_content_type' )->value();
	return favblog_pro_is_latest_product_section_enable( $control ) && ( 'product-category' == $content_type );
}



/*popular_product*/

/**
 * Check if popular_product section is enabled.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_popular_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[popular_product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if popular_product section content type is popular_product.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_popular_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_popular_product_content_type' )->value();
	return favblog_pro_is_popular_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if popular_product section content type is popular_product category.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_popular_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_popular_product_content_type' )->value();
	return favblog_pro_is_popular_product_section_enable( $control ) && ( 'product-category' == $content_type );
}


/*product_collection*/

/**
 * Check if product_collection section is enabled.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_product_collection_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[product_collection_section_enable]' )->value() );
}

/**
 * Check if product_collection section content type is product_collection.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_product_collection_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_product_collection_content_type' )->value();
	return favblog_pro_is_product_collection_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if product_collection section content type is product_collection category.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_product_collection_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_product_collection_content_type' )->value();
	return favblog_pro_is_product_collection_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if product_collection section content type is product_collection post.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_product_collection_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_product_collection_content_type' )->value();
	return favblog_pro_is_product_collection_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if product_collection section content type is product_collection page.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_product_collection_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_product_collection_content_type' )->value();
	return favblog_pro_is_product_collection_section_enable( $control ) && ( 'page' == $content_type );
}

/*recent_product*/

/**
 * Check if recent_product section is enabled.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_recent_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[recent_product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if recent_product section content type is recent_product.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_recent_product_section_content_recent_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_recent_product_content_type' )->value();
	return favblog_pro_is_recent_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if recent_product section content type is recent_product category.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_recent_product_section_content_recent_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_recent_product_content_type' )->value();
	return favblog_pro_is_recent_product_section_enable( $control ) && ( 'product-category' == $content_type );
}


/*recent featured_product*/

/**
 * Check if featured_product section is enabled.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_featured_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[featured_product_section_enable]' )->value() );
}

/**
 * Check if featured_product section content type is featured_product.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_featured_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_featured_product_content_type' )->value();
	return favblog_pro_is_featured_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if featured_product section content type is featured_product category.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_featured_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_featured_product_content_type' )->value();
	return favblog_pro_is_featured_product_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if featured_product section content type is featured_product category.
 *
 * @since FavBlog Pro 1.0.0 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_featured_product_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_featured_product_content_type' )->value();
	return favblog_pro_is_featured_product_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if course section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_course_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[course_section_enable]' )->value() );
}

/**
 * Check if course section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_course_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options[course_content_type]' )->value();
	return favblog_pro_is_course_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if course section content type is page.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_course_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options[course_content_type]' )->value();
	return favblog_pro_is_course_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if course section content type is category.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_course_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options[course_content_type]' )->value();
	return favblog_pro_is_course_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if trending_product section is enabled.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function favblog_pro_is_trending_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'favblog_pro_theme_options[trending_product_section_enable]' )->value() );
}

/**
 * Check if trending_product section content type is post.
 *
 * @since FavBlog Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function favblog_pro_is_trending_product_section_content_product_category_enable_1( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_trending_product_content_type_1' )->value();
	return favblog_pro_is_trending_product_section_enable( $control ) && ( 'product-category' == $content_type );
}

function favblog_pro_is_trending_product_section_content_product_category_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_trending_product_content_type_2' )->value();
	return favblog_pro_is_trending_product_section_enable( $control ) && ( 'product-category' == $content_type );
}

function favblog_pro_is_trending_product_section_content_product_category_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_trending_product_content_type_3' )->value();
	return favblog_pro_is_trending_product_section_enable( $control ) && ( 'product-category' == $content_type );
}

function favblog_pro_is_trending_product_section_content_product_enable_1( $control ) {
		$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_trending_product_content_type_1' )->value();
	return favblog_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function favblog_pro_is_trending_product_section_content_product_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_trending_product_content_type_2' )->value();
	return favblog_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function favblog_pro_is_trending_product_section_content_product_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'favblog_pro_theme_options_trending_product_content_type_3' )->value();
	return favblog_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}