<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 * @return array An array of default values
 */

function favblog_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$favblog_pro_default_options = array(
		// Color Options
		'header_title_color'			    => '#000',
		'header_tagline_color'			    => '#666',
		'header_txt_logo_extra'			    => 'show-all',
		'colorscheme_hue'				    => '#fe463a',
		'colorscheme'					    => 'default',
		'theme_version'						=> 'lite-version',
		'home_layout'						=> 'pro-design',
		'search_icon_in_primary_menu_enable'=> true,

		// typography Options
		'theme_typography' 				    => 'default',
		'body_theme_typography' 		    => 'default',
		
		// loader
		'loader_enable'         		    => (bool) false,
		'loader_icon'         			    => 'default',

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',
		
		// layout 
		'site_layout'         			    => 'wide',
		'sidebar_position'         		    => 'right-sidebar',
		'post_sidebar_position' 		    => 'right-sidebar',
		'page_sidebar_position' 		    => 'right-sidebar',
		'menu_sticky'					    => (bool) false,
		'menu_transparent'					=> (bool) false,

		// excerpt options
		'long_excerpt_length'               => 25,

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    	=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'favblog-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'favblog-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'favblog-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	    	=> (bool) true,
		'footer_logo_and_social_menu_enable'	=> (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,
		
		// homepage sections sortable
		'sortable' 						    => 'slider,hero,top_read,featured_post,popular_post,about,service,latest_product,cta,popular_product,counter,product_collection,subscription,recent_product,featured_product,trending_product,gallery_slider,gallery,team,testimonial,recent_post,most_read',


		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'favblog-pro' ),
		'hide_date' 					    => (bool) false,
		'hide_author' 					    => (bool) false,
		'hide_reading_time' 			    => (bool) false,
		'hide_excerpt'		 			    => (bool) false,
		'hide_category'					    => (bool) false,
		'blog_column'						=> 'col-2',


		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,
		'single_post_hide_category'		    => (bool) false,
		'single_post_hide_tags'			    => (bool) false,

		/* Front Page */

		//top bar
		'topbar_section_enable'				=> true,
		'social_menu_enable'				=> true,
		'secondary_menu_enable'				=> true,

		//Hero Section
		'hero_section_enable'				=> true,
		'hero_section_content_type'			=> 'post',
		'hero_section_tag_options'			=> 'post_tag',
		'hero_section_tag_title'			=> esc_html__( 'Popular Tags', 'favblog-pro' ),


		// Top Read
		'top_read_title'					=> esc_html__( 'Top Read Reviews', 'favblog-pro' ),
		'top_read_sub_title'	    	 	=> esc_html__( 'Hand Picked', 'favblog-pro' ),
		'top_read_section_enable'			=> true,
		'top_read_content_type'				=> 'category',
		'top_read_count'					=> 3,

		// Featured Post
		'featured_post_title'				=> esc_html__( 'Featured Posts', 'favblog-pro' ),
		'featured_post_sub_title'	     	=> esc_html__( 'Important', 'favblog-pro' ),
		'featured_post_section_enable'		=> true,
		'featured_post_content_type'		=> 'category',
		'featured_post_count'				=> 2,

		// Popular Post
		'popular_post_title'				=> esc_html__( 'Popular Posts', 'favblog-pro' ),
		'popular_post_sub_title'	     	=> esc_html__( 'Popular', 'favblog-pro' ),
		'popular_post_section_enable'		=> true,
		'popular_post_content_type'			=> 'category',
		'popular_post_count'				=> 3,

		
		// Recent Post
		'recent_post_title'					=> esc_html__( 'Top Read Reviews', 'favblog-pro' ),
		'recent_post_sub_title'	     		=> esc_html__( 'Recents', 'favblog-pro' ),
		'recent_post_section_enable'		=> true,
		'recent_post_content_type'			=> 'category',
		'recent_post_count'					=> 8,

		// Top Read
		'most_read_title'					=> esc_html__( 'Top Read Reviews', 'favblog-pro' ),
		'most_read_sub_title'	     		=> esc_html__( 'Most Read', 'favblog-pro' ),
		'most_read_section_enable'			=> true,
		'most_read_content_type'			=> 'category',
		'most_read_count'					=> 4,

		// Slider
		'slider_section_enable'				=> (bool) true,
		'slider_content_type'				=> 'post',
		'slider_section_sub_title'			=> esc_html__('Agency','favblog-pro'),
		'slider_count'						=> 3,
		'slider_autoplay_enable'			=> false,
		'slider_btn_txt'                    => esc_html__('Learn More','favblog-pro'),
		
		//about 
		'about_section_enable'			    => (bool) true,
		'about_content_type'			    =>'post',
		'about_custom_title'				=> esc_html__('Welcome to World Best Business Company','favblog-pro'),
		'about_section_title'				=> esc_html__('About Us','favblog-pro'),
		'about_custom_content'				=> esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry\'s standardLorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.','favblog-pro'),
		'about_btn_txt'                    => esc_html__('Learn More','favblog-pro'),

		// counter
		'counter_section_enable'			=> false,
		'counter_count'						=> 4,

		//service
		'service_section_enable'		    => (bool) true,
		'service_section_sub_title'			=> esc_html__( 'What We Do', 'favblog-pro' ),
		'service_section_title'			    => esc_html__( 'Our Services', 'favblog-pro' ),
		'service_content_type'			    =>'page',
		'service_posts_count'			    => 3,

		//cta
		'cta_section_enable' 				=> true,
		'cta_content_type'					=> 'post',
		'cta_read_more'						=>	esc_html__('Contact Now', 'favblog-pro'),

		// Gallery 
		'gallery_title'						=> esc_html__( 'Our Gallery Colection', 'favblog-pro' ),
		'gallery_sub_title'	     			=> esc_html__( 'Gallery', 'favblog-pro' ),
		'gallery_section_enable'			=> true,
		'gallery_content_type'				=> 'category',
		'gallery_count'						=> 6,

		// Featured Post
		'gallery_slider_title'				=> esc_html__( 'Featured Posts', 'favblog-pro' ),
		'gallery_slider_sub_title'	     	=> esc_html__( 'Gallery', 'favblog-pro' ),
		'gallery_slider_section_enable'		=> true,
		'gallery_slider_content_type'		=> 'category',
		'gallery_slider_count'				=> 3,

		// team
		'team_section_enable'				=> true,
		'team_content_type'					=> 'category',
		'team_count'						=> 4,
		'team_column'						=> 'col-3',
		'team_title'						=> esc_html__( 'Meet Our Team', 'favblog-pro' ),
		'team_sub_title'					=> esc_html__( 'Our Team', 'favblog-pro' ),

		//testimonial
        'testimonial_section_enable'        => (bool) true,
		'testimonial_content_type'          =>'post',
		'testimonial_count'     		      => 4,
		
		//Featured Product
		'latest_product_section_enable'		=> true,
		'latest_product_content_type'		=> 'product',
		'latest_product_count'				=> 2,

		//Featured Product
		'popular_product_section_enable'	=> true,
		'popular_product_content_type'		=> 'product',
		'popular_product_count'				=> 4,
		'popular_product_title'				=> esc_html__( 'Latest Spring Collection', 'favblog-pro' ),
		'popular_product_subtitle'			=> esc_html__( 'Popular Products', 'favblog-pro' ),
		'popular_product_btn_title'			=> esc_html__( 'Add To Cart', 'favblog-pro' ),

		//Product Collection
		'product_collection_section_enable'	=> true,
		'product_collection_content_type'	=> 'product',
		'product_collection_count'			=> 2,
		'product_collection_title'			=> esc_html__( 'Latest Spring Collection', 'favblog-pro' ),
		'product_collection_subtitle'		=> esc_html__( 'Products Collection', 'favblog-pro' ),
		'product_collection_btn_title'		=> esc_html__( 'Add To Cart', 'favblog-pro' ),

        //subscription
        'subscription_section_enable'       		=> (bool) true,
        'subscription_section_sub_title'    		=> esc_html__('Subscription','favblog-pro'),
        'subscription_section_bg_image'   			=> get_template_directory_uri().'/assets/uploads/header-image.jpg',
        'subscription_section_title'        		=> esc_html__('The best of Mountain to your inbox','favblog-pro'),
        'subscription_section_description'  		=> esc_html__('By signing up for this email, you are agreeing to receive news, offers, and information from Mounten.com, LLC and our partners. Easy unsubscribe links are provided in every email.','favblog-pro'),
		'subscription_section_btn_txt'      		=> esc_html__('Subscribe now','favblog-pro'),
		'subscription_section_social_menu_enable'   => true,
		
		//Recent Product
		'recent_product_section_enable'		=> true,
		'recent_product_content_type'		=> 'product',
		'recent_product_count'				=> 4,
		'recent_product_subtitle'			=> esc_html__( 'Recent Products', 'favblog-pro' ),
		'recent_product_title'			   	=> esc_html__( 'Shopping Every Day', 'favblog-pro' ),
		'recent_product_btn_title'			=> esc_html__( 'Add To Cart', 'favblog-pro' ),

		//Featured Product
		'featured_product_section_enable'	=> true,
		'featured_product_content_type'		=> 'product',
		'featured_product_count'			=> 2,
		'featured_product_btn_title'		=> esc_html__( 'Add To Cart', 'favblog-pro' ),
		
		//Featured Product
		'trending_product_section_enable'	=> true,
		'trending_product_content_type'		=> 'product',
		'trending_product_count'			=> 3,
		'trending_product_title'			=> esc_html__( 'Latest Collection', 'favblog-pro' ),

	);

	$output = apply_filters( 'favblog_pro_default_theme_options', $favblog_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}