<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'favblog_pro_about_section', array(
	'title'             => esc_html__( 'About us','favblog-pro' ),
	'description'       => esc_html__( 'About us  Section options.', 'favblog-pro' ),
	'panel'             => 'favblog_pro_front_page_panel',
) );

$wp_customize->add_setting('favblog_pro_about_section_setting',array(
	'default' => 'setting',
	'sanitize_callback' => 'favblog_pro_sanitize_select',
));

$wp_customize->add_control('favblog_pro_about_section_setting',array(
	'section'			=> 'favblog_pro_about_section',
	'type'				=> 'radio',
    'active_callback'	=> 'favblog_pro_is_about_section_enable',
	'choices'			=> array(
			'setting' => esc_html__( 'Setting', 'favblog-pro' ),
			'style' => esc_html__( 'Style', 'favblog-pro' ),
			)
	));

// About content enable control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'favblog-pro' ),
	'section'           => 'favblog_pro_about_section',
	'on_off_label' 		=> favblog_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[about_section_enable]', array(
		'selector'            => '#about-us .tooltiptext',
		'settings'            => 'favblog_pro_theme_options[about_section_enable]',
    ) );
}

// about section title control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[about_section_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
	'default'			=> 	$options['about_section_title'],
	'transport'			=>'postMessage'
) );

$wp_customize->add_control('favblog_pro_theme_options[about_section_title]', array(
    'label'             => esc_html__( 'Section Sub Title', 'favblog-pro' ),
    'section'           => 'favblog_pro_about_section',
    'type'              =>'text',
    'active_callback'	=> 'favblog_pro_is_about_section_enable',
));
$wp_customize->selective_refresh->add_partial(
    'favblog_pro_theme_options[about_section_title]',
    array(
        'selector'            => '#about-us .section-subtitle',
        'render_callback'     => 'favblog_pro_about_section_partial_title',
    )
);

// About content type control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_about_content_type', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'favblog_pro_sanitize_select',
) );

$wp_customize->add_control( 'favblog_pro_theme_options_about_content_type', array(
	'label'             => esc_html__( 'Content Type', 'favblog-pro' ),
	'section'           => 'favblog_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'favblog_pro_is_about_section_enable',
	'choices'			=> array( 
            'page' 		=> esc_html__( 'Page', 'favblog-pro' ),
            'post' 		=> esc_html__( 'Post', 'favblog-pro' ),
            'category' 	=> esc_html__( 'Category', 'favblog-pro' ),
            'custom' 	=> esc_html__( 'Custom', 'favblog-pro' ),
	),
) );

	// about pages drop down chooser control and setting
	$wp_customize->add_setting( 'favblog_pro_theme_options[about_content_page]', array(
		'sanitize_callback' => 'favblog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[about_content_page]', array(
		'label'             => esc_html__( 'Select Page', 'favblog-pro' ),
		'section'           => 'favblog_pro_about_section',
		'choices'			=> favblog_pro_page_choices(),
		'active_callback'	=> 'favblog_pro_is_about_section_content_page_enable',
	) ) );

	// about posts drop down chooser control and setting
	$wp_customize->add_setting( 'favblog_pro_theme_options[about_content_post]', array(
		'sanitize_callback' => 'favblog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[about_content_post]', array(
		'label'             => esc_html__( 'Select Post', 'favblog-pro' ),
		'section'           => 'favblog_pro_about_section',
		'choices'			=> favblog_pro_post_choices(),
		'active_callback'	=> 'favblog_pro_is_about_section_content_post_enable',
	) ) );


// about posts drop down chooser control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[about_category]', array(
	'sanitize_callback' => 'favblog_pro_sanitize_single_category',
) );

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'favblog_pro_theme_options[about_category]', array(
	'label'             => esc_html__( 'Select Categories', 'favblog-pro' ),
	'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'favblog-pro' ),
	'type'           	=> 'dropdown-taxonomies',
	'section'           => 'favblog_pro_about_section',
	'active_callback'	=> 'favblog_pro_is_about_section_content_category_enable',
) ) ); 

// About title setting
$wp_customize->add_setting('favblog_pro_theme_options[about_custom_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_custom_title']
    )
);

$wp_customize->add_control('favblog_pro_theme_options[about_custom_title]',
    array(
        'section'			=> 'favblog_pro_about_section',
        'label'				=> esc_html__( 'Title:', 'favblog-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'favblog_pro_if_about_section_content_custom_enable'
    )
);

$wp_customize->selective_refresh->add_partial('favblog_pro_theme_options[about_custom_title]',
    array(
        'selector'            => '#about-us .section-title',
        'render_callback'     => 'favblog_pro_about_section_partial_custom_title',
    )
);

// About content setting
$wp_customize->add_setting('favblog_pro_theme_options[about_custom_content]',
    array(
        'sanitize_callback' => 'sanitize_textarea_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_custom_content']

    )
);

$wp_customize->add_control('favblog_pro_theme_options[about_custom_content]',
    array(
        'section'			=> 'favblog_pro_about_section',
        'label'				=> esc_html__( 'Content:', 'favblog-pro' ),
        'type'          	=>'textarea',
        'active_callback'	=> 'favblog_pro_if_about_section_content_custom_enable'
    )
);

$wp_customize->selective_refresh->add_partial('favblog_pro_theme_options[about_custom_content]',array(
        'selector'            => '#about-us .section-header span.content',
        'render_callback'     => 'favblog_pro_about_section_partial_custom_content',
    )
);
//slider_btn_txt
$wp_customize->add_setting('favblog_pro_theme_options[about_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_btn_txt'],
    )
);

$wp_customize->add_control('favblog_pro_theme_options[about_btn_txt]',
    array(
        'section'			=> 'favblog_pro_about_section',
        'label'				=> esc_html__( 'Button Text:', 'favblog-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'favblog_pro_is_about_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[about_btn_txt]', array(
		'selector'            => '#about-us div.read-more a',
		'settings'            => 'favblog_pro_theme_options[about_btn_txt]',
		'fallback_refresh'    => true,
		'container_inclusive' => false,
 		'render_callback'     => 'favblog_pro_about_btn_txt_partial',
    ) );
}

$wp_customize->add_setting( 'favblog_pro_theme_options[about_us_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'favblog_pro_theme_options[about_us_btn_url]', array(
	'label'           	=>  esc_html__( 'About Us Button Link ', 'favblog-pro' ),
	'section'        	=> 'favblog_pro_about_section',
	'active_callback' 	=> 'favblog_pro_if_about_section_content_custom_enable',
	'type'				=> 'url',
) );

/**
 * Style
 */
$wp_customize->add_setting( 'favblog_pro_theme_options[style_about_section_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_about_section_subtitle_color]', array(
	'label'             => esc_html__( 'Section SubTitle Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_about_section',
	) ) );


$wp_customize->add_setting( 'favblog_pro_theme_options[style_about_section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_about_section_title_color]', array(
	'label'             => esc_html__( 'Section Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_about_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_about_description_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_about_description_color]', array(
	'label'             => esc_html__( 'Description Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_about_section',
	) ) );
    
    $wp_customize->add_setting( 'favblog_pro_theme_options[style_about_btn_bg_color]', array(
        'sanitize_callback' => 'sanitize_hex_color',
        'transport'			=> 'refresh'
        ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_about_btn_bg_color]', array(
        'label'             => esc_html__( 'Btn Background Color', 'favblog-pro' ),
        'section'           => 'favblog_pro_about_section',
		) ) );
		
    $wp_customize->add_setting( 'favblog_pro_theme_options[style_about_btn_text_color]', array(
        'sanitize_callback' => 'sanitize_hex_color',
        'transport'			=> 'refresh'
        ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_about_btn_text_color]', array(
        'label'             => esc_html__( 'Btn Text Color', 'favblog-pro' ),
        'section'           => 'favblog_pro_about_section',
        ) ) );
    
    $wp_customize->add_setting( 'favblog_pro_theme_options[style_about_btn_hover_color]', array(
        'sanitize_callback' => 'sanitize_hex_color',
        'transport'			=> 'refresh'
        ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_about_btn_hover_color]', array(
        'label'             => esc_html__( 'Btn Hover Color', 'favblog-pro' ),
        'section'           => 'favblog_pro_about_section',
        ) ) );