<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'favblog_pro_counter_section', array(
	'title'             => esc_html__( 'Counters','favblog-pro' ),
	'description'       => esc_html__( 'Counters Section options.', 'favblog-pro' ),
	'panel'             => 'favblog_pro_front_page_panel',
) );

$wp_customize->add_setting('favblog_pro_counter_section_setting',array(
	'default' => 'setting',
	'sanitize_callback' => 'favblog_pro_sanitize_select',
));

$wp_customize->add_control('favblog_pro_counter_section_setting',array(
	'section'			=> 'favblog_pro_counter_section',
	'type'				=> 'radio',
	'active_callback'	=> 'favblog_pro_is_counter_section_enable',
	'choices'			=> array(
			'setting' => esc_html__( 'Setting', 'favblog-pro' ),
			'style' => esc_html__( 'Style', 'favblog-pro' ),
			)
	));
// Counter content enable control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'favblog-pro' ),
	'section'           => 'favblog_pro_counter_section',
	'on_off_label' 		=> favblog_pro_switch_options(),
) ) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[counter_section_enable]', array(
		'selector'            => '#counter-section .tooltiptext',
		'settings'            => 'favblog_pro_theme_options[counter_section_enable]',
    ) );
}

$wp_customize->add_setting( 'favblog_pro_theme_options[counter_image]', array(
	'sanitize_callback' => 'favblog_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'favblog_pro_theme_options[counter_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'favblog-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'favblog-pro' ), 1350, 385 ),
		'section'     		=> 'favblog_pro_counter_section',
		'active_callback'	=> 'favblog_pro_is_counter_section_enable',
) ) );

// counter number control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_counter_count', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'favblog_pro_sanitize_number_range',
	'validate_callback' => 'favblog_pro_validate_counter_count',
) );

$wp_customize->add_control( 'favblog_pro_theme_options_counter_count', array(
	'label'             => esc_html__( 'Number of Counters', 'favblog-pro' ),
	'description'       => esc_html__( 'Note: Min 4 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'favblog-pro' ),
	'section'           => 'favblog_pro_counter_section',
	'active_callback'   => 'favblog_pro_is_counter_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 4,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= get_theme_mod( 'favblog_pro_theme_options_counter_count', $options['counter_count'] ); $i++ ) :


	// 	// counter note control and setting
	// 	$wp_customize->add_setting( 'favblog_pro_theme_options[counter_content_icon_' . $i . ']', array(
	// 		'sanitize_callback' => 'sanitize_text_field',
	// 	) );
	
	// 	$wp_customize->add_control( new FavBlog_Pro_Icon_Picker( $wp_customize, 'favblog_pro_theme_options[counter_content_icon_' . $i . ']', array(
	// 		'label'             => sprintf( esc_html__( 'Select Icon %d', 'favblog-pro' ), $i ),
	// 		'section'           => 'favblog_pro_counter_section',
	// 		'active_callback'	=> 'favblog_pro_is_counter_section_enable',
	// 	) ) );
	// }

	// counter title setting and control
	$wp_customize->add_setting( 'favblog_pro_theme_options[counter_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'favblog_pro_theme_options[counter_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Title %d', 'favblog-pro' ), $i ),
		'section'        	=> 'favblog_pro_counter_section',
		'active_callback' 	=> 'favblog_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter title setting and control
	$wp_customize->add_setting( 'favblog_pro_theme_options[counter_number_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'favblog_pro_theme_options[counter_number_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Count %d', 'favblog-pro' ), $i ),
		'section'        	=> 'favblog_pro_counter_section',
		'active_callback' 	=> 'favblog_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'favblog_pro_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'favblog_pro_sanitize_html'
	) );

	$wp_customize->add_control( new FavBlog_Pro_Customize_Horizontal_Line( $wp_customize, 'favblog_pro_theme_options[counter_hr_'. $i .']',
		array(
			'section'         => 'favblog_pro_counter_section',
			'active_callback' => 'favblog_pro_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );
	
endfor;

/**
 * STYLE
 */
    
$wp_customize->add_setting( 'favblog_pro_theme_options[style_counter_btn_bg_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_counter_btn_bg_color]', array(
	'label'             => esc_html__( 'Background Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_counter_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_counter_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_counter_title_color]', array(
	'label'             => esc_html__( 'Counter Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_counter_section',
	) ) );
	
$wp_customize->add_setting( 'favblog_pro_theme_options[style_counter_number_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_counter_number_color]', array(
	'label'             => esc_html__( 'Counter Number Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_counter_section',
	) ) );
