<?php
/**
 * Call To Action Section options
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

// Add cta section
$wp_customize->add_section( 'favblog_pro_cta_section', array(
	'title'             => esc_html__( 'Call To Action','favblog-pro' ),
	'description'       => esc_html__( 'CTA Section options.', 'favblog-pro' ),
	'panel'             => 'favblog_pro_front_page_panel',

) );

$wp_customize->add_setting('favblog_pro_cta_section_setting',array(
	'default' => 'setting',
	'sanitize_callback' => 'favblog_pro_sanitize_select',
));

$wp_customize->add_control('favblog_pro_cta_section_setting',array(
	'section'			=> 'favblog_pro_cta_section',
	'type'				=> 'radio',
    'active_callback' 	=> 'favblog_pro_is_cta_section_enable',
	'choices'			=> array(
			'setting' => esc_html__( 'Setting', 'favblog-pro' ),
			'style' => esc_html__( 'Style', 'favblog-pro' ),
			)
	));

// cta content enable control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'favblog-pro' ),
	'section'           => 'favblog_pro_cta_section',
	'on_off_label' 		=> favblog_pro_switch_options(),
) ) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[cta_section_enable]', array(
		'selector'            => '#call-to-action .tooltiptext',
		'settings'            => 'favblog_pro_theme_options[cta_section_enable]',
    ) );
}


// cta content type control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_cta_content_type', array(
    'default'          	=> $options['cta_content_type'],
    'sanitize_callback' => 'favblog_pro_sanitize_select',
) );

$wp_customize->add_control( 'favblog_pro_theme_options_cta_content_type', array(
    'label'             => esc_html__( 'Content Type', 'favblog-pro' ),
    'section'           => 'favblog_pro_cta_section',
    'type'				=> 'select',
    'active_callback' 	=> 'favblog_pro_is_cta_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'favblog-pro' ),
		'post' 		=> esc_html__( 'Post', 'favblog-pro' ),
		'category' 	=> esc_html__( 'Category', 'favblog-pro' ),
		),
) );

$wp_customize->add_setting( 'favblog_pro_theme_options[cta_content_page]', array(
    'sanitize_callback' => 'favblog_pro_sanitize_page',
) );

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[cta_content_page]', array(
    'label'             => esc_html__( 'Select Page', 'favblog-pro' ),
    'section'           => 'favblog_pro_cta_section',
    'choices'			=> favblog_pro_page_choices(),
    'active_callback'	=> 'favblog_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[cta_content_post]', array(
    'sanitize_callback' => 'favblog_pro_sanitize_page',
) );

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[cta_content_post]', array(
    'label'             => esc_html__( 'Select posts', 'favblog-pro' ),
    'section'           => 'favblog_pro_cta_section',
    'choices'			=> favblog_pro_post_choices(),
    'active_callback'	=> 'favblog_pro_is_cta_section_content_post_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[cta_category]', array(
	'sanitize_callback' => 'favblog_pro_sanitize_single_category',
) );

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'favblog_pro_theme_options[cta_category]', array(
	'label'             => esc_html__( 'Select Categories', 'favblog-pro' ),
	'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'favblog-pro' ),
	'type'           	=> 'dropdown-taxonomies',
	'section'           => 'favblog_pro_cta_section',
	'active_callback'	=> 'favblog_pro_is_cta_section_content_category_enable',
) ) ); 



// cta read more setting and control
$wp_customize->add_setting( 'favblog_pro_theme_options[cta_read_more]', array(
	'default'			=> $options['cta_read_more'],
    'sanitize_callback' => 'sanitize_text_field',
    'transport'         =>'postMessage',
) );

$wp_customize->add_control( 'favblog_pro_theme_options[cta_read_more]', array(
	'label'           	=> esc_html__( 'Read More Text', 'favblog-pro' ),
	'section'        	=> 'favblog_pro_cta_section',
	'active_callback' 	=> 'favblog_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[cta_read_more]', array(
		'selector'            => '#call-to-action .wrapper .read-more a.btn',
		'settings'            => 'favblog_pro_theme_options[cta_read_more]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'favblog_pro_cta_read_more_partial',
    ) );
}
/**
 * STYLE
 */

$wp_customize->add_setting( 'favblog_pro_theme_options[style_cta_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_cta_title_color]', array(
	'label'             => esc_html__( 'Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_cta_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_cta_description_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_cta_description_color]', array(
	'label'             => esc_html__( 'Description Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_cta_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_cta_btn_bg_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_cta_btn_bg_color]', array(
	'label'             => esc_html__( 'Btn Background Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_cta_section',
	) ) );
	
$wp_customize->add_setting( 'favblog_pro_theme_options[style_cta_btn_text_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_cta_btn_text_color]', array(
	'label'             => esc_html__( 'Btn Text Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_cta_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_cta_btn_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_cta_btn_hover_color]', array(
	'label'             => esc_html__( 'Btn Hover Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_cta_section',
	) ) );