<?php
/**
 * Gallery Slider Section options
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

// Add Gallery Slider section
$wp_customize->add_section( 'favblog_pro_gallery_slider_section', array(
	'title'             => esc_html__( 'Gallery Slider','favblog-pro' ),
	'description'       => esc_html__( 'Gallery Slider Section options.', 'favblog-pro' ),
	'panel'             => 'favblog_pro_front_page_panel',
	) );

	$wp_customize->add_setting('favblog_pro_gallery_slider_section_setting',array(
		'default' => 'setting',
		'sanitize_callback' => 'favblog_pro_sanitize_select',
	));
	
	$wp_customize->add_control('favblog_pro_gallery_slider_section_setting',array(
		'section'			=> 'favblog_pro_gallery_slider_section',
		'type'				=> 'radio',
		'active_callback' 	=> 'favblog_pro_is_gallery_slider_section_enable',
		'choices'			=> array(
				'setting' => esc_html__( 'Setting', 'favblog-pro' ),
				'style' => esc_html__( 'Style', 'favblog-pro' ),
				)
		));
	
// Gallery Slider content enable control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[gallery_slider_section_enable]', array(
	'default'			=> 	$options['gallery_slider_section_enable'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[gallery_slider_section_enable]', array(
	'label'             => esc_html__( 'Gallery Slider Section Enable', 'favblog-pro' ),
	'section'           => 'favblog_pro_gallery_slider_section',
	'on_off_label' 		=> favblog_pro_switch_options(),
	) ) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[gallery_slider_section_enable]', array(
		'selector'            => '#gallery-slider-section .tooltiptext',
		'settings'            => 'favblog_pro_theme_options[gallery_slider_section_enable]',
    ) );
}

// popular destination sub title setting and control
$wp_customize->add_setting( 'favblog_pro_theme_options[gallery_slider_sub_title]', array(
	'default'			=> $options['gallery_slider_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'favblog_pro_theme_options[gallery_slider_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'favblog-pro' ),
	'section'        	=> 'favblog_pro_gallery_slider_section',
	'active_callback' 	=> 'favblog_pro_is_gallery_slider_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[gallery_slider_sub_title]', array(
		'selector'            => '#must-read .business-section-header p.section-subtitle',
		'settings'            => 'favblog_pro_theme_options[gallery_slider_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'favblog_pro_gallery_slider_sub_title_partial',
    ) );
}

// gallery_slider title setting and control
$wp_customize->add_setting( 'favblog_pro_theme_options[gallery_slider_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_slider_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'favblog_pro_theme_options[gallery_slider_title]', array(
	'label'           	=> esc_html__( 'Section Title', 'favblog-pro' ),
	'section'        	=> 'favblog_pro_gallery_slider_section',
	'active_callback' 	=> 'favblog_pro_is_gallery_slider_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[gallery_slider_title]', array(
		'selector'            => '#must-read .business-section-header h2',
		'settings'            => 'favblog_pro_theme_options[gallery_slider_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'favblog_pro_gallery_slider_title_partial',
		) );
}


// Event social icons number control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_gallery_slider_count', array(
	'default'          	=> $options['gallery_slider_count'],
	'sanitize_callback' => 'favblog_pro_sanitize_number_range',
	'validate_callback' => 'favblog_pro_validate_gallery_slider_count',
	) );

$wp_customize->add_control( 'favblog_pro_theme_options_gallery_slider_count', array(
	'label'             => esc_html__( 'Number of Posts', 'favblog-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'favblog-pro' ),
	'section'           => 'favblog_pro_gallery_slider_section',
	'active_callback'   => 'favblog_pro_is_gallery_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
	) );

// Gallery Slider content type control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_gallery_slider_content_type', array(
	'default'          	=> $options['gallery_slider_content_type'],
	'sanitize_callback' => 'favblog_pro_sanitize_select',
	) );

$wp_customize->add_control( 'favblog_pro_theme_options_gallery_slider_content_type', array(
	'label'             => esc_html__( 'Content Type', 'favblog-pro' ),
	'section'           => 'favblog_pro_gallery_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'favblog_pro_is_gallery_slider_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'favblog-pro' ),
		'post' 		=> esc_html__( 'Post', 'favblog-pro' ),
		'category' 	=> esc_html__( 'Category', 'favblog-pro' ),
		),
	) );

for ( $i = 1; $i <= get_theme_mod( 'favblog_pro_theme_options_gallery_slider_count', $options['gallery_slider_count'] ); $i++ ) :
	// gallery_slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'favblog_pro_theme_options[gallery_slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'favblog_pro_sanitize_page',
		) );

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[gallery_slider_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'favblog-pro' ), $i ),
	'section'           => 'favblog_pro_gallery_slider_section',
	'choices'			=> favblog_pro_page_choices(),
	'active_callback'	=> 'favblog_pro_is_gallery_slider_section_content_page_enable',
	) ) );

	// gallery_slider posts drop down chooser control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[gallery_slider_content_post_' . $i . ']', array(
	'sanitize_callback' => 'favblog_pro_sanitize_page',
	) );

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[gallery_slider_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'favblog-pro' ), $i ),
	'section'           => 'favblog_pro_gallery_slider_section',
	'choices'			=> favblog_pro_post_choices(),
	'active_callback'	=> 'favblog_pro_is_gallery_slider_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'favblog_pro_theme_options[gallery_slider_content_category]', array(
	'sanitize_callback' => 'favblog_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'favblog_pro_theme_options[gallery_slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'favblog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'favblog-pro' ),
	'section'           => 'favblog_pro_gallery_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'favblog_pro_is_gallery_slider_section_content_category_enable'
    ) ) );

	$wp_customize->add_setting( 'favblog_pro_theme_options[gallery_slider_video_url]', array(
		'sanitize_callback' => 'esc_url_raw',
	) );
	
	$wp_customize->add_control( 'favblog_pro_theme_options[gallery_slider_video_url]', array(
		'label'           	=>  esc_html__( 'Video URL ', 'favblog-pro' ),
		'section'        	=> 'favblog_pro_gallery_slider_section',
		'active_callback' 	=> 'favblog_pro_is_gallery_slider_section_enable',
		'type'				=> 'url',
	) );
	
/**
 * Style
 */
$wp_customize->add_setting( 'favblog_pro_theme_options[style_gallery_slider_section_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_gallery_slider_section_subtitle_color]', array(
	'label'             => esc_html__( 'Section SubTitle Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_gallery_slider_section',
	) ) );


$wp_customize->add_setting( 'favblog_pro_theme_options[style_gallery_slider_section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_gallery_slider_section_title_color]', array(
	'label'             => esc_html__( 'Section Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_gallery_slider_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_gallery_slider_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_gallery_slider_title_color]', array(
	'label'             => esc_html__( 'Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_gallery_slider_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_gallery_slider_icon_border_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_gallery_slider_icon_border_color]', array(
	'label'             => esc_html__( 'Icon Border Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_gallery_slider_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_gallery_slider_icon_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_gallery_slider_icon_color]', array(
	'label'             => esc_html__( 'Icon Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_gallery_slider_section',
	) ) );
