<?php
/**
 * Hero Section Section options
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

// Add Hero Section section
$wp_customize->add_section( 'favblog_pro_hero_section', array(
	'title'             => esc_html__( 'Hero Section','favblog-pro' ),
	'description'       => esc_html__( 'Hero Section options.', 'favblog-pro' ),
	'panel'             => 'favblog_pro_front_page_panel',
	) );

$wp_customize->add_setting('favblog_pro_hero_section_setting',array(
	'default' => 'setting',
	'sanitize_callback' => 'favblog_pro_sanitize_select',
));

$wp_customize->add_control('favblog_pro_hero_section_setting',array(
	'section'			=> 'favblog_pro_hero_section',
	'type'				=> 'radio',
	'active_callback' 	=> 'favblog_pro_is_hero_section_enable',
	'choices'			=> array(
			'setting' => esc_html__( 'Setting', 'favblog-pro' ),
			'style' => esc_html__( 'Style', 'favblog-pro' ),
			)
	));

// Hero Section content enable control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[hero_section_enable]', array(
	'default'			=> 	$options['hero_section_enable'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[hero_section_enable]', array(
	'label'             => esc_html__( 'Hero Section Enable', 'favblog-pro' ),
	'section'           => 'favblog_pro_hero_section',
	'on_off_label' 		=> favblog_pro_switch_options(),
	) ) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[hero_section_enable]', array(
		'selector'            => '#hero-section .tooltiptext',
		'settings'            => 'favblog_pro_theme_options[hero_section_enable]',
    ) );
}

// Hero Section content type control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_hero_content_type', array(
	'default'          	=> $options['hero_section_content_type'],
	'sanitize_callback' => 'favblog_pro_sanitize_select',
	) );

$wp_customize->add_control( 'favblog_pro_theme_options_hero_content_type', array(
	'label'             => esc_html__( 'Content Type', 'favblog-pro' ),
	'section'           => 'favblog_pro_hero_section',
	'type'				=> 'select',
	'active_callback' 	=> 'favblog_pro_is_hero_section_enable',
	'choices'			=> array( 
			'page' 			=> esc_html__( 'Page', 'favblog-pro' ),
			'post' 			=> esc_html__( 'Post', 'favblog-pro' ),
			'category' 		=> esc_html__( 'Category', 'favblog-pro' ),
			), 
	) );

// hero_section pages drop down chooser control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[hero_content_page]', array(
    'sanitize_callback' => 'favblog_pro_sanitize_page',
    ) );

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[hero_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'favblog-pro' ),
	'section'           => 'favblog_pro_hero_section',
	'choices'			=> favblog_pro_page_choices(),
	'active_callback'	=> 'favblog_pro_is_hero_content_page_enable',
	) ) );

	// hero_section posts drop down chooser control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[hero_content_post]', array(
	'sanitize_callback' => 'favblog_pro_sanitize_page',
	) );

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[hero_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'favblog-pro' ),
	'section'           => 'favblog_pro_hero_section',
	'choices'			=> favblog_pro_post_choices(),
	'active_callback'	=> 'favblog_pro_is_hero_content_post_enable',
	) ) );

// hero posts drop down chooser control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[hero_content_category]', array(
	'sanitize_callback' => 'favblog_pro_sanitize_single_category',
) );

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'favblog_pro_theme_options[hero_content_category]', array(
	'label'             => esc_html__( 'Select Categories', 'favblog-pro' ),
	'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'favblog-pro' ),
	'type'           	=> 'dropdown-taxonomies',
	'section'           => 'favblog_pro_hero_section',
	'active_callback'	=> 'favblog_pro_is_hero_section_content_category_enable',
) ) ); 

// hero_section title setting and control
$wp_customize->add_setting( 'favblog_pro_theme_options[hero_section_tag_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['hero_section_tag_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'favblog_pro_theme_options[hero_section_tag_title]', array(
	'label'           	=> esc_html__( 'Tags Title', 'favblog-pro' ),
	'section'        	=> 'favblog_pro_hero_section',
	'active_callback' 	=> 'favblog_pro_is_hero_content_tag_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[hero_section_tag_title]', array(
		'selector'            => '#hero-section div.entry-container .entry-meta p',
		'settings'            => 'favblog_pro_theme_options[hero_section_tag_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'favblog_pro_hero_section_tag_title_partial',
		) );
}

// Hero Section content type control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[hero_section_tag_options]', array(
	'default'          	=> $options['hero_section_tag_options'],
	'sanitize_callback' => 'favblog_pro_sanitize_select',
	) );

$wp_customize->add_control( 'favblog_pro_theme_options[hero_section_tag_options]', array(
	'label'             => esc_html__( 'Tags Types', 'favblog-pro' ),
	'section'           => 'favblog_pro_hero_section',
	'type'				=> 'select',
	'active_callback' 	=> 'favblog_pro_is_hero_content_tag_enable',
	'choices'			=> array( 
		'category' 		=> esc_html__( 'Categories', 'favblog-pro' ),
		'post_tag'     => esc_html__( 'Tags', 'favblog-pro' ),
		), 
	) );

 	
$wp_customize->add_setting( 'favblog_pro_theme_options[style_hero_section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_hero_section_title_color]', array(
	'label'             => esc_html__( 'Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_hero_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_hero_section_title_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_hero_section_title_hover_color]', array(
	'label'             => esc_html__( 'Title Hover Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_hero_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_hero_section_description_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_hero_section_description_color]', array(
	'label'             => esc_html__( 'Description Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_hero_section',
	) ) );


	$wp_customize->add_setting('favblog_pro_theme_options[style_hero_section_bg_options]',array(
		'default' => 'image',
		'sanitize_callback' => 'favblog_pro_sanitize_select',
	));
	
	$wp_customize->add_control('favblog_pro_theme_options[style_hero_section_bg_options]',array(
		'section'		=> 'favblog_pro_hero_section',
		'type'			=> 'radio',
		'choices'		=> array(
				'image' => esc_html__( 'Background Image', 'favblog-pro' ),
				'color' => esc_html__( 'Color', 'favblog-pro' ),
			)
		));
	
	$wp_customize->add_setting( 'favblog_pro_theme_options[style_hero_section_bg_image]', array(
		'sanitize_callback' => 'favblog_pro_sanitize_image',
		'transport'			=> 'refresh'
		) );
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'favblog_pro_theme_options[style_hero_section_bg_image]', array(
		'label'             => esc_html__( 'Image', 'favblog-pro' ),
		'section'           => 'favblog_pro_hero_section',
		'active_callback' 	=> 'favblog_pro_is_hero_section_bg_image_enable',
		) ) );
	
	$wp_customize->add_setting( 'favblog_pro_theme_options[style_hero_section_bg_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'refresh'
		) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_hero_section_bg_color]', array(
		'label'             => esc_html__( 'Background Color', 'favblog-pro' ),
		'section'           => 'favblog_pro_hero_section',
		'active_callback' 	=> 'favblog_pro_is_hero_section_bg_color_enable',
		) ) );