<?php
/**
 * Latest Product Section options
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

// Add Product section
$wp_customize->add_section( 'favblog_pro_latest_product_section', array(
	'title'             => esc_html__( 'Latest Product','favblog-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'favblog-pro' ),
	'panel'             => 'favblog_pro_front_page_panel',
) );

$wp_customize->add_setting('favblog_pro_latest_product_section_setting',array(
	'default' => 'setting',
	'sanitize_callback' => 'favblog_pro_sanitize_select',
));

$wp_customize->add_control('favblog_pro_latest_product_section_setting',array(
	'section'			=> 'favblog_pro_latest_product_section',
	'type'				=> 'radio',
	'active_callback' 	=> 'favblog_pro_is_latest_product_section_enable',
	'choices'			=> array(
			'setting' => esc_html__( 'Setting', 'favblog-pro' ),
			'style' => esc_html__( 'Style', 'favblog-pro' ),
			)
	));

// Product content enable control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[latest_product_section_enable]', array(
	'default'			=> 	$options['latest_product_section_enable'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[latest_product_section_enable]', array(
	'label'             => esc_html__( 'Latest Product Section Enable', 'favblog-pro' ),
	'section'           => 'favblog_pro_latest_product_section',
	'on_off_label' 		=> favblog_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[latest_product_section_enable]', array(
		'selector'            => '#latest-products .tooltiptext',
		'settings'            => 'favblog_pro_theme_options[latest_product_section_enable]',
    ) );
}

// Product content type control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_latest_product_content_type', array(
	'default'          	=> $options['latest_product_content_type'],
	'sanitize_callback' => 'favblog_pro_sanitize_select',
) );

$wp_customize->add_control( 'favblog_pro_theme_options_latest_product_content_type', array(
	'label'             => esc_html__( 'Content Type', 'favblog-pro' ),
	'section'           => 'favblog_pro_latest_product_section',
	'type'				=> 'select',
	'active_callback' 	=> 'favblog_pro_is_latest_product_section_enable',
	'choices'			=> favblog_pro_latest_product_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_latest_product_count', array(
	'default'          	=> $options['latest_product_count'],
	'sanitize_callback' => 'favblog_pro_sanitize_number_range',
	'validate_callback' => 'favblog_pro_validate_latest_product_count',
) );

$wp_customize->add_control( 'favblog_pro_theme_options_latest_product_count', array(
	'label'             => esc_html__( 'Number of Product', 'favblog-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 4. Please input the valid number and save. Then refresh the page to see the change.', 'favblog-pro' ),
	'section'           => 'favblog_pro_latest_product_section',
	'active_callback'   => 'favblog_pro_is_latest_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 4,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= get_theme_mod( 'favblog_pro_theme_options_latest_product_count', $options['latest_product_count'] ); $i++ ) :

	// latest_product posts drop down chooser control and setting
	$wp_customize->add_setting( 'favblog_pro_theme_options[latest_product_content_product_' . $i . ']', array(
		'sanitize_callback' => 'favblog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[latest_product_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'favblog-pro' ), $i ),
		'section'           => 'favblog_pro_latest_product_section',
		'choices'			=> favblog_pro_product_choices(),
		'active_callback'	=> 'favblog_pro_is_latest_product_section_content_latest_product_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'favblog_pro_theme_options[latest_product_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'favblog_pro_theme_options[latest_product_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'favblog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'favblog-pro' ),
	'section'           => 'favblog_pro_latest_product_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'favblog_pro_is_latest_product_section_content_latest_product_category_enable'
) ) );

/**
 * Style
 */

$wp_customize->add_setting( 'favblog_pro_theme_options[style_latest_product_section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_latest_product_section_title_color]', array(
	'label'             => esc_html__( 'Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_latest_product_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_latest_product_section_title_bg_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_latest_product_section_title_bg_color]', array(
	'label'             => esc_html__( 'Title Background Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_latest_product_section',
	) ) );

