<?php
/**
 * Product Collection Section options
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

// Add Product section
$wp_customize->add_section( 'favblog_pro_product_collection_section', array(
	'title'             => esc_html__( 'Product Collection','favblog-pro' ),
	'description'       => esc_html__( 'Product Collection Section options.', 'favblog-pro' ),
	'panel'             => 'favblog_pro_front_page_panel',
) );

$wp_customize->add_setting('favblog_pro_product_collection_section_setting',array(
	'default' => 'setting',
	'sanitize_callback' => 'favblog_pro_sanitize_select',
));

$wp_customize->add_control('favblog_pro_product_collection_section_setting',array(
	'section'			=> 'favblog_pro_product_collection_section',
	'type'				=> 'radio',
	'active_callback'   => 'favblog_pro_is_product_collection_section_enable',
	'choices'			=> array(
			'setting' => esc_html__( 'Setting', 'favblog-pro' ),
			'style' => esc_html__( 'Style', 'favblog-pro' ),
			)
	));

// Product content enable control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[product_collection_section_enable]', array(
	'default'			=> 	$options['product_collection_section_enable'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[product_collection_section_enable]', array(
	'label'             => esc_html__( 'Product Section Enable', 'favblog-pro' ),
	'section'           => 'favblog_pro_product_collection_section',
	'on_off_label' 		=> favblog_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[product_collection_section_enable]', array(
		'selector'            => '#products-collection .tooltiptext',
		'settings'            => 'favblog_pro_theme_options[product_collection_section_enable]',
    ) );
}

// product_collection title setting and control
$wp_customize->add_setting( 'favblog_pro_theme_options[product_collection_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['product_collection_title'],
	'transport'			=> 'postMessage',

) );

$wp_customize->add_control( 'favblog_pro_theme_options[product_collection_title]', array(
	'label'           	=> esc_html__( 'Title', 'favblog-pro' ),
	'section'        	=> 'favblog_pro_product_collection_section',
	'active_callback' 	=> 'favblog_pro_is_product_collection_section_enable',
	'type'				=> 'text',
) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[product_collection_title]', array(
		'selector'            => '#products-collection .section-header h2.section-title',
		'settings'            => 'favblog_pro_theme_options[product_collection_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'favblog_pro_product_collection_title_partial',
    ) );
}

// product_collection subtitle setting and control
$wp_customize->add_setting( 'favblog_pro_theme_options[product_collection_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['product_collection_subtitle'],
	'transport'			=> 'postMessage',

) );

$wp_customize->add_control( 'favblog_pro_theme_options[product_collection_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'favblog-pro' ),
	'section'        	=> 'favblog_pro_product_collection_section',
	'active_callback' 	=> 'favblog_pro_is_product_collection_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[product_collection_subtitle]', array(
		'selector'            => '#products-collection .section-header p.section-subtitle',
		'settings'            => 'favblog_pro_theme_options[product_collection_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'favblog_pro_product_collection_subtitle_partial',
    ) );
}

// Product content type control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_product_collection_content_type', array(
	'default'          	=> $options['product_collection_content_type'],
	'sanitize_callback' => 'favblog_pro_sanitize_select',
) );

$wp_customize->add_control( 'favblog_pro_theme_options_product_collection_content_type', array(
	'label'             => esc_html__( 'Content Type', 'favblog-pro' ),
	'section'           => 'favblog_pro_product_collection_section',
	'type'				=> 'select',
	'active_callback' 	=> 'favblog_pro_is_product_collection_section_enable',
	'choices'			=> favblog_pro_product_collection_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_product_collection_count', array(
	'default'          	=> $options['product_collection_count'],
	'sanitize_callback' => 'favblog_pro_sanitize_number_range',
	'validate_callback' => 'favblog_pro_validate_product_collection_count',
) );

$wp_customize->add_control( 'favblog_pro_theme_options_product_collection_count', array(
	'label'             => esc_html__( 'Number of Product', 'favblog-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'favblog-pro' ),
	'section'           => 'favblog_pro_product_collection_section',
	'active_callback'   => 'favblog_pro_is_product_collection_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 6,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= get_theme_mod( 'favblog_pro_theme_options_product_collection_count', $options['product_collection_count'] ); $i++ ) :

	// product_collection pages drop down chooser control and setting
	$wp_customize->add_setting( 'favblog_pro_theme_options[product_collection_content_page_' . $i . ']', array(
		'sanitize_callback' => 'favblog_pro_sanitize_page',
		) );

	$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[product_collection_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'favblog-pro' ), $i ),
		'section'           => 'favblog_pro_product_collection_section',
		'choices'			=> favblog_pro_page_choices(),
		'active_callback'	=> 'favblog_pro_is_product_collection_section_content_page_enable',
		) ) );

	// product_collection posts drop down chooser control and setting
	$wp_customize->add_setting( 'favblog_pro_theme_options[product_collection_content_post_' . $i . ']', array(
		'sanitize_callback' => 'favblog_pro_sanitize_page',
		) );
	
	$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[product_collection_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'favblog-pro' ), $i ),
		'section'           => 'favblog_pro_product_collection_section',
		'choices'			=> favblog_pro_post_choices(),
		'active_callback'	=> 'favblog_pro_is_product_collection_section_content_post_enable',
		) ) );

	// product_collection posts drop down chooser control and setting
	$wp_customize->add_setting( 'favblog_pro_theme_options[product_collection_content_product_' . $i . ']', array(
		'sanitize_callback' => 'favblog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[product_collection_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'favblog-pro' ), $i ),
		'section'           => 'favblog_pro_product_collection_section',
		'choices'			=> favblog_pro_product_choices(),
		'active_callback'	=> 'favblog_pro_is_product_collection_section_content_product_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'favblog_pro_theme_options[product_collection_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'favblog_pro_theme_options[product_collection_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'favblog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'favblog-pro' ),
	'section'           => 'favblog_pro_product_collection_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'favblog_pro_is_product_collection_section_content_product_category_enable'
) ) );


// featured product btn title setting and control
$wp_customize->add_setting( 'favblog_pro_theme_options[product_collection_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'           => $options['product_collection_btn_title'],
	'transport'			=> 'postMessage',

	) );

$wp_customize->add_control( 'favblog_pro_theme_options[product_collection_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label ', 'favblog-pro' ),
	'section'        	=> 'favblog_pro_product_collection_section',
	'active_callback' 	=> 'favblog_pro_is_product_collection_section_enable',
	'type'				=> 'text',
	) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[product_collection_btn_title]', array(
		'selector'            => '#products-collection .section-content a.button.add_to_cart_button',
		'settings'            => 'favblog_pro_theme_options[product_collection_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'favblog_pro_product_collection_btn_title_partial',
    ) );
}


/**
 * Style
 */

$wp_customize->add_setting( 'favblog_pro_theme_options[style_product_collection_section_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_product_collection_section_subtitle_color]', array(
	'label'             => esc_html__( 'Section SubTitle Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_product_collection_section',
	) ) );


$wp_customize->add_setting( 'favblog_pro_theme_options[style_product_collection_section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_product_collection_section_title_color]', array(
	'label'             => esc_html__( 'Section Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_product_collection_section',
	) ) );


$wp_customize->add_setting( 'favblog_pro_theme_options[style_product_collection_cat_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_product_collection_cat_color]', array(
	'label'             => esc_html__( 'Cat Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_product_collection_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_product_collection_cat_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_product_collection_cat_hover_color]', array(
	'label'             => esc_html__( 'Cat Hover Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_product_collection_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_product_collection_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_product_collection_title_color]', array(
	'label'             => esc_html__( 'Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_product_collection_section',
	) ) );

    
    $wp_customize->add_setting( 'favblog_pro_theme_options[style_product_collection_btn_bg_color]', array(
        'sanitize_callback' => 'sanitize_hex_color',
        'transport'			=> 'refresh'
        ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_product_collection_btn_bg_color]', array(
        'label'             => esc_html__( 'Btn Background Color', 'favblog-pro' ),
        'section'           => 'favblog_pro_product_collection_section',
		) ) );
		
    $wp_customize->add_setting( 'favblog_pro_theme_options[style_product_collection_btn_text_color]', array(
        'sanitize_callback' => 'sanitize_hex_color',
        'transport'			=> 'refresh'
        ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_product_collection_btn_text_color]', array(
        'label'             => esc_html__( 'Btn Text Color', 'favblog-pro' ),
        'section'           => 'favblog_pro_product_collection_section',
        ) ) );
    
    $wp_customize->add_setting( 'favblog_pro_theme_options[style_product_collection_btn_hover_color]', array(
        'sanitize_callback' => 'sanitize_hex_color',
        'transport'			=> 'refresh'
        ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_product_collection_btn_hover_color]', array(
        'label'             => esc_html__( 'Btn Hover Color', 'favblog-pro' ),
        'section'           => 'favblog_pro_product_collection_section',
        ) ) );