<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'favblog_pro_service_section', array(
	'title'             => esc_html__( 'Services','favblog-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'favblog-pro' ),
	'panel'             => 'favblog_pro_front_page_panel',
) );

$wp_customize->add_setting('favblog_pro_service_section_setting',array(
	'default' => 'setting',
	'sanitize_callback' => 'favblog_pro_sanitize_select',
));

$wp_customize->add_control('favblog_pro_service_section_setting',array(
	'section'			=> 'favblog_pro_service_section',
	'type'				=> 'radio',
	'active_callback'   => 'favblog_pro_is_service_section_enable',
	'choices'			=> array(
			'setting' => esc_html__( 'Setting', 'favblog-pro' ),
			'style' => esc_html__( 'Style', 'favblog-pro' ),
			)
	));

// Service content enable control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'favblog-pro' ),
	'section'           => 'favblog_pro_service_section',
	'on_off_label' 		=> favblog_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[service_section_enable]', array(
		'selector'            => '#our-services .tooltiptext',
		'settings'            => 'favblog_pro_theme_options[service_section_enable]',
    ) );
}

// Service section sub title control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[service_section_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=>'postMessage',
    'default'           => $options['service_section_sub_title'],
) );

$wp_customize->add_control('favblog_pro_theme_options[service_section_sub_title]', array(
    'label'             => esc_html__( 'Section Sub Title', 'favblog-pro' ),
    'section'           => 'favblog_pro_service_section',
    'type'              =>'text',
    'active_callback'	=> 'favblog_pro_is_service_section_enable',
));
$wp_customize->selective_refresh->add_partial(
    'favblog_pro_theme_options[service_section_sub_title]',
    array(
        'selector'            => '#our-services .section-subtitle',
        'render_callback'     => 'favblog_pro_service_section_partial_sub_title',
    )
);

// Service section title control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[service_section_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
    'transport'			=>'postMessage',
    'default'           => $options['service_section_title'],
    
) );

$wp_customize->add_control('favblog_pro_theme_options[service_section_title]', array(
    'label'             => esc_html__( 'Section Title', 'favblog-pro' ),
    'section'           => 'favblog_pro_service_section',
    'type'              =>'text',
    'active_callback'	=> 'favblog_pro_is_service_section_enable',
));
$wp_customize->selective_refresh->add_partial(
    'favblog_pro_theme_options[service_section_title]',
    array(
        'selector'            => '#our-services .section-title',
        'render_callback'     => 'favblog_pro_service_section_partial_title',
    )
);

// Service content type control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_service_content_type', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'favblog_pro_sanitize_select',
) );

$wp_customize->add_control( 'favblog_pro_theme_options_service_content_type', array(
	'label'             => esc_html__( 'Content Type', 'favblog-pro' ),
	'section'           => 'favblog_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'favblog_pro_is_service_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'favblog-pro' ),
		'post' 		=> esc_html__( 'Post', 'favblog-pro' ),
        'category' 	=> esc_html__( 'Category', 'favblog-pro' ),
	),
) );

// Services post number control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_service_count', array(
	'default'          	=> $options['service_posts_count'],
	'sanitize_callback' => 'favblog_pro_sanitize_number_range',
	'validate_callback' => 'favblog_pro_validate_service_count',
) );

$wp_customize->add_control( 'favblog_pro_theme_options_service_count', array(
	'label'             => esc_html__( 'Number of Posts', 'favblog-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'favblog-pro' ),
	'section'           => 'favblog_pro_service_section',
	'active_callback'   => 'favblog_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
                'min'	=> 2,
                'max'	=> 6,
                'style' => 'width: 100px;'
            ),
) );

for($i = 1; $i <= get_theme_mod( 'favblog_pro_theme_options_service_count', $options['service_posts_count'] ); $i ++):

    $wp_customize->add_setting( 'favblog_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new FavBlog_Pro_Icon_Picker( $wp_customize, 'favblog_pro_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'favblog-pro' ), $i ),
		'section'           => 'favblog_pro_service_section',
		'active_callback'	=> 'favblog_pro_is_service_section_enable',
	) ) );
// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'favblog_pro_theme_options[service_content_page_'.$i.']', array(
		'sanitize_callback' => 'favblog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[service_content_page_'.$i.']', array(
		'label'             => sprintf(esc_html__( 'Select Page : %d', 'favblog-pro'), $i ),
		'section'           => 'favblog_pro_service_section',
		'choices'			=> favblog_pro_page_choices(),
		'active_callback'	=> 'favblog_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'favblog_pro_theme_options[service_content_post_'.$i.']', array(
		'sanitize_callback' => 'favblog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[service_content_post_'.$i.']', array(
		'label'             => sprintf(esc_html__( 'Select Post : %d', 'favblog-pro'), $i ),
		'section'           => 'favblog_pro_service_section',
		'choices'			=> favblog_pro_post_choices(),
		'active_callback'	=> 'favblog_pro_is_service_section_content_post_enable',
	) ) );

    //FavBlog_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('favblog_pro_theme_options[service_separator'. $i .']',array(
        'sanitize_callback'      => 'favblog_pro_sanitize_html',
    ));

    $wp_customize->add_control(new FavBlog_Pro_Customize_Horizontal_Line($wp_customize,'favblog_pro_theme_options[service_separator'. $i .']',array(
        'active_callback'       => 'favblog_pro_is_service_section_separator_enable',
        'type'                  =>'hr',
        'section'               =>'favblog_pro_service_section',
    )));

endfor;

// service category drop down chooser control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[service_content_category]', array(
    'sanitize_callback' => 'favblog_pro_sanitize_single_category',
) );

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'favblog_pro_theme_options[service_content_category]', array(
    'label'             => esc_html__( 'Select Categories', 'favblog-pro' ),
    'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'favblog-pro' ),
    'type'           	=> 'dropdown-taxonomies',
    'section'           => 'favblog_pro_service_section',
    'active_callback'	=> 'favblog_pro_is_service_section_content_category_enable',
) ) );


/**
 * Style
 */
$wp_customize->add_setting( 'favblog_pro_theme_options[style_service_section_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_service_section_subtitle_color]', array(
	'label'             => esc_html__( 'Section SubTitle Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_service_section',
	) ) );


$wp_customize->add_setting( 'favblog_pro_theme_options[style_service_section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_service_section_title_color]', array(
	'label'             => esc_html__( 'Section Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_service_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_service_icon_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_service_icon_color]', array(
	'label'             => esc_html__( 'Icon Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_service_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_service_icon_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_service_icon_hover_color]', array(
	'label'             => esc_html__( 'Icon Hover Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_service_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_service_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_service_title_color]', array(
	'label'             => esc_html__( 'Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_service_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_service_title_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_service_title_hover_color]', array(
	'label'             => esc_html__( 'Hover Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_service_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_service_description_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_service_description_color]', array(
	'label'             => esc_html__( 'Description Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_service_section',
	) ) );

