<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'favblog_pro_slider_section', array(
	'title'             => esc_html__( 'Slider','favblog-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'favblog-pro' ),
	'panel'             => 'favblog_pro_front_page_panel',
) );

$wp_customize->add_setting('favblog_pro_slider_section_setting',array(
	'default' => 'setting',
	'sanitize_callback' => 'favblog_pro_sanitize_select',
));

$wp_customize->add_control('favblog_pro_slider_section_setting',array(
	'section'		=> 'favblog_pro_slider_section',
	'type'			=> 'radio',
	'active_callback'   => 'favblog_pro_is_slider_section_enable',
	'choices'		=> array(
			'setting' => esc_html__( 'Setting', 'favblog-pro' ),
			'style' => esc_html__( 'Style', 'favblog-pro' ),
			)
	));

// Slider content enable control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'favblog-pro' ),
	'section'           => 'favblog_pro_slider_section',
	'on_off_label' 		=> favblog_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[slider_section_enable]', array(
		'selector'            => '#featured-slider-section .tooltiptext',
		'settings'            => 'favblog_pro_theme_options[slider_section_enable]',
    ) );
}

// Slider autoplay enable control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[slider_autoplay_enable]', array(
	'default'			=> 	$options['slider_autoplay_enable'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[slider_autoplay_enable]', array(
	'label'             => esc_html__( 'Slider Autoplay Enable', 'favblog-pro' ),
	'section'           => 'favblog_pro_slider_section',
	'active_callback'   => 'favblog_pro_is_slider_section_enable',
	'on_off_label' 		=> favblog_pro_switch_options(),
) ) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[slider_autoplay_enable]', array(
		'selector'            => '#featured-slider .tooltiptext',
		'settings'            => 'favblog_pro_theme_options[slider_autoplay_enable]',
    ) );
}

// Slider number control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_slider_count', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'favblog_pro_sanitize_number_range',
	'validate_callback' => 'favblog_pro_validate_slider_count',
) );

$wp_customize->add_control( 'favblog_pro_theme_options_slider_count', array(
	'label'             => esc_html__( 'Number of Featured', 'favblog-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 5. Please input the valid number and save. Then refresh the page to see the change.', 'favblog-pro' ),
	'section'           => 'favblog_pro_slider_section',
	'active_callback'   => 'favblog_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 5,
		'style' => 'width: 100px;'
		),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_slider_content_type', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'favblog_pro_sanitize_select',
) );

$wp_customize->add_control( 'favblog_pro_theme_options_slider_content_type', array(
	'label'             => esc_html__( 'Content Type', 'favblog-pro' ),
	'section'           => 'favblog_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'favblog_pro_is_slider_section_enable',
	'choices'			=> array( 
            'page' 		=> esc_html__( 'Page', 'favblog-pro' ),
            'post' 		=> esc_html__( 'Post', 'favblog-pro' ),
            'category' 	=> esc_html__( 'Category', 'favblog-pro' ),
	),
) );


for ( $i = 1; $i <= get_theme_mod( 'favblog_pro_theme_options_slider_count', $options['slider_count'] ); $i++ ) :

		
	// slider section title control and setting
	$wp_customize->add_setting( 'favblog_pro_theme_options[slider_section_sub_title_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['slider_section_sub_title'],
		'transport'			=>'refresh'
	) );

	$wp_customize->add_control('favblog_pro_theme_options[slider_section_sub_title_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Section Sub Title %d', 'favblog-pro' ), $i),
		'section'           => 'favblog_pro_slider_section',
		'type'              =>'text',
		'active_callback'	=> 'favblog_pro_is_slider_section_enable',
	));

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'favblog_pro_theme_options[slider_content_page_'. $i .']', array(
		'sanitize_callback' => 'favblog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[slider_content_page_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Select Page: %d', 'favblog-pro'), $i ),
		'section'           => 'favblog_pro_slider_section',
		'choices'			=> favblog_pro_page_choices(),
		'active_callback'	=> 'favblog_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'favblog_pro_theme_options[slider_content_post_'. $i .']', array(
		'sanitize_callback' => 'favblog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[slider_content_post_'. $i .']', array(
		'label'             => sprintf(esc_html__( 'Select Post : %d', 'favblog-pro'), $i ),
		'section'           => 'favblog_pro_slider_section',
		'choices'			=> favblog_pro_post_choices(),
		'active_callback'	=> 'favblog_pro_is_slider_section_content_post_enable',
	) ) );

	//FavBlog_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('favblog_pro_theme_options[slider_separator'. $i .']',array(
       'sanitize_callback'      => 'favblog_pro_sanitize_html',
    ));

    $wp_customize->add_control(new FavBlog_Pro_Customize_Horizontal_Line($wp_customize,'favblog_pro_theme_options[slider_separator'. $i .']',array(
        'active_callback'       => 'favblog_pro_is_slider_section_separator_enable',
        'type'                  =>'hr',
        'section'               =>'favblog_pro_slider_section',
    )));

endfor;

// slider posts drop down chooser control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'favblog_pro_sanitize_single_category',
) );

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'favblog_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Categories', 'favblog-pro' ),
	'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'favblog-pro' ),
	'type'           	=> 'dropdown-taxonomies',
	'section'           => 'favblog_pro_slider_section',
	'active_callback'	=> 'favblog_pro_is_slider_section_content_category_enable',
) ) ); 

//slider_btn_txt
$wp_customize->add_setting('favblog_pro_theme_options[slider_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['slider_btn_txt'],
    )
);

$wp_customize->add_control('favblog_pro_theme_options[slider_btn_txt]',
    array(
        'section'			=> 'favblog_pro_slider_section',
        'label'				=> esc_html__( 'Button Text:', 'favblog-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'favblog_pro_is_slider_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[slider_btn_txt]', array(
		'selector'            => '#featured-slider article div.read-more a:nth-child(1)',
		'settings'            => 'favblog_pro_theme_options[slider_btn_txt]',
		'fallback_refresh'    => true,
		'container_inclusive' => false,
 		'render_callback'     => 'favblog_pro_slider_btn_txt_partial',
    ) );
}

$wp_customize->add_setting( 'favblog_pro_theme_options[style_slider_section_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_slider_section_subtitle_color]', array(
	'label'             => esc_html__( 'Section Sub Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_slider_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_slider_section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_slider_section_title_color]', array(
	'label'             => esc_html__( 'Section Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_slider_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_slider_section_description_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_slider_section_description_color]', array(
	'label'             => esc_html__( 'Description Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_slider_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_slider_section_btn_text_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_slider_section_btn_text_color]', array(
	'label'             => esc_html__( 'Btn Text Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_slider_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_slider_section_btn_bg_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_slider_section_btn_bg_color]', array(
	'label'             => esc_html__( 'Btn Background Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_slider_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_slider_section_btn_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_slider_section_btn_hover_color]', array(
	'label'             => esc_html__( 'Btn Hover Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_slider_section',
	) ) );