<?php

/**
 * Subscription section
 */
// Subscription section
$wp_customize->add_section(
    'favblog_pro_subscription_section',
    array(
        'title'         => esc_html__( 'Subscription', 'favblog-pro' ),
        'description'   => sprintf( esc_html__( '%1$sJetpack%2$s should be active and site should be connected to WordPress.com for this section to work.', 'favblog-pro' ), '<a target="_blank" href="https://wordpress.org/plugins/jetpack">', '</a>' ),
        'panel'         => 'favblog_pro_front_page_panel',
    )
);

// Subscription enable setting
$wp_customize->add_setting(
    'favblog_pro_theme_options[subscription_section_enable]',
    array(
        'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
        'default'           => $options['subscription_section_enable'],
    )
);

$wp_customize->add_control(new FavBlog_Pro_Switch_Control($wp_customize,'favblog_pro_theme_options[subscription_section_enable]',
    array(
        'section'		=> 'favblog_pro_subscription_section',
        'label'			=> esc_html__( 'Enable subscription.', 'favblog-pro' ),
        'on_off_label'  => favblog_pro_switch_options(),

    )
));

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[subscription_section_enable]', array(
		'selector'            => '#subscribe-now .tooltiptext',
		'settings'            => 'favblog_pro_theme_options[subscription_section_enable]',
    ) );
}

// Subscription enable setting
$wp_customize->add_setting(
    'favblog_pro_theme_options[subscription_section_social_menu_enable]',
    array(
        'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
        'default'           => $options['subscription_section_social_menu_enable'],
    )
);

$wp_customize->add_control(new FavBlog_Pro_Switch_Control($wp_customize,'favblog_pro_theme_options[subscription_section_social_menu_enable]',
    array(
        'section'		=> 'favblog_pro_subscription_section',
        'label'			=> esc_html__( 'Enable Social Menu.', 'favblog-pro' ),
        'on_off_label'  => favblog_pro_switch_options(),
        'active_callback'   => 'favblog_pro_if_subscription_enable',

    )
));

// Subscribe title setting
$wp_customize->add_setting(
    'favblog_pro_theme_options[subscription_section_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['subscription_section_sub_title'],
        'transport'	        => 'postMessage',
    )
);

$wp_customize->add_control(
    'favblog_pro_theme_options[subscription_section_sub_title]',
    array(
        'section'		    => 'favblog_pro_subscription_section',
        'label'			    => esc_html__( 'Section Sub Title:', 'favblog-pro' ),
        'active_callback'   => 'favblog_pro_if_subscription_enable',
        'type'              =>'text'
    )
);

$wp_customize->selective_refresh->add_partial(
    'favblog_pro_theme_options[subscription_section_sub_title]',
    array(
        'selector'            => '#subscription-us .section-subtitle',
        'render_callback'     => 'favblog_pro_subscription_section_partial_sub_title',
    )
);

// Subscribe title setting
$wp_customize->add_setting(
    'favblog_pro_theme_options[subscription_section_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['subscription_section_title'],
        'transport'	        => 'postMessage',
    )
);

$wp_customize->add_control(
    'favblog_pro_theme_options[subscription_section_title]',
    array(
        'section'		    => 'favblog_pro_subscription_section',
        'label'			    => esc_html__( 'Section Title:', 'favblog-pro' ),
        'active_callback'   => 'favblog_pro_if_subscription_enable',
        'type'              =>'text'
    )
);

$wp_customize->selective_refresh->add_partial(
    'favblog_pro_theme_options[subscription_section_title]',
    array(
        'selector'            => '#subscription-us .section-title',
        'render_callback'     => 'favblog_pro_subscription_section_partial_title',
    )
);


// Subscribe text setting
$wp_customize->add_setting(
    'favblog_pro_theme_options[subscription_section_description]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['subscription_section_description'],
        'transport'	        => 'postMessage',
    )
);

$wp_customize->add_control(
    'favblog_pro_theme_options[subscription_section_description]',
    array(
        'section'		    => 'favblog_pro_subscription_section',
        'label'			    => esc_html__( 'Description:', 'favblog-pro' ),
        'active_callback'   => 'favblog_pro_if_subscription_enable',
        'type'			    => 'textarea'
    )
);

$wp_customize->selective_refresh->add_partial(
    'favblog_pro_theme_options[subscription_section_description]',
    array(
        'selector'            => '#subscription-us #subscription-text p',
        'render_callback'     => 'favblog_pro_subscription_section_partial_description',
    )
);


// Subscribe button text setting
$wp_customize->add_setting(
    'favblog_pro_theme_options[subscription_section_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['subscription_section_btn_txt'],
    )
);

$wp_customize->add_control(
    'favblog_pro_theme_options[subscription_section_btn_txt]',
    array(
        'section'		    => 'favblog_pro_subscription_section',
        'label'			    => esc_html__( 'Button text:', 'favblog-pro' ),
        'active_callback'   => 'favblog_pro_if_subscription_enable'
    )
);

// Subscribe image setting
$wp_customize->add_setting(
    'favblog_pro_theme_options[subscription_section_bg_image]',
    array(
        'sanitize_callback' => 'favblog_pro_sanitize_image',
        'default'           => $options['subscription_section_bg_image'],
    )
);

$wp_customize->add_control(
    new WP_Customize_Image_Control(
        $wp_customize,
        'favblog_pro_theme_options[subscription_section_bg_image]',
        array(
            'section'		    => 'favblog_pro_subscription_section',
            'label'			    => esc_html__( 'Background image:', 'favblog-pro' ),
            'active_callback'   => 'favblog_pro_if_subscription_enable',
        )
    )
);