<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

// Add Team section
$wp_customize->add_section( 'favblog_pro_team_section', array(
	'title'             => esc_html__( 'Team','favblog-pro' ),
	'description'       => esc_html__( 'Team Section options.', 'favblog-pro' ),
	'panel'             => 'favblog_pro_front_page_panel',
) );

$wp_customize->add_setting('favblog_pro_team_section_setting',array(
	'default' => 'setting',
	'sanitize_callback' => 'favblog_pro_sanitize_select',
));

$wp_customize->add_control('favblog_pro_team_section_setting',array(
	'section'		=> 'favblog_pro_team_section',
	'type'			=> 'radio',
	'active_callback'   => 'favblog_pro_is_team_section_enable',
	'choices'		=> array(
			'setting' => esc_html__( 'Setting', 'favblog-pro' ),
			'style' => esc_html__( 'Style', 'favblog-pro' ),
			)
	));

// Team content enable control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'favblog-pro' ),
	'section'           => 'favblog_pro_team_section',
	'on_off_label' 		=> favblog_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[team_section_enable]', array(
		'selector'            => '#our-team .tooltiptext',
		'settings'            => 'favblog_pro_theme_options[team_section_enable]',
    ) );
}

// team title setting and control
$wp_customize->add_setting( 'favblog_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'favblog_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'favblog-pro' ),
	'section'        	=> 'favblog_pro_team_section',
	'active_callback' 	=> 'favblog_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[team_title]', array(
		'selector'            => '#our-team .business-section-header h2',
		'settings'            => 'favblog_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'favblog_pro_team_title_partial',
    ) );
}

// team description setting and control
$wp_customize->add_setting( 'favblog_pro_theme_options[team_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'favblog_pro_theme_options[team_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'favblog-pro' ),
	'section'        	=> 'favblog_pro_team_section',
	'active_callback' 	=> 'favblog_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[team_sub_title]', array(
		'selector'            => '#our-team .business-section-header p',
		'settings'            => 'favblog_pro_theme_options[team_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'favblog_pro_team_sub_title_partial',
    ) );
}


// Slider number control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_team_count', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'favblog_pro_sanitize_number_range',
	'validate_callback' => 'favblog_pro_validate_team_count',
) );

$wp_customize->add_control( 'favblog_pro_theme_options_team_count', array(
	'label'             => esc_html__( 'Number of Team', 'favblog-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'favblog-pro' ),
	'section'           => 'favblog_pro_team_section',
	'active_callback'   => 'favblog_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// team content type control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[team_column]', array(
	'default'          	=> $options['team_column'],
	'sanitize_callback' => 'favblog_pro_sanitize_select',
) );

$wp_customize->add_control( 'favblog_pro_theme_options[team_column]', array(
	'label'             => esc_html__( 'Column Layout', 'favblog-pro' ),
	'section'           => 'favblog_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'favblog_pro_is_team_section_enable',
	'choices'			=> array( 
		'col-2'		=> esc_html__( 'Two Column', 'favblog-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'favblog-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'favblog-pro' ),
	),
) );

// Team content type control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options_team_content_type', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'favblog_pro_sanitize_select',
) );

$wp_customize->add_control( 'favblog_pro_theme_options_team_content_type', array(
	'label'             => esc_html__( 'Content Type', 'favblog-pro' ),
	'section'           => 'favblog_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'favblog_pro_is_team_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'favblog-pro' ),
		'post' 		=> esc_html__( 'Post', 'favblog-pro' ),
		'category' 	=> esc_html__( 'Category', 'favblog-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'favblog-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'favblog_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'favblog_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new FavBlog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'favblog_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'favblog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'favblog-pro' ),
	'section'           => 'favblog_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'favblog_pro_is_team_section_content_category_enable'
) ) );

for ( $i = 1; $i <= get_theme_mod( 'favblog_pro_theme_options_team_count', $options['team_count'] ); $i++ ) :
	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'favblog_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'favblog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'favblog-pro' ), $i ),
		'section'           => 'favblog_pro_team_section',
		'choices'			=> favblog_pro_page_choices(),
		'active_callback'	=> 'favblog_pro_is_team_section_content_page_enable',
	) ) );

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'favblog_pro_theme_options[team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'favblog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'favblog-pro' ), $i ),
		'section'           => 'favblog_pro_team_section',
		'choices'			=> favblog_pro_post_choices(),
		'active_callback'	=> 'favblog_pro_is_team_section_content_post_enable',
	) ) );

	// team title setting and control
	$wp_customize->add_setting( 'favblog_pro_theme_options[team_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'favblog_pro_theme_options[team_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'favblog-pro' ), $i ),
		'section'        	=> 'favblog_pro_team_section',
		'active_callback' 	=> 'favblog_pro_is_team_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// team position setting and control
	$wp_customize->add_setting( 'favblog_pro_theme_options[team_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'favblog_pro_theme_options[team_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Position %d', 'favblog-pro' ), $i ),
		'section'        	=> 'favblog_pro_team_section',
		'active_callback' 	=> 'favblog_pro_is_team_section_enable',
		'type'				=> 'text',
	) );

	// team image setting and control.
	$wp_customize->add_setting( 'favblog_pro_theme_options[team_image_' . $i . ']', array(
		'sanitize_callback' => 'favblog_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'favblog_pro_theme_options[team_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'favblog-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'favblog-pro' ), 382, 420 ),
			'section'     		=> 'favblog_pro_team_section',
			'active_callback'	=> 'favblog_pro_is_team_section_content_custom_enable',
	) ) );

	// team position setting and control
	$wp_customize->add_setting( 'favblog_pro_theme_options[team_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'favblog_pro_theme_options[team_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'favblog-pro' ), $i ),
		'section'        	=> 'favblog_pro_team_section',
		'active_callback' 	=> 'favblog_pro_is_team_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// team multiple input setting and control
	$wp_customize->add_setting( 'favblog_pro_theme_options[team_social_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new FavBlog_Pro_Multi_Input_Custom_Control( $wp_customize, 'favblog_pro_theme_options[team_social_'. $i .']',
		array(
			'label'           => sprintf( esc_html__( 'Social Link %d', 'favblog-pro' ), $i ),
			'button_text'	  => esc_html__( 'Add Social Link', 'favblog-pro' ),
			'section'         => 'favblog_pro_team_section',
			'active_callback' => 'favblog_pro_is_team_section_enable',
			'type'			  => 'multi-input'
	) ) );

	// team hr setting and control
	$wp_customize->add_setting( 'favblog_pro_theme_options[team_hr_'. $i .']', array(
		'sanitize_callback' => 'favblog_pro_sanitize_html'
	) );

	$wp_customize->add_control( new FavBlog_Pro_Customize_Horizontal_Line( $wp_customize, 'favblog_pro_theme_options[team_hr_'. $i .']',
		array(
			'section'         => 'favblog_pro_team_section',
			'active_callback' => 'favblog_pro_is_team_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;


/**
 * Style
 */
$wp_customize->add_setting( 'favblog_pro_theme_options[style_team_section_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_team_section_subtitle_color]', array(
	'label'             => esc_html__( 'Section SubTitle Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_team_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_team_section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_team_section_title_color]', array(
	'label'             => esc_html__( 'Section Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_team_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_team_position_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_team_position_color]', array(
	'label'             => esc_html__( 'Position Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_team_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_team_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_team_title_color]', array(
	'label'             => esc_html__( 'Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_team_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_team_title_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_team_title_hover_color]', array(
	'label'             => esc_html__( 'Title Hover Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_team_section',
	) ) );

	$wp_customize->add_setting( 'favblog_pro_theme_options[style_team_description_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'refresh'
		) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_team_description_color]', array(
		'label'             => esc_html__( 'Description Color', 'favblog-pro' ),
		'section'           => 'favblog_pro_team_section',
		) ) );