<?php

/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section('favblog_pro_testimonial_section', array(
    'title'         => esc_html__('Testimonials', 'favblog-pro'),
    'description'   => esc_html__('Testimonials Section options.', 'favblog-pro'),
    'panel'         => 'favblog_pro_front_page_panel',
));

$wp_customize->add_setting('favblog_pro_testimonial_section_setting',array(
    'default' => 'setting',
    'sanitize_callback' => 'favblog_pro_sanitize_select',
));

$wp_customize->add_control('favblog_pro_testimonial_section_setting',array(
    'section'	    	=> 'favblog_pro_testimonial_section',
    'type'		    	=> 'radio',
	'active_callback'	=> 'favblog_pro_is_testimonial_section_enable',
       'choices'		=> array(
            'setting' => esc_html__( 'Setting', 'favblog-pro' ),
            'style' => esc_html__( 'Style', 'favblog-pro' ),
            )
    ));

// Testimonial content enable control and setting
$wp_customize->add_setting('favblog_pro_theme_options[testimonial_section_enable]', array(
    'default'           => $options['testimonial_section_enable'],
    'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
));

$wp_customize->add_control(new FavBlog_Pro_Switch_Control($wp_customize, 'favblog_pro_theme_options[testimonial_section_enable]', array(
    'label'         => esc_html__('Testimonial Section Enable', 'favblog-pro'),
    'section'       => 'favblog_pro_testimonial_section',
    'on_off_label'  => favblog_pro_switch_options(),
)));

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'favblog_pro_theme_options[testimonial_section_enable]', array(
		'selector'            => '#testimonial-section .tooltiptext',
		'settings'            => 'favblog_pro_theme_options[testimonial_section_enable]',
    ) );
}

$wp_customize->add_setting( 'favblog_pro_theme_options[testimonial_image]', array(
	'sanitize_callback' => 'favblog_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'favblog_pro_theme_options[testimonial_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'favblog-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'favblog-pro' ), 1350, 385 ),
		'section'     		=> 'favblog_pro_testimonial_section',
		'active_callback'	=> 'favblog_pro_is_testimonial_section_enable',
) ) );

//Testimonial section content control type setting and control
$wp_customize->add_setting('favblog_pro_theme_options_testimonial_content_type', array(
    'default'               => $options['testimonial_content_type'],
    'sanitize_callback'     => 'favblog_pro_sanitize_select',
));

$wp_customize->add_control('favblog_pro_theme_options_testimonial_content_type', array(
    'label'                 => esc_html__('Content Type', 'favblog-pro'),
    'section'               => 'favblog_pro_testimonial_section',
    'type'                  => 'select',
    'active_callback'       => 'favblog_pro_is_testimonial_section_enable',
    'choices'               => array(
            'page' => esc_html__('Page', 'favblog-pro'),
            'post' => esc_html__('Post', 'favblog-pro'),
            'category' => esc_html__('Category', 'favblog-pro'),
        ),
));


// Testimonial post number control and setting
$wp_customize->add_setting('favblog_pro_theme_options_testimonial_count', array(
    'default'               => $options['testimonial_count'],
    'sanitize_callback'     => 'absint',
));

$wp_customize->add_control('favblog_pro_theme_options_testimonial_count', array(
    'label'                 => esc_html__('Number of Posts', 'favblog-pro'),
    'description'           => esc_html__('Please input the number of of post to display and save. Then refresh the page to see the change.', 'favblog-pro'),
    'section'               => 'favblog_pro_testimonial_section',
    'active_callback'       => 'favblog_pro_is_testimonial_section_enable',
    'type'                  => 'number',
));

for ($i = 1; $i <= get_theme_mod( 'favblog_pro_theme_options_testimonial_count', $options['testimonial_count'] ); $i++):
// Testimonial pages drop down chooser control and setting
    $wp_customize->add_setting('favblog_pro_theme_options[testimonial_content_page_' . $i . ']', array(
        'sanitize_callback' => 'favblog_pro_sanitize_page',
    ));

    $wp_customize->add_control(new FavBlog_Pro_Dropdown_Chooser($wp_customize, 'favblog_pro_theme_options[testimonial_content_page_' . $i . ']', array(
        'label'             => sprintf(esc_html__('Select Page : %d', 'favblog-pro'), $i),
        'section'           => 'favblog_pro_testimonial_section',
        'choices'           => favblog_pro_page_choices(),
        'active_callback'   => 'favblog_pro_is_testimonial_section_content_page_enable',
    )));

    // Testimonial posts drop down chooser control and setting
    $wp_customize->add_setting('favblog_pro_theme_options[testimonial_content_post_' . $i . ']', array(
        'sanitize_callback' => 'favblog_pro_sanitize_page',
    ));

    $wp_customize->add_control(new FavBlog_Pro_Dropdown_Chooser($wp_customize, 'favblog_pro_theme_options[testimonial_content_post_' . $i . ']', array(
        'label'             => sprintf(esc_html__('Select Post : %d', 'favblog-pro'), $i),
        'section'           => 'favblog_pro_testimonial_section',
        'choices'           => favblog_pro_post_choices(),
        'active_callback'   => 'favblog_pro_is_testimonial_section_content_post_enable',
    )));
    // Testimonial posts sub title control and setting
    $wp_customize->add_setting('favblog_pro_theme_options[testimonial_post_sub_title_' . $i . ']', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));

    $wp_customize->add_control(new FavBlog_Pro_Dropdown_Chooser($wp_customize, 'favblog_pro_theme_options[testimonial_post_sub_title_' . $i . ']', array(
        'label'             => sprintf(esc_html__('Select Sub Title : %d', 'favblog-pro'), $i),
        'section'           => 'favblog_pro_testimonial_section',
        'active_callback'   => 'favblog_pro_is_testimonial_section_enable',
        'type'              => 'text',
    )));

    //testimonial separator
    $wp_customize->add_setting('favblog_pro_theme_options[testimonial_separator'. $i .']',array(
        'sanitize_callback'      => 'favblog_pro_sanitize_html',
    ));

    $wp_customize->add_control(new FavBlog_Pro_Customize_Horizontal_Line($wp_customize,'favblog_pro_theme_options[testimonial_separator'. $i .']',array(
        'active_callback'       => 'favblog_pro_is_testimonial_section_enable',
        'type'                  =>'hr',
        'section'               =>'favblog_pro_testimonial_section',
    )));

endfor;

// Testimonial category drop down chooser control and setting
$wp_customize->add_setting('favblog_pro_theme_options[testimonial_category]', array(
    'sanitize_callback' => 'favblog_pro_sanitize_single_category',
));

$wp_customize->add_control(new FavBlog_Pro_Dropdown_Taxonomies_Control($wp_customize, 'favblog_pro_theme_options[testimonial_category]', array(
    'label'             => esc_html__('Select Categories', 'favblog-pro'),
    'description'       => esc_html__('Note: Latest selected no of posts will be shown from selected category', 'favblog-pro'),
    'type'              => 'dropdown-taxonomies',
    'section'           => 'favblog_pro_testimonial_section',
    'active_callback'   => 'favblog_pro_is_testimonial_section_content_category_enable',
)));

/**
 * STYLE
 */

$wp_customize->add_setting( 'favblog_pro_theme_options[style_testimonial_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_testimonial_title_color]', array(
	'label'             => esc_html__( 'Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_testimonial_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_testimonial_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_testimonial_subtitle_color]', array(
	'label'             => esc_html__( 'Sub Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_testimonial_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_testimonial_description_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_testimonial_description_color]', array(
	'label'             => esc_html__( 'Description Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_testimonial_section',
	) ) );
