<?php
/**
 * trending_product Section options
 *
 * @package Theme Palace
 * @subpackage Favblog Pro
 * @since Favblog Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
	return;
}
// Add trending_product section
$wp_customize->add_section( 'favblog_pro_trending_product_section', array(
	'title'             => esc_html__( 'Trending Product','favblog-pro' ),
	'description'       => esc_html__( 'Trending Product Section options.', 'favblog-pro' ),
	'panel'             => 'favblog_pro_front_page_panel',
) );

$wp_customize->add_setting('favblog_pro_trending_product_section_setting',array(
	'default' => 'setting',
	'sanitize_callback' => 'favblog_pro_sanitize_select',
));

$wp_customize->add_control('favblog_pro_trending_product_section_setting',array(
	'section'			=> 'favblog_pro_trending_product_section',
	'type'				=> 'radio',
	'active_callback'   => 'favblog_pro_is_trending_product_section_enable',
	'choices'			=> array(
			'setting' => esc_html__( 'Setting', 'favblog-pro' ),
			'style' => esc_html__( 'Style', 'favblog-pro' ),
			)
	));

// trending_product content enable control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[trending_product_section_enable]', array(
	'default'			=> 	$options['trending_product_section_enable'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[trending_product_section_enable]', array(
	'label'             => esc_html__( 'Trending Product Section Enable', 'favblog-pro' ),
	'section'           => 'favblog_pro_trending_product_section',
	'on_off_label' 		=> favblog_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options_trending_product_count', array(
	'default'          	=> $options['trending_product_count'],
	'sanitize_callback' => 'favblog_pro_sanitize_number_range',
	'validate_callback' => 'favblog_pro_validate_trending_product_count',
) );

$wp_customize->add_control( 'favblog_pro_theme_options_trending_product_count', array(
	'label'             => esc_html__( 'Number of Product Per Column', 'favblog-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'favblog-pro' ),
	'section'           => 'favblog_pro_trending_product_section',
	'active_callback'   => 'favblog_pro_is_trending_product_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );


for( $i = 1 ; $i <= 3 ; $i++ ){

	$wp_customize->add_setting( 'favblog_pro_theme_options[trending_product_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new FavBlog_Pro_Customize_Horizontal_Line( $wp_customize, 'favblog_pro_theme_options[trending_product_hr_'. $i .']',
		array(
			'section'         => 'favblog_pro_trending_product_section',
			'active_callback' => 'favblog_pro_is_trending_product_section_enable',
			'type'			  => 'hr'
	) ) );


	$wp_customize->add_setting( 'favblog_pro_theme_options[trending_product_column_'. $i .']', array(
			'sanitize_callback' => 'sanitize_text_field'
		) );

	$wp_customize->add_control( new FavBlog_Pro_Customize_Column( $wp_customize, 'favblog_pro_theme_options[trending_product_column_'. $i .']',
		array(
			'label'			  => esc_html__('Column ', 'favblog-pro').$i,
			'section'         => 'favblog_pro_trending_product_section',
			'active_callback' => 'favblog_pro_is_trending_product_section_enable',
			'type'			  => 'column'
	) ) );

	// trending_product title setting and control
	$wp_customize->add_setting( 'favblog_pro_theme_options[trending_product_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => $options['trending_product_title'],
	) );

	$wp_customize->add_control( 'favblog_pro_theme_options[trending_product_title_'.$i.']', array(
		'label'             => esc_html__( 'Title', 'favblog-pro' ),
		'section'           => 'favblog_pro_trending_product_section',
		'active_callback'   => 'favblog_pro_is_trending_product_section_enable',
		'type'              => 'text',
	) );

	$wp_customize->add_setting( 'favblog_pro_theme_options_trending_product_content_type_'.$i.'', array(
		'default'          	=> 'product',
		'sanitize_callback' => 'favblog_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'favblog_pro_theme_options_trending_product_content_type_'.$i.'', array(
		'label'             => esc_html__( 'Content Type', 'favblog-pro' ),
		'section'           => 'favblog_pro_trending_product_section',
		'type'				=> 'select',
		'active_callback' 	=> 'favblog_pro_is_trending_product_section_enable',
		'choices'			=> favblog_pro_trending_product_content_type(),
	) );

	for ( $j=1 ; $j <= get_theme_mod( 'favblog_pro_theme_options_trending_product_count', $options['trending_product_count'] ); $j++ ) { 
		$wp_customize->add_setting( 'favblog_pro_theme_options[trending_product_content_product_'. $i.$j. ']', array(
			'sanitize_callback' => 'favblog_pro_sanitize_page',
		) );

		$wp_customize->add_control( new FavBlog_Pro_Dropdown_Chooser( $wp_customize, 'favblog_pro_theme_options[trending_product_content_product_' .$i.$j. ']', array(
				'label'             => sprintf( esc_html__( 'Select Product %d', 'favblog-pro' ), $j ),
				'section'           => 'favblog_pro_trending_product_section',
				'choices'			=> favblog_pro_product_choices(),
				'active_callback'	=> 'favblog_pro_is_trending_product_section_content_product_enable_'.$i,

		) ) );
	}

	$wp_customize->add_setting(  'favblog_pro_theme_options[trending_product_content_product_category_'.$i.']', array(
			'sanitize_callback' => 'absint',
		) ) ;

	$wp_customize->add_control( new FavBlog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'favblog_pro_theme_options[trending_product_content_product_category_'.$i.']', array(
		'label'             => esc_html__( 'Select Product Categories', 'favblog-pro' ),
		'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'favblog-pro' ),
		'section'           => 'favblog_pro_trending_product_section',
		'taxonomy'			=> 'product_cat',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'favblog_pro_is_trending_product_section_content_product_category_enable_'.$i,

	) ) );

}

/**
 * Style
 */
$wp_customize->add_setting( 'favblog_pro_theme_options[style_trending_product_column_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_trending_product_column_title_color]', array(
	'label'             => esc_html__( 'Column Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_trending_product_section',
	) ) );


$wp_customize->add_setting( 'favblog_pro_theme_options[style_trending_product_cat_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_trending_product_cat_color]', array(
	'label'             => esc_html__( 'Category Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_trending_product_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_trending_product_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_trending_product_title_color]', array(
	'label'             => esc_html__( 'Title Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_trending_product_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_trending_product_title_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_trending_product_title_hover_color]', array(
	'label'             => esc_html__( 'Title Hover Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_trending_product_section',
	) ) );

$wp_customize->add_setting( 'favblog_pro_theme_options[style_trending_product_price_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'favblog_pro_theme_options[style_trending_product_price_color]', array(
	'label'             => esc_html__( 'Price Color', 'favblog-pro' ),
	'section'           => 'favblog_pro_trending_product_section',
	) ) );

