<?php
/**
 * Archive options
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

// Add archive section
$wp_customize->add_section( 'favblog_pro_archive_section', array(
	'title'             => esc_html__( 'Blog/Archive','favblog-pro' ),
	'description'       => esc_html__( 'Archive section options.', 'favblog-pro' ),
	'panel'             => 'favblog_pro_theme_options_panel',
) );

// Your latest posts title setting and control.
$wp_customize->add_setting( 'favblog_pro_theme_options[your_latest_posts_title]', array(
	'default'           => $options['your_latest_posts_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'favblog_pro_theme_options[your_latest_posts_title]', array(
	'label'             => esc_html__( 'Your Latest Posts Title', 'favblog-pro' ),
	'description'       => esc_html__( 'This option only works if Static Front Page is set to "Your latest posts."', 'favblog-pro' ),
	'section'           => 'favblog_pro_archive_section',
	'type'				=> 'text',
	'active_callback'   => 'favblog_pro_is_latest_posts'
) );

// Archive date meta setting and control.
$wp_customize->add_setting( 'favblog_pro_theme_options[hide_date]', array(
	'default'           => $options['hide_date'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[hide_date]', array(
	'label'             => esc_html__( 'Hide Date', 'favblog-pro' ),
	'section'           => 'favblog_pro_archive_section',
	'on_off_label' 		=> favblog_pro_hide_options(),
) ) );

// Archive author category setting and control.
$wp_customize->add_setting( 'favblog_pro_theme_options[hide_category]', array(
	'default'           => $options['hide_category'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[hide_category]', array(
	'label'             => esc_html__( 'Hide Category', 'favblog-pro' ),
	'section'           => 'favblog_pro_archive_section',
	'on_off_label' 		=> favblog_pro_hide_options(),
) ) );

// Archive author category setting and control.
$wp_customize->add_setting( 'favblog_pro_theme_options[hide_author]', array(
	'default'           => $options['hide_author'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[hide_author]', array(
	'label'             => esc_html__( 'Hide Author', 'favblog-pro' ),
	'section'           => 'favblog_pro_archive_section',
	'on_off_label' 		=> favblog_pro_hide_options(),
) ) );

// Archive author category setting and control.
$wp_customize->add_setting( 'favblog_pro_theme_options[hide_excerpt]', array(
	'default'           => $options['hide_excerpt'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[hide_excerpt]', array(
	'label'             => esc_html__( 'Hide Excerpt', 'favblog-pro' ),
	'section'           => 'favblog_pro_archive_section',
	'on_off_label' 		=> favblog_pro_hide_options(),
) ) );


// Archive author category setting and control.
$wp_customize->add_setting( 'favblog_pro_theme_options[hide_reading_time]', array(
	'default'           => $options['hide_reading_time'],
	'sanitize_callback' => 'favblog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new FavBlog_Pro_Switch_Control( $wp_customize, 'favblog_pro_theme_options[hide_reading_time]', array(
	'label'             => esc_html__( 'Hide Reading Time', 'favblog-pro' ),
	'section'           => 'favblog_pro_archive_section',
	'on_off_label' 		=> favblog_pro_hide_options(),
) ) );

// // Featured content type control and setting
// $wp_customize->add_setting( 'favblog_pro_theme_options[blog_layout_design]', array(
// 	'default'          	=> $options['blog_layout_design'],
// 	'sanitize_callback' => 'favblog_pro_sanitize_select',
// 	//'transport'			=> 'refresh',
// ) );

// $wp_customize->add_control( 'favblog_pro_theme_options[blog_layout_design]', array(
// 	'label'             => esc_html__( 'Layout Design', 'favblog-pro' ),
// 	'section'           => 'favblog_pro_archive_section',
// 	'type'				=> 'select',
// 	'choices'			=> array(
// 		''      	=> esc_html__( 'Default Layout', 'favblog-pro' ),
// 		'list-view' => esc_html__( 'List View Layout', 'favblog-pro' ),
// 		'grid-view' => esc_html__( 'Grid View Layout', 'favblog-pro' ),
// 		),
// ) );

// features content type control and setting
$wp_customize->add_setting( 'favblog_pro_theme_options[blog_column]', array(
	'default'          	=> $options['blog_column'],
	'sanitize_callback' => 'favblog_pro_sanitize_select',
	//'transport'			=> 'refresh',
) );

$wp_customize->add_control( 'favblog_pro_theme_options[blog_column]', array(
	'label'             => esc_html__( 'Column Layout', 'favblog-pro' ),
	'section'           => 'favblog_pro_archive_section',
	'type'				=> 'select',
	'choices'			=> array( 
		'col-1'		=> esc_html__( 'One Column', 'favblog-pro' ),
		'col-2'		=> esc_html__( 'Two Column', 'favblog-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'favblog-pro' ),
	),
) );
