<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function favblog_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'favblog-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function favblog_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'favblog-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function favblog_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'favblog-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function favblog_pro_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'favblog-pro' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

if ( ! function_exists( 'favblog_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function favblog_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'favblog-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'favblog-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'favblog-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'favblog-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'favblog-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'favblog-pro' ),
        );

        $output = apply_filters( 'favblog_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'favblog_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function favblog_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'favblog-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'favblog-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'favblog-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'favblog-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'favblog-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'favblog-pro' ),
        );

        $output = apply_filters( 'favblog_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'favblog_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function favblog_pro_site_layout() {
        $favblog_pro_site_layout = array(
            'wide'          => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout'  => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout'  => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'favblog_pro_site_layout', $favblog_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'favblog_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function favblog_pro_selected_sidebar() {
        $favblog_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'favblog-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'favblog-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'favblog-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'favblog-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'favblog-pro' ),
        );

        $output = apply_filters( 'favblog_pro_selected_sidebar', $favblog_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'favblog_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function favblog_pro_global_sidebar_position() {
        $favblog_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'favblog_pro_global_sidebar_position', $favblog_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'favblog_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function favblog_pro_sidebar_position() {
        $favblog_pro_sidebar_position = array(
            'right-sidebar'         => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'          => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'            => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'    => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'favblog_pro_sidebar_position', $favblog_pro_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'favblog_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function favblog_pro_pagination_options() {
        $favblog_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'favblog-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'favblog-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'favblog-pro' ),
        );

        $output = apply_filters( 'favblog_pro_pagination_options', $favblog_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'favblog_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function favblog_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'favblog-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'favblog-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'favblog-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'favblog-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'favblog-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'favblog-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'favblog-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'favblog-pro' ),
        );
        return apply_filters( 'favblog_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'favblog_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function favblog_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'favblog-pro' ),
            'off'       => esc_html__( 'Disable', 'favblog-pro' )
        );
        return apply_filters( 'favblog_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'favblog_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function favblog_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'favblog-pro' ),
            'off'       => esc_html__( 'No', 'favblog-pro' )
        );
        return apply_filters( 'favblog_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'favblog_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function favblog_pro_sortable_sections() {
        $options = favblog_pro_get_theme_options();
        $sections = array();
        if ( $options['home_layout'] == 'default-design' ) {
            $sections = array(
                'slider'            => esc_html__( 'Slider', 'favblog-pro' ),
                'hero'              => esc_html__( 'Hero Section', 'favblog-pro' ),
                'top_read'          => esc_html__( 'Top Read', 'favblog-pro' ),
                'featured_post'     => esc_html__( 'Featured Post', 'favblog-pro' ),
                'popular_post'      => esc_html__( 'Popular Post', 'favblog-pro' ),
                'about'             => esc_html__( 'About us', 'favblog-pro' ),
                'service'           => esc_html__( 'Service', 'favblog-pro' ),
                'latest_product'    => esc_html__( 'Latest Product', 'favblog-pro' ),
                'cta'               => esc_html__( 'Call to Action', 'favblog-pro' ),
                'popular_product'   => esc_html__( 'Popular Products', 'favblog-pro' ),
                'counter'           => esc_html__( 'Counter', 'favblog-pro' ),
                'product_collection'=> esc_html__( 'Product Collections', 'favblog-pro' ),
                'subscription'      => esc_html__( 'Subscription', 'favblog-pro' ),
                'recent_product'    => esc_html__( 'Recent Product', 'favblog-pro' ),
                'featured_product'  => esc_html__( 'Featured Product', 'favblog-pro' ),
                'trending_product'  => esc_html__( 'Trending Product', 'favblog-pro' ),
                'gallery_slider'    => esc_html__( 'Gallery Slider', 'favblog-pro' ),
                'gallery'           => esc_html__( 'Gallery', 'favblog-pro' ),
                'team'              => esc_html__( 'Team', 'favblog-pro' ),
                'testimonial'       => esc_html__( 'Testimonial', 'favblog-pro' ),
                'recent_post'       => esc_html__( 'Recent Post', 'favblog-pro' ),
                'most_read'         => esc_html__( 'Most Read', 'favblog-pro' ),
            );
        }
        if ( $options['home_layout'] == 'pro-design' ) {
            $sections = array(
                'hero'              => esc_html__( 'Hero Section', 'favblog-pro' ),
                'top_read'          => esc_html__( 'Top Read', 'favblog-pro' ),
                'featured_post'     => esc_html__( 'Featured Post', 'favblog-pro' ),
                'popular_post'      => esc_html__( 'Popular Post', 'favblog-pro' ),
                'subscription'      => esc_html__( 'Subscription', 'favblog-pro' ),
                'recent_post'       => esc_html__( 'Recent Post', 'favblog-pro' ),
                'most_read'         => esc_html__( 'Most Read', 'favblog-pro' ),
            );
        }
        if ( $options['home_layout'] == 'second-design' ) {
            $sections = array(
                'slider'            => esc_html__( 'Slider', 'favblog-pro' ),
                'about'             => esc_html__( 'About us', 'favblog-pro' ),
                'counter'           => esc_html__( 'Counter', 'favblog-pro' ),
                'service'           => esc_html__( 'Service', 'favblog-pro' ),
                'gallery_slider'    => esc_html__( 'Gallery Slider', 'favblog-pro' ),
                'team'              => esc_html__( 'Team', 'favblog-pro' ),
                'testimonial'       => esc_html__( 'Testimonial', 'favblog-pro' ),
                'most_read'         => esc_html__( 'Most Read', 'favblog-pro' ),

            );
        }
        if ( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fifth-design' ||  $options['home_layout'] == 'seventh-design' ) {
            $sections = array(
                'slider'                => esc_html__( 'Slider', 'favblog-pro' ),
                'about'                 => esc_html__( 'About us', 'favblog-pro' ),
                'counter'               => esc_html__( 'Counter', 'favblog-pro' ),
                'service'               => esc_html__( 'Service', 'favblog-pro' ),
                'cta'                   => esc_html__( 'Call to Action', 'favblog-pro' ),
                'gallery_slider'        => esc_html__( 'Gallery Slider', 'favblog-pro' ),
                'gallery'               => esc_html__( 'Gallery', 'favblog-pro' ),
                'team'                  => esc_html__( 'Team', 'favblog-pro' ),
                'testimonial'           => esc_html__( 'Testimonial', 'favblog-pro' ),
                'most_read'             => esc_html__( 'Most read', 'favblog-pro' ),
                
            );
        }
        if ( $options['home_layout'] == 'fourth-design' ) {
            $sections = array(
                'slider'                => esc_html__( 'Slider', 'favblog-pro' ),
                'latest_product'        => esc_html__( 'Latest Product', 'favblog-pro' ),
                'cta'                   => esc_html__( 'Call TO Action', 'favblog-pro' ),
                'popular_product'       => esc_html__( 'Popular Products', 'favblog-pro' ),
                'counter'               => esc_html__( 'Counter', 'favblog-pro' ),
                'product_collection'    => esc_html__( 'Product Collections', 'favblog-pro' ),
                'subscription'          => esc_html__( 'Subscription', 'favblog-pro' ),
                'recent_product'        => esc_html__( 'Recent Product', 'favblog-pro' ),
                'featured_product'      => esc_html__( 'Featured Product', 'favblog-pro' ),
                'trending_product'      => esc_html__( 'Trending Product', 'favblog-pro' ),
                'most_read'             => esc_html__( 'Most read', 'favblog-pro' ),
                
            );
        }
        
        if ( $options['home_layout'] == 'sixth-design' ) {
            $sections = array(
                'slider'                => esc_html__( 'Slider', 'favblog-pro' ),
                'service'               => esc_html__( 'Service', 'favblog-pro' ),
                'counter'               => esc_html__( 'Counter', 'favblog-pro' ),
                'about'                 => esc_html__( 'About us', 'favblog-pro' ),
                'cta'                   => esc_html__( 'Call TO Action', 'favblog-pro' ),
                'gallery_slider'        => esc_html__( 'Gallery Slider', 'favblog-pro' ),
                'gallery'               => esc_html__( 'Gallery', 'favblog-pro' ),
                'team'                  => esc_html__( 'Team', 'favblog-pro' ),
                'testimonial'           => esc_html__( 'Testimonial', 'favblog-pro' ),
                'most_read'             => esc_html__( 'Most read', 'favblog-pro' ),
            );
        }
        return apply_filters( 'favblog_pro_sortable_sections', $sections );
    }
endif;



if ( ! function_exists( 'favblog_pro_featured_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function favblog_pro_featured_product_content_type() {
        $favblog_pro_featured_product_content_type = array(
            'post'            => esc_html__( 'Post', 'favblog-pro' ),
            'page'            => esc_html__( 'Page', 'favblog-pro' ),
        );

        if(class_exists('WooCommerce')){
            $favblog_pro_featured_product_content_type = array_merge($favblog_pro_featured_product_content_type, array(
                'product'            => esc_html__( 'Product', 'favblog-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'favblog-pro' ),
            ) );
        }

        $output = apply_filters( 'favblog_pro_featured_product_content_type', $favblog_pro_featured_product_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'favblog_pro_latest_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function favblog_pro_latest_product_content_type() {
        $favblog_pro_latest_product_content_type = array(
            'product'           => esc_html__( 'Product', 'favblog-pro' ),
            'product-category'   => esc_html__( 'Product Category', 'favblog-pro' ),
        );

        $output = apply_filters( 'favblog_pro_latest_product_content_type', $favblog_pro_latest_product_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'favblog_pro_recent_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function favblog_pro_recent_product_content_type() {
        $favblog_pro_recent_product_content_type = array(
            'product'   => esc_html__( 'Product', 'favblog-pro' ),
            'product-category'   => esc_html__( 'Product Category', 'favblog-pro' ),
        );

        $output = apply_filters( 'favblog_pro_recent_product_content_type', $favblog_pro_recent_product_content_type );

        return $output;
    }
endif;


if ( ! function_exists( 'favblog_pro_popular_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function favblog_pro_popular_product_content_type() {
        $favblog_pro_popular_product_content_type = array(
            'product'   => esc_html__( 'Product', 'favblog-pro' ),
            'product-category'   => esc_html__( 'Product Category', 'favblog-pro' ),
        );

        $output = apply_filters( 'favblog_pro_popular_product_content_type', $favblog_pro_popular_product_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'favblog_pro_trending_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function favblog_pro_trending_product_content_type() {
        $favblog_pro_trending_product_content_type = array(
            'product'   => esc_html__( 'Product', 'favblog-pro' ),
            'product-category'   => esc_html__( 'Product Category', 'favblog-pro' ),
        );

        $output = apply_filters( 'favblog_pro_trending_product_content_type', $favblog_pro_trending_product_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'favblog_pro_product_collection_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function favblog_pro_product_collection_content_type() {
        $favblog_pro_product_collection_content_type = array(
            'post'            => esc_html__( 'Post', 'favblog-pro' ),
            'page'            => esc_html__( 'Page', 'favblog-pro' ),
        );

        if(class_exists('WooCommerce')){
            $favblog_pro_product_collection_content_type = array_merge($favblog_pro_product_collection_content_type, array(
                'product'            => esc_html__( 'Product', 'favblog-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'favblog-pro' ),
            ) );
        }

        $output = apply_filters( 'favblog_pro_product_collection_content_type', $favblog_pro_product_collection_content_type );

        return $output;
    }
endif;