<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_counter_section() {
        $options = favblog_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'favblog_pro_section_status', true, 'counter_section_enable' );

        if ( true !== $counter_enable ) {
            return false;
        }

        // Render counter section now.
        favblog_pro_render_counter_section();
    }
endif;

if ( ! function_exists( 'favblog_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_counter_section() {
        $options = favblog_pro_get_theme_options();
        $image   = empty( $options['counter_image'] ) ? '' : $options['counter_image'] ;
        $counter_count  = get_theme_mod( 'favblog_pro_theme_options_counter_count', $options['counter_count'] );
        $contents = array();

        for( $i= 1; $i <= absint( $counter_count ); $i++ ){
            // $page_post['icon']      = empty( $options['counter_content_icon_'.$i] ) ? '' : $options['counter_content_icon_'.$i] ;
            $page_post['title']     = empty( $options['counter_title_'.$i] ) ? '' :$options['counter_title_'.$i];
            $page_post['number']    = empty( $options['counter_number_'.$i] ) ? '' :$options['counter_number_'.$i];
            if( !empty($page_post['title']) && !empty($page_post['number']) )
                array_push( $contents, $page_post );
        }
        if(empty($contents)) return; ?>

        
    <div id="counter-section" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ) ; ?>');">
        <div class="overlay"></div>
            <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                    <?php favblog_pro_section_tooltip( 'counter-section' ); ?>
                <?php endif; ?>
                <div class="col-4 clear">
                <?php foreach ( $contents as $content ):  ?>
                    
                    <article>
                        <h2 class="counter-value"><?php echo esc_html( $content['number'] ); ?>  </h2>
                        <h3 class="counter-title"><?php echo esc_html( $content['title'] ); ?></h3>
                    </article>
                    <?php endforeach ?>

                </div><!-- .col-4 -->
            </div><!-- .wrapper -->
    </div><!-- #counter-section -->
      

    <?php }
endif;

function favblog_pro_counter_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_counter_btn_bg_color'] ) ): ?>
            #counter-section {
                background-color: <?php echo esc_attr( $options['style_counter_btn_bg_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_counter_title_color'] ) ): ?>
            #counter-section h3.counter-title{
                color: <?php echo esc_attr( $options['style_counter_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_counter_number_color'] ) ): ?>
            #counter-section h2.counter-value{
                color: <?php echo esc_attr( $options['style_counter_number_color'] ); ?>;
           }
       <?php endif; ?>
    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_counter_style' );    