<?php
/**
 * Call To Action section
 *
 * This is the template for the content of Call To Action section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_cta_section' ) ) :
    /**
    * Add Call To Action section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_cta_section() {
        $options = favblog_pro_get_theme_options();
        
        // Check if Call To Action is enabled on frontpage
        $cta_enable = apply_filters( 'favblog_pro_section_status', true, 'cta_section_enable' );

        if ($options['home_layout'] == 'second-design') {
            $cta_enable = false;
        }
        if ( true !== $cta_enable ) {
            return false;
        }

        // Get Call To Action section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_cta_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render Call To Action section now.
        favblog_pro_render_cta_section( $section_details[0] );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_cta_section_details' ) ) :
    /**
    * Call To Action section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input Call To Action section details.
    */
    function favblog_pro_get_cta_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        $cta_content_type  = get_theme_mod( 'favblog_pro_theme_options_cta_content_type', $options['cta_content_type'] );

        $content = array();
        switch ( $cta_content_type ) {
        	
            case 'page':
                $page_id = ! empty( $options['cta_content_page'] ) ? $options['cta_content_page'] : '';
                $args = array(
                    'post_type'             => 'page',
                    'posts_per_page'        => 1,
                    'p'                     => $page_id,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'post':
                $page_id = ! empty( $options['cta_content_post'] ) ? $options['cta_content_post'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'p'                     => $page_id,
                    'posts_per_page'        => 1,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = isset( $options['cta_category'] ) ? $options['cta_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
                break;

            default:
            break;
        }
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = favblog_pro_trim_content( 30 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;

// Call To Action section content details.
add_filter( 'favblog_pro_filter_cta_section_details', 'favblog_pro_get_cta_section_details' );


if ( ! function_exists( 'favblog_pro_render_cta_section' ) ) :
  /**
   * Start Call To Action section
   *
   * @return string Call To Action content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_cta_section( $content_details = array() ) {
        $options    = favblog_pro_get_theme_options();
        $btn_label  = $options['cta_read_more'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="call-to-action" class="relative page-section" style="background-image: url('<?php echo $content_details['image']; ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                    <?php favblog_pro_section_tooltip( 'call-to-action' ); ?>
                <?php endif; ?>
                <header class="entry-header">
                    <h2 class="entry-title"><?php echo esc_html($content_details['title']); ?></h2>
                </header>

                <div class="entry-content">
                    <p><?php echo wp_kses_post( $content_details['excerpt'] ); ?></p>
                </div><!-- .entry-content -->

            <?php if ( !empty( $btn_label ) ): ?>
                <div class="read-more">
                    <a href="<?php echo esc_url($content_details['url']); ?>" class="btn"><?php echo esc_html($btn_label); ?></a>
                </div>
            <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #call-to-action -->

    <?php }
endif;

function favblog_pro_cta_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_cta_title_color'] ) ): ?>
            #call-to-action h2.entry-title{
                color: <?php echo esc_attr( $options['style_cta_title_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_cta_description_color'] ) ): ?>
            #call-to-action .entry-content{
                color: <?php echo esc_attr( $options['style_cta_description_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_cta_btn_bg_color'] ) ): ?>
            #call-to-action .btn{
                background-color: <?php echo esc_attr( $options['style_cta_btn_bg_color'] ); ?>;
                border: <?php echo esc_attr( $options['style_cta_btn_bg_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_cta_btn_text_color'] ) ): ?>
            #call-to-action .btn{
                color: <?php echo esc_attr( $options['style_cta_btn_text_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_cta_btn_hover_color'] ) ): ?>
            #call-to-action .btn:hover{
                background-color: <?php echo esc_attr( $options['style_cta_btn_hover_color'] ); ?>;
                border: <?php echo esc_attr( $options['style_cta_btn_hover_color'] ); ?>;
           }
       <?php endif; ?>
    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_cta_style' );    