<?php
/**
 * Product section
 *
 * This is the template for the content of featured_product section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_featured_product_section' ) ) :
    /**
    * Add featured_product section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_featured_product_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if featured_product is enabled on frontpage
        $featured_product_enable = apply_filters( 'favblog_pro_section_status', true, 'featured_product_section_enable' );

        if ( !in_array( $options['home_layout'], array('default-design', 'fourth-design') ) ) {
            $featured_product_enable = false;
        }
        if ( true !== $featured_product_enable ) {
            return false;
        }
        // Get featured_product section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_featured_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured_product section now.
        favblog_pro_render_featured_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_featured_product_section_details' ) ) :
    /**
    * featured_product section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input featured_product section details.
    */
    function favblog_pro_get_featured_product_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $featured_product_content_type  = get_theme_mod( 'favblog_pro_theme_options_featured_product_content_type', $options['featured_product_content_type'] );
        $featured_product_count = get_theme_mod( 'favblog_pro_theme_options_featured_product_count', $options['featured_product_count'] );
        
        $content = array();
        $content = array();
        switch ( $featured_product_content_type ) {


            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_product_count; $i++ ) {
                    if ( ! empty( $options['featured_product_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_product_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_product_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'  => true,
                    );                    
            break;

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_product_count; $i++ ) {
                    if ( ! empty( $options['featured_product_content_product_' . $i] ) )
                        $page_ids[] = $options['featured_product_content_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_product_count ),
                    'orderby'           => 'post__in',
                    );
            break;
            
            case 'product-category':
                $cat_id = ! empty( $options['featured_product_content_product_category'] ) ? $options['featured_product_content_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $featured_product_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = favblog_pro_trim_content( 10 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured_product section content details.
add_filter( 'favblog_pro_filter_featured_product_section_details', 'favblog_pro_get_featured_product_section_details' );


if ( ! function_exists( 'favblog_pro_render_featured_product_section' ) ) :
  /**
   * Start featured_product section
   *
   * @return string featured_product content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_featured_product_section( $content_details = array() ) {
        $options = favblog_pro_get_theme_options();
        $featured_product_content_type  = get_theme_mod( 'favblog_pro_theme_options_featured_product_content_type', $options['featured_product_content_type'] );

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
            <div id="featured-products" class="relative page-section same-background">
                <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                    <?php favblog_pro_section_tooltip( 'featured-products' ); ?>
                <?php endif; ?>
                    <div class="section-content clear col-2">
                    <?php foreach ( $content_details as $content ): 
                        if(in_array($featured_product_content_type, array('product', 'product-category'))) $featured_product = new WC_Product( $content['id'] ) ;  ?>
                        <article>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <div class="overlay"></div>
                                <div class="entry-container">
                                    <span class="cat-links">
                                        <?php echo in_array($featured_product_content_type, array('product', 'product-category')) ? wc_get_product_category_list($content['id']) :  the_category( ', ', '', $content['id'] ); ?>
                                    </span><!-- .cat-links -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url($content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->

                                    <?php if ( !empty( $options['featured_product_btn_title'] ) ): ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html( $options['featured_product_btn_title'] ); ?></a>
                                    </div><!-- .read-more -->
                                    <?php endif; ?>
                                </div><!-- .entry-container -->
                            </div><!-- .featured-image -->
                        </article>
                    <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #featured-products -->
    <?php }
endif;

function favblog_pro_featured_product_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_featured_product_cat_color'] ) ): ?>
            #featured-products .cat-links a{
                color: <?php echo esc_attr( $options['style_featured_product_cat_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_featured_product_cat_hover_color'] ) ): ?>
            #featured-products .cat-links a:hover{
                color: <?php echo esc_attr( $options['style_featured_product_cat_hover_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_featured_product_title_color'] ) ): ?>
            #featured-products .entry-title a{
                color: <?php echo esc_attr( $options['style_featured_product_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_featured_product_title_hover_color'] ) ): ?>
            #featured-products .entry-title a:hover{
                color: <?php echo esc_attr( $options['style_featured_product_title_hover_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_featured_product_description_color'] ) ): ?>
            #featured-products .entry-content{
                color: <?php echo esc_attr( $options['style_featured_product_description_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_featured_product_btn_bg_color'] ) ): ?>
             #featured-products .btn{
                background-color: <?php echo esc_attr( $options['style_featured_product_btn_bg_color'] ); ?>;
                border: <?php echo esc_attr( $options['style_featured_product_btn_bg_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_featured_product_btn_text_color'] ) ): ?>
             #featured-products .btn{
                color: <?php echo esc_attr( $options['style_featured_product_btn_text_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_featured_product_btn_hover_color'] ) ): ?>
             #featured-products .btn:hover{
                background-color: <?php echo esc_attr( $options['style_featured_product_btn_hover_color'] ); ?>;
                border: <?php echo esc_attr( $options['style_featured_product_btn_hover_color'] ); ?>;
           }
       <?php endif; ?>
    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_featured_product_style' );    