<?php
/**
 * Gallery Slider section
 *
 * This is the template for the content of gallery_slider section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_gallery_slider_section' ) ) :
    /**
    * Add gallery_slider section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_gallery_slider_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if gallery_slider is enabled on frontpage
        $gallery_slider_enable = apply_filters( 'favblog_pro_section_status', true, 'gallery_slider_section_enable' );
        
        if ( in_array( $options['home_layout'], array('fourth-design') )  ) {
            $gallery_slider_enable = false;
        }

        if ( true !== $gallery_slider_enable ) {
            return false;
        }
        // Get gallery_slider section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_gallery_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render gallery_slider section now.
        favblog_pro_render_gallery_slider_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_gallery_slider_section_details' ) ) :
    /**
    * gallery_slider section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input gallery_slider section details.
    */
    function favblog_pro_get_gallery_slider_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $gallery_slider_content_type  = get_theme_mod( 'favblog_pro_theme_options_gallery_slider_content_type', $options['gallery_slider_content_type'] );
        $gallery_slider_count = get_theme_mod( 'favblog_pro_theme_options_gallery_slider_count', $options['gallery_slider_count'] );

        $content = array();
        switch ( $gallery_slider_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $gallery_slider_count; $i++ ) {
                    if ( ! empty( $options['gallery_slider_content_page_' . $i] ) )
                        $page_ids[] = $options['gallery_slider_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $gallery_slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $gallery_slider_count; $i++ ) {
                    if ( ! empty( $options['gallery_slider_content_post_' . $i] ) )
                        $post_ids[] = $options['gallery_slider_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $gallery_slider_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['gallery_slider_content_category'] ) ? $options['gallery_slider_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $gallery_slider_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']            = get_the_id();
                $page_post['author_id']     = get_post_field('post_author', get_the_ID());
                $page_post['title']         = get_the_title();
                $page_post['excerpt']       = favblog_pro_trim_content( 20 );
                $page_post['url']           = get_the_permalink();
                $page_post['image']         = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// gallery_slider section content details.
add_filter( 'favblog_pro_filter_gallery_slider_section_details', 'favblog_pro_get_gallery_slider_section_details' );


if ( ! function_exists( 'favblog_pro_render_gallery_slider_section' ) ) :
  /**
   * Start gallery_slider section
   *
   * @return string gallery_slider content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_gallery_slider_section( $content_details = array() ) {
        $options = favblog_pro_get_theme_options();
        $gallery_slider_video_url = (!empty($options['gallery_slider_video_url'])) ? $options['gallery_slider_video_url'] : '#';
        if ( empty( $content_details ) ) {
            return;
        } ?>
        
            <div id="gallery-slider-section" class="relative page-section">
                <?php if ( is_customize_preview()): ?>
                    <?php favblog_pro_section_tooltip( 'gallery-slider-section' ); ?>
                <?php endif; ?>
                <div class="section-header">
                    <?php if( !empty( $options['gallery_slider_title'] || !empty($options['gallery_slider_sub_title'])) ):
                        echo ($options['gallery_slider_sub_title']) ? sprintf( '<p class="section-subtitle">%s</p>',  esc_html( $options['gallery_slider_sub_title'] ) ) : ''; 
                        echo ($options['gallery_slider_title']) ? sprintf( '<h2 class="section-title">%s</h2>',  esc_html( $options['gallery_slider_title'] ) ) : ''; ?>
                    <?php endif; ?>
                </div><!-- .section-header -->

                <div class="wrapper">
                    <div class="gallery-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": false, "draggable": true, "fade": false }'>
                        <?php foreach($content_details as $content ): ?>
                        <article style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <div class="entry-container">
                                <?php if(!empty($gallery_slider_video_url)) : ?>
                                    <div class="video-button">
                                        <a href="<?php echo esc_url($gallery_slider_video_url); ?>" class="popup-video">
                                            <svg viewBox="0 0 320.001 320.001" class="icon icon-play">
                                                <path d="M295.84,146.049l-256-144c-4.96-2.784-11.008-2.72-15.904,0.128C19.008,5.057,16,10.305,16,16.001v288
                                                c0,5.696,3.008,10.944,7.936,13.824c2.496,1.44,5.28,2.176,8.064,2.176c2.688,0,5.408-0.672,7.84-2.048l256-144
                                                c5.024-2.848,8.16-8.16,8.16-13.952S300.864,148.897,295.84,146.049z"/>
                                            </svg>
                                        </a>
                                    </div><!-- .video-button -->
                                <?php endif; ?>

                                <div class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </div><!-- .entry-header -->
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; ?>
                    </div><!-- .gallery-slider -->
                </div><!-- .wrapper -->
            </div><!-- #gallery-slider-section -->


    <?php 
    }    
endif;


function favblog_pro_gallery_slider_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_gallery_slider_section_title_color'] ) ): ?>
           #gallery-slider-section h2.section-title{
                color: <?php echo esc_attr( $options['style_gallery_slider_section_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_gallery_slider_section_subtitle_color'] ) ): ?>
            #gallery-slider-section p.section-subtitle{
                color: <?php echo esc_attr( $options['style_gallery_slider_section_subtitle_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_gallery_slider_title_color'] ) ): ?>
            #gallery-slider-section h2.entry-title a{
                color: <?php echo esc_attr( $options['style_gallery_slider_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_gallery_slider_icon_border_color'] ) ): ?>
            #gallery-slider-section .video-button a{
                color: <?php echo esc_attr( $options['style_gallery_slider_icon_border_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_gallery_slider_icon_color'] ) ): ?>
            #gallery-slider-section .video-button svg{
                color: <?php echo esc_attr( $options['style_gallery_slider_icon_color'] ); ?>;
           }
       <?php endif; ?>
    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_gallery_slider_style' );    