<?php
/**
 * Gallery section
 *
 * This is the template for the content of gallery section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_gallery_section' ) ) :
    /**
    * Add gallery section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_gallery_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if gallery is enabled on frontpage
        $gallery_enable = apply_filters( 'favblog_pro_section_status', true, 'gallery_section_enable' );

        if (in_array( $options['home_layout'], array('second-design', 'fourth-design') )  ) {
            $gallery_enable = false;
        }

        if ( true !== $gallery_enable  ) {
            return false;
        }
        // Get gallery section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_gallery_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render gallery section now.
        favblog_pro_render_gallery_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_gallery_section_details' ) ) :
    /**
    * gallery section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input gallery section details.
    */
    function favblog_pro_get_gallery_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $gallery_content_type  = get_theme_mod( 'favblog_pro_theme_options_gallery_content_type', $options['gallery_content_type'] );
        $gallery_count = get_theme_mod( 'favblog_pro_theme_options_gallery_count', $options['gallery_count'] );

        $content = array();
        switch ( $gallery_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_page_' . $i] ) )
                        $page_ids[] = $options['gallery_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_post_' . $i] ) )
                        $post_ids[] = $options['gallery_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['gallery_content_category'] ) ? $options['gallery_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $gallery_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']            = get_the_id();
                $page_post['author_id']     = get_post_field('post_author', get_the_ID());
                $page_post['title']         = get_the_title();
                $page_post['excerpt']       = favblog_pro_trim_content( 20 );
                $page_post['url']           = get_the_permalink();
                $page_post['image']         = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// gallery section content details.
add_filter( 'favblog_pro_filter_gallery_section_details', 'favblog_pro_get_gallery_section_details' );


if ( ! function_exists( 'favblog_pro_render_gallery_section' ) ) :
  /**
   * Start gallery section
   *
   * @return string gallery content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_gallery_section( $content_details = array() ) {
        $options = favblog_pro_get_theme_options();
        $gallery_content_type  = get_theme_mod( 'favblog_pro_theme_options_gallery_content_type', $options['gallery_content_type'] );

        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="our-gallery" class="page-section">
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                        <?php favblog_pro_section_tooltip( 'our-gallery' ); ?>
                    <?php endif; ?>
                    <div class="section-header">
                    <?php if( !empty( $options['gallery_title'] || !empty($options['gallery_sub_title'])) ):
                        echo ($options['gallery_sub_title']) ? sprintf( '<p class="section-subtitle">%s</p>',  esc_html( $options['gallery_sub_title'] ) ) : ''; 
                        echo ($options['gallery_title']) ? sprintf( '<h2 class="section-title">%s</h2>',  esc_html( $options['gallery_title'] ) ) : ''; ?>
                    <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="section-content col-3 clear">
                        <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="gallery-item-wrapper">
                                <div class="overlay"></div>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                </div><!-- .featured-image -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>
                            </div><!-- .gallery-item-wrapper -->
                        </article>
                        <?php endforeach; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>

    <?php 
    }    
endif;

function favblog_pro_gallery_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_gallery_section_title_color'] ) ): ?>
           #our-gallery h2.section-title{
                color: <?php echo esc_attr( $options['style_gallery_section_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_gallery_section_subtitle_color'] ) ): ?>
            #our-gallery p.section-subtitle{
                color: <?php echo esc_attr( $options['style_gallery_section_subtitle_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_gallery_title_color'] ) ): ?>
            #our-gallery h2.entry-title a{
                color: <?php echo esc_attr( $options['style_gallery_title_color'] ); ?>;
           }
       <?php endif; ?>
    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_gallery_style' );  
