<?php
/**
 * Latest Product section
 *
 * This is the template for the content of latest_product section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_latest_product_section' ) ) :
    /**
    * Add latest_product section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_latest_product_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if latest_product is enabled on frontpage
        $latest_product_enable = apply_filters( 'favblog_pro_section_status', true, 'latest_product_section_enable' );

        if ( !in_array( $options['home_layout'], array('default-design', 'fourth-design') ) ) {
            $latest_product_enable = false;
        }
        if ( !$latest_product_enable) {
            return false;
        }

        // Get latest_product section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_latest_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Render latest_product section now.
        favblog_pro_render_latest_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_latest_product_section_details' ) ) :
    /**
    * latest_product section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input latest_product section details.
    */
    function favblog_pro_get_latest_product_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $latest_product_content_type  = get_theme_mod( 'favblog_pro_theme_options_latest_product_content_type', $options['latest_product_content_type'] );
        $latest_product_count = get_theme_mod( 'favblog_pro_theme_options_latest_product_count', $options['latest_product_count'] );

        
        $content = array();
        $args = array();
        switch ( $latest_product_content_type ) {


            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $latest_product_count; $i++ ) {
                    if ( ! empty( $options['latest_product_content_product_' . $i] ) )
                        $page_ids[] = $options['latest_product_content_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $latest_product_count ),
                    'orderby'           => 'post__in',
                    );
            break;
            
            case 'product-category':
                $cat_id = ! empty( $options['latest_product_content_product_category'] ) ? $options['latest_product_content_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $latest_product_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = favblog_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// latest_product section content details.
add_filter( 'favblog_pro_filter_latest_product_section_details', 'favblog_pro_get_latest_product_section_details' );


if ( ! function_exists( 'favblog_pro_render_latest_product_section' ) ) :
  /**
   * Start latest_product section
   *
   * @return string latest_product content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_latest_product_section( $content_details = array() ) {
        $options = favblog_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
      
            <div id="latest-products" class="relative page-section same-background">
                <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                    <?php favblog_pro_section_tooltip( 'latest-products' ); ?>
                <?php endif; ?>
                    <div class="col-2 clear">
                        <?php foreach ( $content_details as $content ): ?>
                        <article>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ?>');">
                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><?php echo esc_html( $content['title'] ) ?></h2>
                                    </header>
                                </div><!-- .entry-container -->
                            </div><!-- .featured-image -->
                        </article>
                        <?php endforeach; ?>

                    </div><!-- .grid --> 
                </div><!-- .wrapper -->
            </div><!-- #latest-products -->

    <?php }
endif;

function favblog_pro_latest_product_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_latest_product_section_title_color'] ) ): ?>
            #latest-products h2.entry-title{
                color: <?php echo esc_attr( $options['style_latest_product_section_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_latest_product_section_title_bg_color'] ) ): ?>
            #latest-products .entry-container{
                background-color: <?php echo esc_attr( $options['style_latest_product_section_title_bg_color'] ); ?>;
           }
       <?php endif; ?>
    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_latest_product_style' );    