<?php
/**
 * Most Read section
 *
 * This is the template for the content of most_read section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_most_read_section' ) ) :
    /**
    * Add most_read section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_most_read_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if most_read is enabled on frontpage
        $most_read_enable = apply_filters( 'favblog_pro_section_status', true, 'most_read_section_enable' );

        if ( true !== $most_read_enable ) {
            return false;
        }
        // Get most_read section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_most_read_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render most_read section now.
        favblog_pro_render_most_read_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_most_read_section_details' ) ) :
    /**
    * most_read section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input most_read section details.
    */
    function favblog_pro_get_most_read_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $most_read_content_type  = get_theme_mod( 'favblog_pro_theme_options_most_read_content_type', $options['most_read_content_type'] );
        $most_read_count = get_theme_mod( 'favblog_pro_theme_options_most_read_count', $options['most_read_count'] );
        
        $content = array();
        switch ( $most_read_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $most_read_count; $i++ ) {
                    if ( ! empty( $options['most_read_content_page_' . $i] ) )
                        $page_ids[] = $options['most_read_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $most_read_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $most_read_count; $i++ ) {
                    if ( ! empty( $options['most_read_content_post_' . $i] ) )
                        $post_ids[] = $options['most_read_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $most_read_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['most_read_content_category'] ) ? $options['most_read_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $most_read_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['author_id'] = get_post_field('post_author', get_the_ID());
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = favblog_pro_trim_content( 20 );
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// most_read section content details.
add_filter( 'favblog_pro_filter_most_read_section_details', 'favblog_pro_get_most_read_section_details' );


if ( ! function_exists( 'favblog_pro_render_most_read_section' ) ) :
  /**
   * Start most_read section
   *
   * @return string most_read content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_most_read_section( $content_details = array() ) {
        $options = favblog_pro_get_theme_options();
        $most_read_content_type  = $options['most_read_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="most-read-posts" class="relative page-section same-background">
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                        <?php favblog_pro_section_tooltip( 'most-read-posts' ); ?>
                    <?php endif; ?>
                    <div class="section-header">
                        <?php if( !empty( $options['most_read_title'] || !empty($options['most_read_sub_title'])) ):
                            echo ($options['most_read_sub_title']) ? sprintf( '<p class="section-subtitle">%s</p>',  esc_html( $options['most_read_sub_title'] ) ) : ''; 
                            echo ($options['most_read_title']) ? sprintf( '<h2 class="section-title">%s</h2>',  esc_html( $options['most_read_title'] ) ) : ''; ?>
                        <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="section-content col-4 clear">
                        <?php foreach ( $content_details as $content ) : ?>

                            <article>
                                <div class="most-read-post-wrapper">
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link" title="<?php echo esc_attr($content['title']); ?>"></a>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <span class="cat-links">
                                            <?php the_category( ', ', '', $content['id'] ); ?>

                                        </span><!-- .cat-links -->

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="admin-profile">
                                            <div class="admin-image">
                                                <a href="#"><img src="<?php echo get_avatar_url($content['author_id'],['size' => '70']); ?>" alt="admin"></a>
                                            </div><!-- .admin-image -->

                                            <div class="admin-container">
                                                <div class="admin-header">
                                                    <h2 class="admin-name"><a href="<?php echo esc_url( get_author_posts_url( $content['author_id']) ); ?>"><?php echo get_the_author_meta('display_name', $content['author_id']); ?></a></h2>
                                                </div><!-- .admin-header -->

                                                <div class="entry-meta">
                                                    <span class="posted-on">
                                                        <?php favblog_pro_posted_on($content['id']); ?>
                                                        
                                                    <span class="reading-time"><?php echo favblog_pro_reading_time($content['id']); ?></span>
                                                </div><!-- .entry-meta -->
                                            </div><!-- .entry-container -->
                                        </div><!-- .admin-profile -->
                                    </div><!-- .entry-container -->
                                </div><!-- .most-read-post-wrapper -->
                            </article>
                        <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #most-read-posts -->
    <?php 
    }    
endif;


function favblog_pro_most_read_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_most_read_section_title_color'] ) ): ?>
           #most-read-posts h2.section-title{
                color: <?php echo esc_attr( $options['style_most_read_section_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_most_read_section_subtitle_color'] ) ): ?>
           #most-read-posts P.section-subtitle{
                color: <?php echo esc_attr( $options['style_most_read_section_subtitle_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_most_read_cat_color'] ) ): ?>
            #most-read-posts .cat-links a{
                color: <?php echo esc_attr( $options['style_most_read_cat_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_most_read_cat_hover_color'] ) ): ?>
            #most-read-posts .cat-links a:hover{
                color: <?php echo esc_attr( $options['style_most_read_cat_hover_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_most_read_title_color'] ) ): ?>
            #most-read-posts .entry-title a,
            #most-read-posts .admin-profile .admin-name a {
                color: <?php echo esc_attr( $options['style_most_read_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_most_read_title_hover_color'] ) ): ?>
            #most-read-posts .entry-title a:hover,
            #most-read-posts .admin-profile .admin-name a:hover {
                color: <?php echo esc_attr( $options['style_most_read_title_hover_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_most_read_description_color'] ) ): ?>
            #most-read-posts .posted-on a,
            #most-read-posts span.reading-time {
                color: <?php echo esc_attr( $options['style_most_read_description_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_most_read_date_hover_color'] ) ): ?>
            #most-read-posts .posted-on a:hover {
                color: <?php echo esc_attr( $options['style_most_read_date_hover_color'] ); ?>;
           }
       <?php endif; ?>

    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_most_read_style' );    