<?php
/**
 * Popular Post section
 *
 * This is the template for the content of popular_post section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_popular_post_section' ) ) :
    /**
    * Add popular_post section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_popular_post_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if popular_post is enabled on frontpage
        $popular_post_enable = apply_filters( 'favblog_pro_section_status', true, 'popular_post_section_enable' );

        if (!in_array($options['home_layout'], array('default-design', 'pro-design'))) {

            $popular_post_enable = false;
        }
        if ( true !== $popular_post_enable ) {
            return false;
        }
        // Get popular_post section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_popular_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render popular_post section now.
        favblog_pro_render_popular_post_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_popular_post_section_details' ) ) :
    /**
    * popular_post section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input popular_post section details.
    */
    function favblog_pro_get_popular_post_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $popular_post_content_type  = get_theme_mod( 'favblog_pro_theme_options_popular_post_content_type', $options['popular_post_content_type'] );
        $popular_post_count = get_theme_mod( 'favblog_pro_theme_options_popular_post_count', $options['popular_post_count'] );
        
        $content = array();
        switch ( $popular_post_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_post_count; $i++ ) {
                    if ( ! empty( $options['popular_post_content_page_' . $i] ) )
                        $page_ids[] = $options['popular_post_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_post_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $popular_post_count; $i++ ) {
                    if ( ! empty( $options['popular_post_content_post_' . $i] ) )
                        $post_ids[] = $options['popular_post_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $popular_post_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['popular_post_content_category'] ) ? $options['popular_post_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_post_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['author_id']     = get_post_field('post_author', get_the_ID());
                $page_post['excerpt']   = favblog_pro_trim_content( 20 );
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_post section content details.
add_filter( 'favblog_pro_filter_popular_post_section_details', 'favblog_pro_get_popular_post_section_details' );


if ( ! function_exists( 'favblog_pro_render_popular_post_section' ) ) :
  /**
   * Start popular_post section
   *
   * @return string popular_post content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_popular_post_section( $content_details = array() ) {
        $options = favblog_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="popular-posts" class="relative page-section same-background">
                <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                    <?php favblog_pro_section_tooltip( 'popular-posts' ); ?>
                <?php endif; ?>
                    <div class="section-header">
                        <?php if( !empty( $options['popular_post_title'] || !empty($options['popular_post_sub_title'])) ):
                            echo ($options['popular_post_sub_title']) ? sprintf( '<p class="section-subtitle">%s</p>',  esc_html( $options['popular_post_sub_title'] ) ) : ''; 
                            echo ($options['popular_post_title']) ? sprintf( '<h2 class="section-title">%s</h2>',  esc_html( $options['popular_post_title'] ) ) : ''; ?>
                        <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="section-content col-3 clear">
                    <?php foreach ( $content_details as $content ) : ?>

                        <article>
                            <div class="popular-post-wrapper">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link" title="<?php echo esc_attr($content['title']); ?>"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <span class="cat-links">
                                        <?php the_category( ', ', '', $content['id'] ); ?>
                                    </span><!-- .cat-links -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="admin-profile">
                                        <div class="admin-image">
                                            <a href="#"><img src="<?php echo get_avatar_url($content['author_id'], ['size' => '70']); ?>" alt="admin"></a>
                                        </div><!-- .admin-image -->

                                        <div class="admin-container">
                                            <div class="admin-header">
                                                <h2 class="admin-name"><a href="<?php echo esc_url( get_author_posts_url( $content['author_id']) ); ?>"><?php echo get_the_author_meta('display_name', $content['author_id']); ?></a></h2>
                                            </div><!-- .admin-header -->

                                            <div class="entry-meta">
                                                <?php favblog_pro_posted_on($content['id']); ?>
                                                <span class="reading-time"><?php echo favblog_pro_reading_time($content['id']) . esc_html__( ' read', 'favblog-pro' ); ?></span>
                                            </div><!-- .entry-meta -->
                                        </div><!-- .entry-container -->
                                    </div><!-- .admin-profile -->
                                </div><!-- .entry-container -->
                            </div><!-- .popular-post-wrapper -->
                        </article>
                    <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #popular-posts -->
    <?php 
    }    
endif;

function favblog_pro_popular_post_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_popular_post_section_subtitle_color'] ) ): ?>
            #popular-posts p.section-subtitle{
                color: <?php echo esc_attr( $options['style_popular_post_section_subtitle_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_popular_post_section_title_color'] ) ): ?>
            #popular-posts h2.section-title{
                color: <?php echo esc_attr( $options['style_popular_post_section_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_popular_post_title_color'] ) ): ?>
            #popular-posts .entry-title a{
                color: <?php echo esc_attr( $options['style_popular_post_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_popular_post_hover_color'] ) ): ?>
            #popular-posts .cat-links a:hover,
            #popular-posts .posted-on a:hover,
            #popular-posts .entry-title a:hover,
            #popular-posts .admin-profile .admin-name:hover{
                color: <?php echo esc_attr( $options['style_popular_post_hover_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_popular_post_description_color'] ) ): ?>
            #popular-posts .posted-on a,
            #popular-posts .cat-links a,
            #popular-posts span.reading-time,
            #popular-posts .admin-profile .admin-name{
                color: <?php echo esc_attr( $options['style_popular_post_description_color'] ); ?>;
           }
       <?php endif; ?>
    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_popular_post_style' );    