<?php
/**
 * Product section
 *
 * This is the template for the content of popular_product section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_popular_product_section' ) ) :
    /**
    * Add popular_product section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_popular_product_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if popular_product is enabled on frontpage
        $popular_product_enable = apply_filters( 'favblog_pro_section_status', true, 'popular_product_section_enable' );

        if ( !in_array( $options['home_layout'], array('default-design', 'fourth-design') )  ) {
            $popular_product_enable = false;
        }

        if ( true !== $popular_product_enable) {
            return false;
        }
        // Get popular_product section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_popular_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Render popular_product section now.
        favblog_pro_render_popular_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_popular_product_section_details' ) ) :
    /**
    * popular_product section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input popular_product section details.
    */
    function favblog_pro_get_popular_product_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $popular_product_content_type  = get_theme_mod( 'favblog_pro_theme_options_popular_product_content_type', $options['popular_product_content_type'] );
        $popular_product_count = get_theme_mod( 'favblog_pro_theme_options_popular_product_count', $options['popular_product_count'] );
        
        $content = array();
        switch ( $popular_product_content_type ) {

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $popular_product_count; $i++ ) {
                    if ( ! empty( $options['popular_product_content_post_' . $i] ) )
                        $post_ids[] = $options['popular_product_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $popular_product_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_product_count; $i++ ) {
                    if ( ! empty( $options['popular_product_content_product_' . $i] ) )
                        $page_ids[] = $options['popular_product_content_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_product_count ),
                    'orderby'           => 'post__in',
                );
            break;
            
            case 'product-category':
                $cat_id = ! empty( $options['popular_product_content_product_category'] ) ? $options['popular_product_content_product_category'] : '';
                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $popular_product_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = favblog_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_product section content details.
add_filter( 'favblog_pro_filter_popular_product_section_details', 'favblog_pro_get_popular_product_section_details' );


if ( ! function_exists( 'favblog_pro_render_popular_product_section' ) ) :
  /**
   * Start popular_product section
   *
   * @return string popular_product content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_popular_product_section( $content_details = array() ) {
        $options = favblog_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

            <div id="popular-products" class="relative page-section same-background">
                <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                    <?php favblog_pro_section_tooltip( 'popular-products' ); ?>
                <?php endif; ?>
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html( $options['popular_product_subtitle'] ); ?></p>
                        <h2 class="section-title"><?php echo esc_html( $options['popular_product_title'] ); ?></h2>
                    </div><!-- .section-header -->

                    <div class="section-content">
                        <ul class="products columns-4 product-slider" data-slick='{"slidesToShow": 4, "slidesToScroll": 4, "infinite": false, "speed": 1500, "dots": true, "arrows": true, "autoplay": false, "draggable": true, "fade": false }'>
                        <?php foreach ( $content_details as $content ): $popular_product = new WC_Product( $content['id'] ); ?>
                            
                            <li class="product first sale featured-products">
                                <a href="<?php echo esc_url($content['url'] ); ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                <?php 
                                    if($popular_product->is_on_sale()) echo sprintf('<span class="onsale">%s</span>', esc_html__( 'Sale!', 'favblog-pro' )); 
                                ?>
                                    <img width="330" height="400" src="<?php echo esc_url( $content['image'] ) ?>">
                                    <div class="product_meta">
                                        <span class="posted_in">
                                            <?php echo wc_get_product_category_list($content['id']); ?>
                                        </span><!-- .posted_in -->
                                    </div><!-- .product-meta -->
                                    <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ); ?></h2>
                                    <span class="price">    
                                        <?php  echo $popular_product->get_price_html(); ?>
                                    </span>
                                </a>
                                <?php if ( !empty( $options['popular_product_btn_title'] ) ): ?>
                                    <a href="<?php echo $popular_product->add_to_cart_url(); ?>" class="button product_type_simple add_to_cart_button ajax_add_to_cart"><?php echo esc_html( $options['popular_product_btn_title'] ); ?></a>
                                <?php endif ?>
                            </li>
                            <?php endforeach; ?>

                        </ul><!-- .product-slider -->
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #popular-products -->

    <?php }
endif;                                                                                                                                                                                          


function favblog_pro_popular_product_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_popular_product_section_subtitle_color'] ) ): ?>
            #popular-products p.section-subtitle{
                color: <?php echo esc_attr( $options['style_popular_product_section_subtitle_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_popular_product_section_title_color'] ) ): ?>
            #popular-products h2.section-title{
                color: <?php echo esc_attr( $options['style_popular_product_section_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_popular_product_cat_color'] ) ): ?>
            #popular-products .cat-links a{
                color: <?php echo esc_attr( $options['style_popular_product_cat_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_popular_product_cat_hover_color'] ) ): ?>
            #popular-products .cat-links a:hover{
                color: <?php echo esc_attr( $options['style_popular_product_cat_hover_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_popular_product_title_color'] ) ): ?>
            #popular-products .entry-title a{
                color: <?php echo esc_attr( $options['style_popular_product_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_popular_product_title_hover_color'] ) ): ?>
            #popular-products .entry-title a:hover{
                color: <?php echo esc_attr( $options['style_popular_product_title_hover_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_popular_product_price_color'] ) ): ?>
            #popular-products .entry-content{
                color: <?php echo esc_attr( $options['style_popular_product_price_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_popular_product_btn_bg_color'] ) ): ?>
            #popular-products .btn{
                background-color: <?php echo esc_attr( $options['style_popular_product_btn_bg_color'] ); ?>;
                border: <?php echo esc_attr( $options['style_popular_product_btn_bg_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_popular_product_btn_text_color'] ) ): ?>
            #popular-products .btn{
                color: <?php echo esc_attr( $options['style_popular_product_btn_text_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_popular_product_btn_hover_color'] ) ): ?>
            #popular-products .btn:hover{
                background-color: <?php echo esc_attr( $options['style_popular_product_btn_hover_color'] ); ?>;
                border: <?php echo esc_attr( $options['style_popular_product_btn_hover_color'] ); ?>;
           }
       <?php endif; ?>
    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_popular_product_style' );    