<?php
/**
 * Product section
 *
 * This is the template for the content of product_collection section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_product_collection_section' ) ) :
    /**
    * Add product_collection section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_product_collection_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if product_collection is enabled on frontpage
        $product_collection_enable = apply_filters( 'favblog_pro_section_status', true, 'product_collection_section_enable' );

        if ( !in_array( $options['home_layout'], array('default-design', 'fourth-design') )  ) {
            $product_collection_enable = false;
        }
        if ( true !== $product_collection_enable) {
            return false;
        }
        // Get product_collection section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_product_collection_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render product_collection section now.
        favblog_pro_render_product_collection_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_product_collection_section_details' ) ) :
    /**
    * product_collection section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input product_collection section details.
    */
    function favblog_pro_get_product_collection_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $product_collection_content_type  = get_theme_mod( 'favblog_pro_theme_options_product_collection_content_type', $options['product_collection_content_type'] );
        $product_collection_count = get_theme_mod( 'favblog_pro_theme_options_product_collection_count', $options['product_collection_count'] );
        
        $content = array();
        switch ( $product_collection_content_type ) {


            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $product_collection_count; $i++ ) {
                    if ( ! empty( $options['product_collection_content_post_' . $i] ) )
                        $post_ids[] = $options['product_collection_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $product_collection_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'  => true,
                    );                    
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $product_collection_count; $i++ ) {
                    if ( ! empty( $options['product_collection_content_page_' . $i] ) )
                        $page_ids[] = $options['product_collection_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $product_collection_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $product_collection_count; $i++ ) {
                    if ( ! empty( $options['product_collection_content_product_' . $i] ) )
                        $page_ids[] = $options['product_collection_content_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $product_collection_count ),
                    'orderby'           => 'post__in',
                    );
            break;
            
            case 'product-category':
                $cat_id = ! empty( $options['product_collection_content_product_category'] ) ? $options['product_collection_content_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $product_collection_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
                $args = array(
                    'post_type'             => 'post',
                    'ignore_sticky_posts'   => true,
                    );
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = favblog_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// product_collection section content details.
add_filter( 'favblog_pro_filter_product_collection_section_details', 'favblog_pro_get_product_collection_section_details' );


if ( ! function_exists( 'favblog_pro_render_product_collection_section' ) ) :
  /**
   * Start product_collection section
   *
   * @return string product_collection content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_product_collection_section( $content_details = array() ) {
        $options = favblog_pro_get_theme_options();
        $product_collection_content_type  = get_theme_mod( 'favblog_pro_theme_options_product_collection_content_type', $options['product_collection_content_type'] );
        
        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <div id="products-collection" class="relative page-section same-background">
            <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                    <?php favblog_pro_section_tooltip( 'products-collection' ); ?>
                <?php endif; ?>
                <div class="section-header">
                    <p class="section-subtitle"><?php echo esc_html( $options['product_collection_subtitle'] ); ?></p>
                    <h2 class="section-title"><?php echo esc_html( $options['product_collection_title'] ); ?></h2>
                </div><!-- .section-header -->

                <div class="section-content grid col-2">
                <?php foreach ( $content_details as $content ):
                    if(in_array($product_collection_content_type, array('product', 'product-category'))) $product_collection = new WC_Product( $content['id'] ) ;  ?>

                    <article class="grid-item">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <div class="entry-container">
                                <span class="cat-links">
                                    <ul class="post-categories">
                                       <?php echo in_array($product_collection_content_type, array('product', 'product-category')) ? wc_get_product_category_list($content['id']) :  the_category( ', ', '', $content['id'] ); ?>
                                    </ul>
                                </span><!-- .cat-links -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <?php if ( !empty( $options['product_collection_btn_title'] )): ?>
                                    <div class="read-more">
                                        <a href="<?php echo $content['url']; ?>" class="btn"><?php echo esc_html( $options['product_collection_btn_title'] ); ?></a>
                                    </div><!-- .read-more -->
                                <?php endif; ?>
                            </div><!-- .entry-container -->
                        </div><!-- .featured-image -->
                    </article>
                    <?php endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #products-collection -->

    <?php }
endif;

function favblog_pro_product_collection_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_product_collection_section_subtitle_color'] ) ): ?>
            #products-collection p.section-subtitle{
                color: <?php echo esc_attr( $options['style_product_collection_section_subtitle_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_product_collection_section_title_color'] ) ): ?>
            #products-collection h2.section-title{
                color: <?php echo esc_attr( $options['style_product_collection_section_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_product_collection_cat_color'] ) ): ?>
            #products-collection .cat-links a{
                color: <?php echo esc_attr( $options['style_product_collection_cat_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_product_collection_cat_hover_color'] ) ): ?>
            #products-collection .cat-links a:hover{
                color: <?php echo esc_attr( $options['style_product_collection_cat_hover_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_product_collection_title_color'] ) ): ?>
            #products-collection .entry-title a{
                color: <?php echo esc_attr( $options['style_product_collection_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_product_collection_title_hover_color'] ) ): ?>
            #products-collection .entry-title a:hover{
                color: <?php echo esc_attr( $options['style_product_collection_title_hover_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_product_collection_btn_bg_color'] ) ): ?>
             #products-collection .btn{
                background-color: <?php echo esc_attr( $options['style_product_collection_btn_bg_color'] ); ?>;
                border: <?php echo esc_attr( $options['style_product_collection_btn_bg_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_product_collection_btn_text_color'] ) ): ?>
             #products-collection .btn{
                color: <?php echo esc_attr( $options['style_product_collection_btn_text_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_product_collection_btn_hover_color'] ) ): ?>
             #products-collection .btn:hover{
                background-color: <?php echo esc_attr( $options['style_product_collection_btn_hover_color'] ); ?>;
                border: <?php echo esc_attr( $options['style_product_collection_btn_hover_color'] ); ?>;
           }
       <?php endif; ?>
    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_product_collection_style' );    