<?php
/**
 * Featured Post section
 *
 * This is the template for the content of recent_post section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_recent_post_section' ) ) :
    /**
    * Add recent_post section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_recent_post_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if recent_post is enabled on frontpage
        $recent_post_enable = apply_filters( 'favblog_pro_section_status', true, 'recent_post_section_enable' );
        
        if (!in_array($options['home_layout'], array('default-design', 'pro-design'))) {
            $recent_post_enable = false;
        }
        if ( true !== $recent_post_enable ) {
            return false;
        }
        // Get recent_post section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_recent_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render recent_post section now.
        favblog_pro_render_recent_post_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_recent_post_section_details' ) ) :
    /**
    * recent_post section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input recent_post section details.
    */
    function favblog_pro_get_recent_post_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $recent_post_content_type  = get_theme_mod( 'favblog_pro_theme_options_recent_post_content_type', $options['recent_post_content_type'] );
        $recent_post_count = get_theme_mod( 'favblog_pro_theme_options_recent_post_count', $options['recent_post_count'] );
 
        $content = array();
        switch ( $recent_post_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $recent_post_count; $i++ ) {
                    if ( ! empty( $options['recent_post_content_page_' . $i] ) )
                        $page_ids[] = $options['recent_post_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $recent_post_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $recent_post_count; $i++ ) {
                    if ( ! empty( $options['recent_post_content_post_' . $i] ) )
                        $post_ids[] = $options['recent_post_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $recent_post_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['recent_post_content_category'] ) ? $options['recent_post_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $recent_post_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']            = get_the_id();
                $page_post['author_id']     = get_post_field('post_author', get_the_ID());
                $page_post['title']         = get_the_title();
                $page_post['excerpt']       = (has_excerpt( get_the_ID() )) ? get_the_excerpt() : favblog_pro_trim_content( 20 );
                $page_post['url']           = get_the_permalink();
                $page_post['image']         = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// recent_post section content details.
add_filter( 'favblog_pro_filter_recent_post_section_details', 'favblog_pro_get_recent_post_section_details' );


if ( ! function_exists( 'favblog_pro_render_recent_post_section' ) ) :
  /**
   * Start recent_post section
   *
   * @return string recent_post content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_recent_post_section( $content_details = array() ) {
        $options = favblog_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="content-wrapper" class="page-section">
            <div class="wrapper">
                <div id="primary" class="content-area">
                    <main id="main" class="site-main" role="main">
                        <div id="most-recent-posts" class="archive-blog-wrapper">
                            <?php if ( is_customize_preview()): ?>
                                <?php favblog_pro_section_tooltip( 'most-recent-posts' ); ?>
                            <?php endif; ?>
                            <div class="section-header">
                                <?php if( !empty( $options['recent_post_title'] || !empty($options['recent_post_sub_title'])) ):
                                    echo ($options['recent_post_sub_title']) ? sprintf( '<p class="section-subtitle">%s</p>',  esc_html( $options['recent_post_sub_title'] ) ) : ''; 
                                    echo ($options['recent_post_title']) ? sprintf( '<h2 class="section-title">%s</h2>',  esc_html( $options['recent_post_title'] ) ) : ''; ?>
                                <?php endif; ?>
                            </div><!-- .section-header -->

                            <div class="col-2 clear">
                                <?php $i=1; foreach ( $content_details as $content ) : 
                                    $class = $i%3 == 0 ? 'full-width' : '';
                                ?>

                                    <article class="<?php echo $class ?> ">
                                        <div class="popular-post-wrapper">
                                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image']); ?>');">
                                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link" title="<?php echo esc_attr($content['title']); ?>"></a>
                                            </div><!-- .featured-image -->

                                            <div class="entry-container">
                                                <span class="cat-links">
                                                    <?php the_category( ', ', '', $content['id'] ); ?>
                                                </span><!-- .cat-links -->

                                                <header class="entry-header">
                                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                                </header>

                                                <div class="entry-content">
                                                    <P><?php echo wp_kses_post( $content['excerpt'] ); ?></P>
                                                </div><!-- .entry-content -->

                                                <div class="admin-profile">
                                                    <?php if ( !empty($class) ): ?>
                                                        <div class="admin-image">
                                                            <a href="#"><img src="<?php echo get_avatar_url($content['author_id'],['size' => '70']); ?>" alt="admin"></a>
                                                        </div><!-- .admin-image -->
                                                    <?php endif ?>
                                                    <div class="admin-container">
                                                        <div class="admin-header">
                                                            <h2 class="admin-name"><a href="<?php echo esc_url( get_author_posts_url( $content['author_id']) ); ?>"><?php echo get_the_author_meta('display_name', $content['author_id']); ?></a></h2>
                                                        </div><!-- .admin-header -->

                                                        <div class="entry-meta">
                                                            <?php favblog_pro_posted_on($content['id']); ?>
                                                            
                                                            <span class="reading-time"><?php echo favblog_pro_reading_time($content['id']) . esc_html__( ' read', 'favblog-pro' ); ?></span>
                                                        </div><!-- .entry-meta -->
                                                    </div><!-- .entry-container -->
                                                </div><!-- .admin-profile -->
                                            </div><!-- .entry-container -->
                                        </div><!-- .popular-post-wrapper -->
                                    </article>
                                <?php $i++; endforeach; ?>
                            </div><!-- .col-2 -->
                        </div><!-- .archive-blog-wrapper -->
                    </main><!-- #main -->
                </div><!-- #primary -->
                <?php if(is_active_sidebar( 'main-section-sidebar' )) : ?>
                    <aside id="secondary" class="widget-area" role="complementary">
                        <?php  dynamic_sidebar( 'main-section-sidebar' ); ?>
                    </aside><!-- #secondary -->
                <?php endif ; ?>
            </div><!-- .wrapper -->
        </div><!-- #content-wrapper -->
    <?php 
    }    
endif;

function favblog_pro_recent_post_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_recent_post_section_title_color'] ) ): ?>
           #most-recent-posts h2.section-title{
                color: <?php echo esc_attr( $options['style_recent_post_section_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_recent_post_section_subtitle_color'] ) ): ?>
           #most-recent-posts P.section-subtitle{
                color: <?php echo esc_attr( $options['style_recent_post_section_subtitle_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_recent_post_cat_color'] ) ): ?>
            #most-recent-posts .cat-links a{
                color: <?php echo esc_attr( $options['style_recent_post_cat_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_recent_post_cat_hover_color'] ) ): ?>
            #most-recent-posts .cat-links a:hover{
                color: <?php echo esc_attr( $options['style_recent_post_cat_hover_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_recent_post_title_color'] ) ): ?>
            #most-recent-posts .entry-title a,
            #most-recent-posts .admin-profile .admin-name a {
                color: <?php echo esc_attr( $options['style_recent_post_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_recent_post_title_hover_color'] ) ): ?>
            #most-recent-posts .entry-title a:hover,
            #most-recent-posts .admin-profile .admin-name a:hover {
                color: <?php echo esc_attr( $options['style_recent_post_title_hover_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_recent_post_description_color'] ) ): ?>
            #most-recent-posts .entry-content {
                color: <?php echo esc_attr( $options['style_recent_post_description_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_recent_post_date_time_color'] ) ): ?>
            #most-recent-posts .posted-on a,
            #most-recent-posts span.reading-time {
                color: <?php echo esc_attr( $options['style_recent_post_date_time_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_recent_post_date_hover_color'] ) ): ?>
            #most-recent-posts .posted-on a:hover {
                color: <?php echo esc_attr( $options['style_recent_post_date_hover_color'] ); ?>;
           }
       <?php endif; ?>

    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_recent_post_style' );    