<?php
/**
 * Product section
 *
 * This is the template for the content of recent_product section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_recent_product_section' ) ) :
    /**
    * Add recent_product section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_recent_product_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if recent_product is enabled on frontpage
        $recent_product_enable = apply_filters( 'favblog_pro_section_status', true, 'recent_product_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'fourth-design' ) ) ) {
            $recent_product_enable = false;
        }

        if ( true !== $recent_product_enable ) {
            return false;
        }
        // Get recent_product section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_recent_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Render recent_product section now.
        favblog_pro_render_recent_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_recent_product_section_details' ) ) :
    /**
    * recent_product section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input recent_product section details.
    */
    function favblog_pro_get_recent_product_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $recent_product_content_type  = get_theme_mod( 'favblog_pro_theme_options_recent_product_content_type', $options['recent_product_content_type'] );
        $recent_product_count = get_theme_mod( 'favblog_pro_theme_options_recent_product_count', $options['recent_product_count'] );
 
        
        $content = array();
        $args = array();
        switch ( $recent_product_content_type ) {


            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $recent_product_count; $i++ ) {
                    if ( ! empty( $options['recent_product_content_recent_product_' . $i] ) )
                        $page_ids[] = $options['recent_product_content_recent_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $recent_product_count ),
                    'orderby'           => 'post__in',
                    );
            break;
            
            case 'product-category':
                $cat_id = ! empty( $options['recent_product_content_recent_product_category'] ) ? $options['recent_product_content_recent_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $recent_product_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = favblog_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// recent_product section content details.
add_filter( 'favblog_pro_filter_recent_product_section_details', 'favblog_pro_get_recent_product_section_details' );


if ( ! function_exists( 'favblog_pro_render_recent_product_section' ) ) :
  /**
   * Start recent_product section
   *
   * @return string recent_product content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_recent_product_section( $content_details = array() ) {
        $options = favblog_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
      
            <div id="recent-products" class="relative page-section same-background">
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                        <?php favblog_pro_section_tooltip( 'recent-products' ); ?>
                    <?php endif; ?>
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html( $options['recent_product_subtitle'] ); ?></p>
                        <h2 class="section-title"><?php echo esc_html( $options['recent_product_title'] ); ?></h2>
                    </div><!-- .section-header -->

                    <div class="section-content">
                        <ul class="products col-4">
                        <?php foreach ( $content_details as $content ): $recent_product = new WC_Product( $content['id'] ); ?>

                            <li class="product featured-products">
                                <a href="<?php echo esc_url( $content['url'] ) ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                <?php 
                                    if($recent_product->is_on_sale()) echo sprintf('<span class="onsale">%s</span>', esc_html__( 'Sale!', 'favblog-pro' )); 
                                ?>
                                    <img width="330" height="400" src="<?php echo esc_url( $content['image'] ); ?>">
                                    <div class="product_meta">
                                        <span class="posted_in">
                                            <?php echo wc_get_product_category_list($content['id']); ?>
                                        </span><!-- .posted_in -->
                                    </div><!-- .product-meta -->
                                    <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ) ?></h2>

                                    <span class="price">
                                    <?php 
                                        echo $recent_product->get_price_html();
                                    ?>
                                    </span>
                                </a>
                                <?php if ( !empty( $options['recent_product_btn_title'] ) ): ?>
                                    <a href="<?php echo $recent_product->add_to_cart_url(); ?>" class="button product_type_simple add_to_cart_button ajax_add_to_cart"><?php echo esc_html( $options['recent_product_btn_title'] ); ?></a>
                                <?php endif ?>
                            </li>
                        <?php endforeach; ?>
    
                        </ul><!-- .product-slider -->
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #recent-products -->


    <?php }
endif;