<?php
/**
 * Services section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_service_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'favblog_pro_section_status', true, 'service_section_enable' );

        if ( !in_array( $options['home_layout'], array('default-design', 'second-design', 'third-design', 'fifth-design', 'sixth-design', 'seventh-design', 'eighth-design') ) ) {
            $service_enable = false;
        }

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        favblog_pro_render_service_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input service section details.
    */
    function favblog_pro_get_service_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $service_content_type  = get_theme_mod( 'favblog_pro_theme_options_service_content_type', $options['service_content_type'] );
        $service_posts_count = get_theme_mod( 'favblog_pro_theme_options_service_count', $options['service_posts_count'] );

        $content = array();
        $icons = array();
        switch ( $service_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $service_posts_count; $i++ ) {
                    if ( ! empty( $options['service_content_page_' . $i] ) ) :
                        $page_ids[] = $options['service_content_page_' . $i];
                    endif;
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $service_posts_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $service_posts_count; $i++ ) {
                    if ( ! empty( $options['service_content_post_' . $i] ) ){
                        $post_ids[] = $options['service_content_post_' . $i];
                    }
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $service_posts_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['service_content_category'] ) ? $options['service_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $service_posts_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = favblog_pro_trim_content(20);
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'favblog_pro_filter_service_section_details', 'favblog_pro_get_service_section_details' );


if ( ! function_exists( 'favblog_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_service_section( $content_details = array() ) {
        $options    = favblog_pro_get_theme_options();
        $sub_title  = $options['service_section_sub_title'];
        $title      = isset($options['service_section_title']) ? $options['service_section_title']: '';
       if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="our-services" class="relative page-section">
            <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                    <?php favblog_pro_section_tooltip( 'our-services' ); ?>
                <?php endif; ?>
                <div class="section-header">
                    <p class="section-subtitle"><?php echo esc_html($sub_title); ?></p>
                    <h2 class="section-title"><?php echo esc_html($title); ?></h2>
                </div><!-- .section-header -->

                <div class="section-content col-3 clear">
                <?php 
                    foreach ( $content_details as $i=>$content ) : ?>
                    <article>
                        <div class="service-item-wrapper">
                            <div class="icon-container">
                                <a href="<?php echo esc_url($content['url']); ?>">
                                    <i class="fab fa <?php echo esc_attr( !empty( $options['service_content_icon_' . ($i+1)] ) ? $options['service_content_icon_' . ($i+1)] : 'fa-podcast' ); ?>"></i>
                                </a>
                            </div><!-- .icon-container -->
                            
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content['excerpt'] )?></p>
                            </div><!-- .entry-content -->
                        </div><!-- service-item-wrapper -->
                    </article>
                    <?php endforeach; ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #our-services -->
    <?php
    }    
endif; 

function favblog_pro_service_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_service_section_subtitle_color'] ) ): ?>
            #our-services p.section-subtitle{
                color: <?php echo esc_attr( $options['style_service_section_subtitle_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_service_section_title_color'] ) ): ?>
            #our-services h2.section-title{
                color: <?php echo esc_attr( $options['style_service_section_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_service_icon_color'] ) ): ?>
            #our-services .icon-container a{
                color: <?php echo esc_attr( $options['style_service_icon_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_service_icon_hover_color'] ) ): ?>
            #our-services .icon-container a:hover{
                color: <?php echo esc_attr( $options['style_service_icon_hover_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_service_title_color'] ) ): ?>
            #our-services h2.entry-title{
                color: <?php echo esc_attr( $options['style_service_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_service_title_hover_color'] ) ): ?>
            #our-services h2.entry-title:hover{
                color: <?php echo esc_attr( $options['style_service_title_hover_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_service_description_color'] ) ): ?>
            #our-services .entry-content p{
                color: <?php echo esc_attr( $options['style_service_description_color'] ); ?>;
           }
       <?php endif; ?>
    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_service_style' );   ?>
