<?php
/**
 * Banner section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_slider_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'favblog_pro_section_status', true, 'slider_section_enable' );

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        favblog_pro_render_slider_section( $section_details );
}

endif;

if ( ! function_exists( 'favblog_pro_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input slider section details.
    */
    function favblog_pro_get_slider_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $slider_content_type    = get_theme_mod( 'favblog_pro_theme_options_slider_content_type', $options['slider_content_type'] );
        $slider_count           = get_theme_mod( 'favblog_pro_theme_options_slider_count', $options['slider_count'] );
        
        $content = array();
        switch ( $slider_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_page_' . $i] ) )
                        $page_ids[] = $options['slider_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_post_' . $i] ) )
                        $post_ids[] = $options['slider_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $slider_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['slider_content_category'] ) ? $options['slider_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $slider_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = favblog_pro_trim_content( 30 );
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
            $i++;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'favblog_pro_filter_slider_section_details', 'favblog_pro_get_slider_section_details' );


if ( ! function_exists( 'favblog_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_slider_section( $content_details = array() ) {
        $options = favblog_pro_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="featured-slider-section" class="slider-section">
                <div class="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": <?php echo (bool) $options['slider_autoplay_enable']; ?>, "draggable": true, "fade": true, "adaptiveHeight": true }'>
                   <?php foreach ( $content_details as $key => $content ) : ?>
                    <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                        <div class="overlay"></div>
                        <div class="wrapper">
                            <div class="featured-content-wrapper">
                            <?php if ( is_customize_preview()): ?>
                                <?php favblog_pro_section_tooltip( 'featured-slider-section' ); ?>
                            <?php endif; ?>
                                <div class="entry-container">
                                    <header class="entry-header">
                                        <p class="section-subtitle"><?php echo esc_html( isset($options['slider_section_sub_title_'.($key+1)]) ? $options['slider_section_sub_title_'.($key+1)] : $options['slider_section_sub_title']  ); ?></p>
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->

                                    <div class="read-more">
                                        <?php if(!empty($options['slider_btn_txt'])) echo sprintf( '<a href="%s" class="btn">%s</a>', esc_url($content['url']), esc_html($options['slider_btn_txt']) ); ?>
                                    </div><!-- .read-more -->
                                </div><!-- .entry-container -->
                            </div><!-- .featured-content-wrapper -->
                        </div><!-- .wrapper -->
                    </article>
                    <?php endforeach; ?>
                </div><!-- .featured-slider -->
            </div><!-- #featured-slider-section -->
    <?php
    }    
endif;

function favblog_pro_slider_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_slider_section_title_color'] ) ): ?>
           #featured-slider-section h2.entry-title a{
                color: <?php echo esc_attr( $options['style_slider_section_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_slider_section_subtitle_color'] ) ): ?>
            .featured-content-wrapper .section-subtitle{
                color: <?php echo esc_attr( $options['style_slider_section_subtitle_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_slider_section_description_color'] ) ): ?>
            .featured-content-wrapper .entry-content p{
                color: <?php echo esc_attr( $options['style_slider_section_description_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_slider_section_btn_text_color'] ) ): ?>
            #featured-slider-section .btn{
                color: <?php echo esc_attr( $options['style_slider_section_btn_text_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_slider_section_btn_bg_color'] ) ): ?>
            #featured-slider-section .btn{
                background-color: <?php echo esc_attr( $options['style_slider_section_btn_bg_color'] ); ?>;
                border: <?php echo esc_attr( $options['style_slider_section_btn_bg_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_slider_section_btn_hover_color'] ) ): ?>
            #featured-slider-section .btn:hover{
                background-color: <?php echo esc_attr( $options['style_slider_section_btn_hover_color'] ); ?>;
                border: <?php echo esc_attr( $options['style_slider_section_btn_hover_color'] ); ?>;
           }
       <?php endif; ?>
    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_slider_style' );    