<?php
/**
 * Subscription section
 *
 * This is the template for the content of subscription section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_subscription_section' ) ) :
    /**
    * Add subscription section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_subscription_section() {
        $options = favblog_pro_get_theme_options();
         if ( ! class_exists( 'Jetpack' ) ) {
            return;
        } elseif ( class_exists( 'Jetpack' ) ) {
            if ( ! Jetpack::is_module_active( 'subscriptions' ) )
                return;
        }

        // Check if subscription is enabled on frontpage
        $subscription_enable = apply_filters( 'favblog_pro_section_status', true, 'subscription_section_enable' );

        if ( !in_array( $options['home_layout'], array('default-design', 'pro-design', 'fourth-design') )  ) {
            $subscription_enable = false;
        }
        if ( true !== $subscription_enable ) {
            return false;
        }
        // Render subscription section now.
        favblog_pro_render_subscription_section();
    }
endif;

if ( ! function_exists( 'favblog_pro_render_subscription_section' ) ) :
  /**
   * Start subscription section
   *
   * @return string subscription content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_subscription_section() {
        $options = favblog_pro_get_theme_options(); ?>
        <div id="subscribe-now" class="relative page-section same-background" >
            <div class="wrapper" style="background-image: url(<?php echo esc_url($options['subscription_section_bg_image']); ?>);">
              <?php if ( is_customize_preview()): ?>
                  <?php favblog_pro_section_tooltip( 'subscribe-now' ); ?>
              <?php endif ?>
               <div class="section-header">
                   <?php if ( ! empty($options['subscription_section_sub_title'])) : ?>
                       <p class="section-subtitle"><?php echo esc_html($options['subscription_section_sub_title']); ?></p>
                   <?php endif; ?>
                   <?php if ( ! empty($options['subscription_section_title'])) : ?>
                       <h2 class="section-title"><?php echo esc_html($options['subscription_section_title']); ?></h2>
                   <?php endif;

                    if($options['subscription_section_social_menu_enable'] && has_nav_menu( 'social' )):
                        
                        wp_nav_menu(  array(
                            'theme_location' => 'social',
                            'container' => 'div',
                            'container_class' => 'social-icons',
                            'echo' => true,
                            'depth' => 1,
                            'link_before' => '<span class="screen-reader-text">',
                            'link_after' => '</span>',
                            'fallback_cb' => false,
                        ) );
                        
                    endif; ?>
               </div><!-- section-header  -->
                <div class="subscribe-form-wrapper">
                    <?php $subscription_shortcode = '[jetpack_subscription_form title="" subscribe_button="' . esc_html( $options['subscription_section_btn_txt'] ) . '" subscribe_text="" show_subscribers_total="0"]';
                    echo do_shortcode( wp_kses_post( $subscription_shortcode ) );  ?>
                    <?php if( !empty( $options['subscription_section_description'] ) ): ?>
                    <p id="subscribe-check">
                        <label><?php echo  wp_kses_post($options['subscription_section_description']); ?></label>
                    </p>
                    <?php endif; ?>
               </div>
           </div><!-- .wrapper -->
       </div><!-- #subscribe-now-->
    <?php
    }
endif; ?>
