<?php
/**
 * Team section
 *
 * This is the template for the content of team section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_team_section' ) ) :
    /**
    * Add team section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_team_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if team is enabled on frontpage
        $team_enable = apply_filters( 'favblog_pro_section_status', true, 'team_section_enable' );

        if ( $options['home_layout'] == 'fourth-design' ) {
            $team_enable = false;
        }
        if ( true !== $team_enable ) {
            return false;
        }
        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_team_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render team section now.
        favblog_pro_render_team_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_team_section_details' ) ) :
    /**
    * team section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input team section details.
    */
    function favblog_pro_get_team_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $team_content_type  = get_theme_mod( 'favblog_pro_theme_options_team_content_type', $options['team_content_type'] );
        $team_count = get_theme_mod( 'favblog_pro_theme_options_team_count', $options['team_count'] );
 
        $content = array();
        switch ( $team_content_type ) {
        	
            case 'page':
                $page_ids = array();
                $position = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_page_' . $i] ) ) :
                        $page_ids[] = $options['team_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint($team_count),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $position = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_post_' . $i] ) ) :
                        $post_ids[] = $options['team_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint($team_count),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['team_content_category'] ) ? $options['team_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint($team_count),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'custom':
                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_title_' . $i] ) ) :
                        $custom['title']        = $options['team_title_' . $i];
                        $custom['image']        = ! empty( $options['team_image_' . $i] ) ? $options['team_image_' . $i] : '';
                        $custom['url']          = ! empty( $options['team_link_' . $i] ) ? $options['team_link_' . $i] : '';
                        $custom['position']     = ! empty( $options['team_position_' . $i] ) ? $options['team_position_' . $i] : '';
                        $custom['social']     = ! empty( $options['team_social_' . $i] ) ? $options['team_social_' . $i] : '';
                        
                        // Push to the main array.
                        array_push( $content, $custom );

                    endif;


                    
                }
            break;


            default:
            break;
        }

        if ( 'custom' !== $team_content_type ) {
            // Run The Loop.
            $query = new WP_Query( $args );
            $i = 1;
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['position']  = (! empty(  $options['team_position_' . $i] ) ) ?  $options['team_position_' . $i] : '';
                    $page_post['social']    = (! empty( $options['team_social_' . $i] ) ) ? $options['team_social_' . $i] : '';
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = favblog_pro_trim_content( 20 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// team section content details.
add_filter( 'favblog_pro_filter_team_section_details', 'favblog_pro_get_team_section_details' );


if ( ! function_exists( 'favblog_pro_render_team_section' ) ) :
  /**
   * Start team section
   *
   * @return string team content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_team_section( $content_details = array() ) {
        $options = favblog_pro_get_theme_options();
        $column = ! empty( $options['team_column'] ) ? $options['team_column'] : 'col-3';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        
            <div id="our-team" class="relative page-section same-background">
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                        <?php favblog_pro_section_tooltip( 'our-team' ); ?>
                    <?php endif; ?>
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html( $options['team_sub_title'] ); ?></p>
                        <h2 class="section-title"><?php echo esc_html( $options['team_title'] ); ?></h2>
                        <span class="separator"></span>
                    </div><!-- .section-header -->

                    <div class="section-content <?php echo esc_attr( $column ); ?> clear">
                    <?php foreach ( $content_details as $content ) : ?>

                        <article>
                            <div class="team-item-wrapper">
                                <div class="featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] )?>" alt="team"></a>
                                </div><!-- .featured-image -->

                                <header class="entry-header">
                                    <p><?php echo esc_html( $content['position'] ); ?></p>
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] )?></p>
                                </div><!-- .entry-content -->

                                <?php 
                                if ( ! empty( $content['social'] ) ) : 
                                        $social = explode( '|', $content['social'] ); ?>
                                    <div class="social-icons">
                                        <ul>
                                            <?php foreach( $social as $social_link ) : ?>
                                                <li>
                                                    <a href="<?php echo esc_url( $social_link ); ?>">
                                                        <?php echo favblog_pro_return_social_icon( $social_link ); ?>
                                                    </a>
                                                </li>
                                            <?php endforeach; ?>
                                        </ul>
                                    </div>
                                <?php endif; ?>

                            </div><!-- team-item-wrapper -->
                        </article>
                    <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #our-team -->

    <?php }
endif;

function favblog_pro_team_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_team_section_subtitle_color'] ) ): ?>
            #our-team p.section-subtitle{
                color: <?php echo esc_attr( $options['style_team_section_subtitle_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_team_section_title_color'] ) ): ?>
            #our-team h2.section-title{
                color: <?php echo esc_attr( $options['style_team_section_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_team_position_color'] ) ): ?>
            #our-team .entry-header p{
                color: <?php echo esc_attr( $options['style_team_position_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_team_title_color'] ) ): ?>
            #our-team h2.entry-title a{
                color: <?php echo esc_attr( $options['style_team_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_team_title_hover_color'] ) ): ?>
            #our-team h2.entry-title a:hover{
                color: <?php echo esc_attr( $options['style_team_title_hover_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_team_description_color'] ) ): ?>
            #our-team .entry-content{
                color: <?php echo esc_attr( $options['style_team_description_color'] ); ?>;
           }
       <?php endif; ?>

    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_team_style' );    ?>