<?php
/**
 * Testimonial section
 *
 * This is the template for the content of Testimonial section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

if ( ! function_exists( 'favblog_pro_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_testimonial_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'favblog_pro_section_status', true, 'testimonial_section_enable' );

         if ( !in_array( $options['home_layout'], array( 'default-design', 'second-design', 'third-design', 'fifth-design', 'sixth-design', 'seventh-design' ) ) ) {
             $testimonial_enable = false;
        }

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_testimonial_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return ;
        }

        // Render testimonial section now.
        favblog_pro_render_testimonial_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input testimonial section details.
    */
    function favblog_pro_get_testimonial_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $testimonial_content_type  = get_theme_mod( 'favblog_pro_theme_options_testimonial_content_type', $options['testimonial_content_type'] );
        $testimonial_count = get_theme_mod( 'favblog_pro_theme_options_testimonial_count', $options['testimonial_count'] );
 
        $content = array();
        switch ( $testimonial_content_type ) {
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_page_' . $i] ) )
                        $page_ids[] = $options['testimonial_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_post_' . $i] ) )
                        $post_ids[] = $options['testimonial_content_post_' . $i];
                }

                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $testimonial_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );
            break;

            case 'category':
                $cat_id = ! empty( $options['testimonial_category'] ) ? $options['testimonial_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $testimonial_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );
            break;

            default:
            break;
        }
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) :
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['content']   = favblog_pro_trim_content(25);
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                $page_post['sub_title'] = isset($options['testimonial_post_sub_title_'.$i])?$options['testimonial_post_sub_title_'.$i] : '';
                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'favblog_pro_filter_testimonial_section_details', 'favblog_pro_get_testimonial_section_details' );


if ( ! function_exists( 'favblog_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_testimonial_section( $content_details = array() ) {
    $options            = favblog_pro_get_theme_options();
    if ( empty( $content_details ) ) {
        return;
    } 
    $image   = empty( $options['testimonial_image'] ) ? '' : $options['testimonial_image'] ;
    ?>

        <div id="testimonial-section" class="relative page-section" style="background-image: url('<?php echo esc_url($image); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                    <?php favblog_pro_section_tooltip( 'testimonial-section' ); ?>
                <?php endif; ?>
                <div class="testimonial-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": false, "draggable": true, "fade": false }'>
                    <?php foreach ($content_details as $i=>$content): ?>
                    <article>
                        <div class="testimonial-item">
                            <div class="featured-image">
                                <a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url($content['image']); ?>" alt="testimonial-01"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                    <span class="testimonial-position"><?php echo esc_html($content['sub_title']); ?></span>
                                </header>

                                <span class="separator"></span>

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post($content['content']);?></p>
                                </div><!-- .entry-content -->
                            </div><!-- .entry-container -->
                        </div><!-- .testimonial-item -->
                    </article>
                    <?php endforeach;?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #testimonial-section -->
    <?php
    }
endif;

function favblog_pro_testimonial_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_testimonial_title_color'] ) ): ?>
            #testimonial-section h2.entry-title a{
                color: <?php echo esc_attr( $options['style_testimonial_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_testimonial_subtitle_color'] ) ): ?>
            #testimonial-section span.testimonial-position{
                color: <?php echo esc_attr( $options['style_testimonial_subtitle_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_testimonial_description_color'] ) ): ?>
            #testimonial-section .entry-content{
                color: <?php echo esc_attr( $options['style_testimonial_description_color'] ); ?>;
           }
       <?php endif; ?>

    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_testimonial_style' );    ?>