<?php
/**
 * Top Read section
 *
 * This is the template for the content of top_read section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_top_read_section' ) ) :
    /**
    * Add top_read section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_top_read_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if top_read is enabled on frontpage
        $top_read_enable = apply_filters( 'favblog_pro_section_status', true, 'top_read_section_enable' );

        if (!in_array($options['home_layout'], array('default-design', 'pro-design'))) {
            $top_read_enable = false;
        }
        if ( true !== $top_read_enable ) {
            return false;
        }

        // Get top_read section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_top_read_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render top_read section now.
        favblog_pro_render_top_read_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_top_read_section_details' ) ) :
    /**
    * top_read section details.     
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input top_read section details.
    */
    function favblog_pro_get_top_read_section_details( $input ) {
        $options = favblog_pro_get_theme_options();

        // Content type.
        $top_read_content_type  = get_theme_mod( 'favblog_pro_theme_options_top_read_content_type', $options['top_read_content_type'] );
        $top_read_count = get_theme_mod( 'favblog_pro_theme_options_top_read_count', $options['top_read_count'] );
        
        $content = array();
        switch ( $top_read_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $top_read_count; $i++ ) {
                    if ( ! empty( $options['top_read_content_page_' . $i] ) )
                        $page_ids[] = $options['top_read_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $top_read_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $top_read_count; $i++ ) {
                    if ( ! empty( $options['top_read_content_post_' . $i] ) )
                        $post_ids[] = $options['top_read_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $top_read_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['top_read_content_category'] ) ? $options['top_read_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $top_read_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = favblog_pro_trim_content( 20 );
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// top_read section content details.
add_filter( 'favblog_pro_filter_top_read_section_details', 'favblog_pro_get_top_read_section_details' );


if ( ! function_exists( 'favblog_pro_render_top_read_section' ) ) :
  /**
   * Start top_read section
   *
   * @return string top_read content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_top_read_section( $content_details = array() ) {
        $options = favblog_pro_get_theme_options();
        $top_read_content_type  = $options['top_read_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="top-read-reviews" class="relative page-section same-background">
                <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                    <?php favblog_pro_section_tooltip( 'top-read-reviews' ); ?>
                <?php endif; ?>
                    <div class="section-header">
                        <?php if( !empty( $options['top_read_title'] || !empty($options['top_read_sub_title'])) ):
                            echo ($options['top_read_sub_title']) ? sprintf( '<p class="section-subtitle">%s</p>',  esc_html( $options['top_read_sub_title'] ) ) : ''; 
                            echo ($options['top_read_title']) ? sprintf( '<h2 class="section-title">%s</h2>',  esc_html( $options['top_read_title'] ) ) : ''; ?>
                        <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="section-content col-3 clear">
                    <?php foreach ( $content_details as $content ) : ?>

                        <article class="has-post-thumbnail">
                            <div class="top-read-wrapper">
                                <div class="featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="reviews"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-meta">
                                        <?php  favblog_pro_posted_on($content['id']); ?>
                                       
                                        <span class="reading-time"><?php echo favblog_pro_reading_time($content['id']); ?>
                                            <svg viewBox="0 0 443.294 443.294" class="icon icon-clock">
                                                <path d="m221.647 0c-122.214 0-221.647 99.433-221.647 221.647s99.433 221.647 221.647 221.647 221.647-99.433 221.647-221.647-99.433-221.647-221.647-221.647zm0 415.588c-106.941 0-193.941-87-193.941-193.941s87-193.941 193.941-193.941 193.941 87 193.941 193.941-87 193.941-193.941 193.941z"/>
                                                <path d="m235.5 83.118h-27.706v144.265l87.176 87.176 19.589-19.589-79.059-79.059z"/>
                                            </svg>
                                        </span>
                                    </div><!-- .entry-meta -->
                                </div><!-- .entry-container -->
                            </div><!-- .top-read-wrapper -->
                        </article>
                    <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #top-read-reviews -->
    <?php 
    }    
endif;

function favblog_pro_top_read_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_top_read_section_subtitle_color'] ) ): ?>
            #top-read-reviews p.section-subtitle{
                color: <?php echo esc_attr( $options['style_top_read_section_subtitle_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_top_read_section_title_color'] ) ): ?>
            #top-read-reviews h2.section-title{
                color: <?php echo esc_attr( $options['style_top_read_section_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_top_read_title_color'] ) ): ?>
            #top-read-reviews .entry-title a{
                color: <?php echo esc_attr( $options['style_top_read_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_top_read_title_hover_color'] ) ): ?>
            #top-read-reviews .entry-title a:hover,
            #top-read-reviews .posted-on a:hover{
                color: <?php echo esc_attr( $options['style_top_read_title_hover_color'] ); ?>;
           }
       <?php endif; ?>
       <?php if ( !empty( $options['style_top_read_description_color'] ) ): ?>
            #top-read-reviews .posted-on a,
            #top-read-reviews span.reading-time,
            #top-read-reviews span.reading-time svg{
                color: <?php echo esc_attr( $options['style_top_read_description_color'] ); ?>;
                fill: <?php echo esc_attr( $options['style_top_read_description_color'] ); ?>;
           }
       <?php endif; ?>
    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_top_read_style' );    