<?php
/**
 * trending_product section
 *
 * This is the template for the content of trending_product section
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */
if ( ! function_exists( 'favblog_pro_add_trending_product_section' ) ) :
    /**
    * Add trending_product section
    *
    *@since FavBlog Pro 1.0.0
    */
    function favblog_pro_add_trending_product_section() {
    	$options = favblog_pro_get_theme_options();
        // Check if trending_product is enabled on frontpage
        $trending_product_enable = apply_filters( 'favblog_pro_section_status', true, 'trending_product_section_enable' );

        if ( !in_array( $options['home_layout'], array('default-design', 'fourth-design') )  ) {
            $trending_product_enable = false;
        }
        if ( true !== $trending_product_enable ){
            return false;
        }
        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Get trending_product section details
        $section_details = array();
        $section_details = apply_filters( 'favblog_pro_filter_trending_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render trending_product section now.
        favblog_pro_render_trending_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'favblog_pro_get_trending_product_section_details' ) ) :
    /**
    * trending_product section details.
    *
    * @since FavBlog Pro 1.0.0
    * @param array $input trending_product section details.
    */
    function favblog_pro_get_trending_product_section_details( $input ) {
        $options = favblog_pro_get_theme_options();
        $content = array();
        $content[1] = array();
        $content[2] = array();
        $content[3] = array();

        for ($i=1; $i <= 3 ; $i++) { 
                // Content type.
            $trending_product_content_type  = get_theme_mod( 'favblog_pro_theme_options_trending_product_content_type_'.$i.'', $options['trending_product_content_type'] );
            $trending_product_count = get_theme_mod( 'favblog_pro_theme_options_trending_product_count', $options['trending_product_count'] );
         
            switch ( $trending_product_content_type ) {
                
                case 'recent_product':
                    $args = array(
                        'post_type'             => 'product',
                        'posts_per_page'        => absint($trending_product_count),
                        'ignore_sticky_posts'   => true,
                        );
                break;

                case 'product':
                    $products = array();

                    for ( $j = 1; $j <=  absint($trending_product_count); $j++ ){
                        if ( ! empty( $options['trending_product_content_product_' . $i.$j] ) ){
                            $products[] = $options['trending_product_content_product_' . $i.$j];
                        }
                        
                    }
                      
                    $args = array(
                        'post_type'         => 'product',
                        'post__in'          => ( array ) $products,
                        'posts_per_page'    => absint($trending_product_count),
                        'orderby'           => 'post__in',
                        );
                break;
                case 'product-category':
                    $product_cat_id = ! empty( $options['trending_product_content_product_category_'.$i] ) ? $options['trending_product_content_product_category_'.$i] : '';

                    $args = array(
                    'post_type'         => 'product',
                    'posts_per_page'    => absint( $trending_product_count ),
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'product_cat',
                            'field'     => 'id',
                            'terms'     => $product_cat_id
                        )
                    ) );
                break;

                default:
                break;
            }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = favblog_pro_trim_content( 30 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';

                    // Push to the main array.
                    array_push( $content[$i], $page_post );
               
                endwhile;
            endif;
            wp_reset_postdata();
        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// trending_product section content details.
add_filter( 'favblog_pro_filter_trending_product_section_details', 'favblog_pro_get_trending_product_section_details' );


if ( ! function_exists( 'favblog_pro_render_trending_product_section' ) ) :
  /**
   * Start trending_product section
   *
   * @return string trending_product content
   * @since FavBlog Pro 1.0.0
   *
   */
   function favblog_pro_render_trending_product_section( $content_details = array() ) {
        $options = favblog_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
  
       <div id="trending-products" class="relative page-section same-background">
            <div class="wrapper">
                <div class="section-content clear">
                    <?php for ( $i=1; $i <=3 ; $i++) { ?>
                        <div class="product-wrapper">
                            <h2 class="category-title"><?php echo esc_html( isset($options['trending_product_title_'.$i]) ? $options['trending_product_title_'.$i] : $options['trending_product_title'] ) ; ?></h2>
                            <div class="product-items">
                                <?php foreach ($content_details[$i] as $content): ?>
                                    <article>
                                        <div class="featured-image">
                                            <a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url(  $content['image'] );?>" title="<?php echo esc_attr($content['title']); ?>"></a>
                                        </div><!-- .featured-image -->

                                        <div class="entry-container">
                                            <span class="cat-links">
                                                <ul class="post-categories">
                                                     <?php 
                                                        $terms = get_the_terms ( $content['id'], 'product_cat' );
                                                        foreach ( $terms as $term ) { ?>
                                                            <li class="posted_in">
                                                                <a href="<?php echo esc_url( get_term_link( $term->term_id, 'product_cat' ) ) ?>"><?php echo esc_html( $term->name) ; ?></a>
                                                            </li><!-- .posted_in -->
                                                           
                                                    <?php } ?>
                                                </ul>
                                            </span><!-- .cat-links -->

                                            <header class="entry-header">
                                                <h2 class="entry-title">
                                                    <a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a>
                                                </h2>
                                            </header>

                                            <span class="price">
                                               <?php 
                                                    $product = new WC_Product( $content['id'] );
                                                    echo $product->get_price_html();
                                                ?>
                                            </span><!-- .price -->
                                        </div><!-- .entry-container -->
                                    </article>
                                <?php endforeach ?>
                            </div><!-- .product-items -->
                        </div><!-- .product-wrapper -->
                    <?php } ?>                    
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>
    <?php }
endif;


function favblog_pro_trending_product_style( ) {
    $options = favblog_pro_get_theme_options(); ?>

    <style type="text/css">
        <?php if ( !empty( $options['style_trending_product_column_title_color'] ) ): ?>
           #trending-products h2.category-title{
                color: <?php echo esc_attr( $options['style_trending_product_column_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_trending_product_cat_color'] ) ): ?>
            #trending-products span.cat-links a{
                color: <?php echo esc_attr( $options['style_trending_product_cat_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_trending_product_title_color'] ) ): ?>
            #trending-products .entry-title a{
                color: <?php echo esc_attr( $options['style_trending_product_title_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_trending_product_title_hover_color'] ) ): ?>
            #trending-products .entry-title a:hover{
                color: <?php echo esc_attr( $options['style_trending_product_title_hover_color'] ); ?>;
           }
       <?php endif; ?>
        <?php if ( !empty( $options['style_trending_product_price_color'] ) ): ?>
            #trending-products .price{
                color: <?php echo esc_attr( $options['style_trending_product_price_color'] ); ?>;
           }
       <?php endif; ?>
    </style>
<?php
}
add_action( 'wp_head', 'favblog_pro_trending_product_style' );    