<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage FavBlog Pro
 * @since FavBlog Pro 1.0.0
 */

$options = favblog_pro_get_theme_options();  


if ( ! function_exists( 'favblog_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since FavBlog Pro 1.0.0
	 */
	function favblog_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;
add_action( 'favblog_pro_doctype', 'favblog_pro_doctype', 10 );


if ( ! function_exists( 'favblog_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since FavBlog Pro 1.0.0
	 *
	 */
	function favblog_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1>
		<link rel="profile" href="https://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'favblog_pro_before_wp_head', 'favblog_pro_head', 10 );

if ( ! function_exists( 'favblog_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since FavBlog Pro 1.0.0
	 *
	 */
	function favblog_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'favblog-pro' ); ?></a>

		<?php
	}
endif;
add_action( 'favblog_pro_page_start_action', 'favblog_pro_page_start', 10 );

if ( ! function_exists( 'favblog_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since FavBlog Pro 1.0.0
	 *
	 */
	function favblog_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'favblog_pro_page_end_action', 'favblog_pro_page_end', 10 );

if ( ! function_exists( 'favblog_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since FavBlog Pro 1.0.0
	 *
	 */
	function favblog_pro_site_branding() {
		$options  = favblog_pro_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];
		?>
		<div class="menu-overlay"></div>
		<?php if($options['topbar_section_enable']) : ?>
			<div id="top-navigation" class="relative">
				<div class="wrapper">
				<nav id="secondary-navigation" class="main-navigation" role="navigation" aria-label="Secondary Menu">
					<?php 
					if(has_nav_menu( 'secondary' ) && $options['secondary_menu_enable']) : ?>
						<button class="menu-toggle" aria-controls="secondary-menu" aria-expanded="false" title="Secondary Menu">
							<span class="menu-label">Top</span> 
							<?php
							echo favblog_pro_get_svg( array( 'icon' => 'menu', 'class' => 'icon-menu' ) );
							echo favblog_pro_get_svg( array( 'icon' => 'close', 'class' => 'icon-menu' ) );
							?>
						</button>
						<?php  
							wp_nav_menu(  array(
								'theme_location' => 'secondary',
								'menu_class' => 'menu nav-menu',
								'container'=> 'div',
								'menu_id'	=>'secondary-menu',
								'echo' => true,
								'fallback_cb' => false,
							) );
					endif; 

					if($options['social_menu_enable'] && has_nav_menu( 'social' )):
				
						wp_nav_menu(  array(
							'theme_location' => 'social',
							'container' => 'div',
							'container_class' => 'social-icons',
							'echo' => true,
							'depth' => 1,
							'link_before' => '<span class="screen-reader-text">',
							'link_after' => '</span>',
							'fallback_cb' => false,
						) );
						
					endif; ?>
					
					</div><!-- .col-2 -->
				</div><!-- .wrapper -->
			</div><!-- .top-navigation -->
			<?php endif; ?>
		 <header id="masthead" class="site-header" role="banner">
			
            <div class="wrapper">
                <div class="site-branding">
					<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) ) && has_custom_logo( )  ) { ?>
						<div class="site-logo">
							<?php the_custom_logo(); ?>
						</div>
					<?php } 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' )  ) ) : ?>
						<div id="site-identity">
							<?php
							if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
								if ( favblog_pro_is_latest_posts() ) : ?>
									<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
								<?php else : ?>
									<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
								<?php
								endif;
							} 
							if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
								$description = get_bloginfo( 'description', 'display' );
								if ( $description || is_customize_preview() ) : ?>
									<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
								<?php
								endif; 
							}?>
						</div>
					<?php endif; ?>
				</div><!-- .site-branding -->

				<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="Primary Menu">
					<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false" title="Primary Menu">
					<span class="menu-label"><?php echo __('Menu', 'favblog-pro');?></span>
						<?php
						echo favblog_pro_get_svg( array( 'icon' => 'menu', 'class' => 'icon-menu' ) );
						echo favblog_pro_get_svg( array( 'icon' => 'close', 'class' => 'icon-menu' ) );
						?>			
					</button>
					<?php  
						$search_html= null;
						if($options['search_icon_in_primary_menu_enable']){
							$search_html = '<li class="search-menu">
								<a href="#" title="Search">' . 
									favblog_pro_get_svg( array( 'icon' => 'search' ) ) .
									favblog_pro_get_svg( array( 'icon' => 'close' ) ) .
								'</a>
								<div id="search">' .
									get_search_form( $echo = false ) .
								'</div><!-- #search -->
							</li>';
						}else{
							$search_html = '';
						}
						wp_nav_menu( array(
							'theme_location' => 'primary',
							'container' => 'div',
							'menu_class' => 'menu nav-menu',
							'menu_id' => 'primary-menu',
							'echo' => true,
							'fallback_cb' => 'favblog_pro_menu_fallback_cb',
							'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s'.$search_html.'</ul>',
						) );
					?>
				</nav><!-- #site-navigation -->
				<span class="double-border-line"></span>
            </div><!-- .wrapper -->
		</header><!-- .header-->
		<?php
	}
endif;
add_action( 'favblog_pro_header_action', 'favblog_pro_site_branding', 10 );

if ( ! function_exists( 'favblog_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since FavBlog Pro 1.0.0
	 *
	 */
	function favblog_pro_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'favblog_pro_content_start_action', 'favblog_pro_content_start', 10 );

if ( ! function_exists( 'favblog_pro_header_image' ) ) :
    /**
     * Header Image codes
     *
     * @since FavBlog Pro 1.0.0
     *
     */
    function favblog_pro_header_image() {
        if ( favblog_pro_is_frontpage() )
            return;
        $header_image = get_header_image();
        if ( is_singular() ) :
            $header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
        endif;
        ?>

        <div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <?php favblog_pro_custom_header_banner_title(); ?>
                </header>
                <?php favblog_pro_add_breadcrumb(); ?>
            </div>
        </div><!-- #page-site-header -->

        <?php
    }
endif;
add_action( 'favblog_pro_header_image_action', 'favblog_pro_header_image', 10 );

if ( ! function_exists( 'favblog_pro_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since FavBlog Pro 1.0.0
	 */
	function favblog_pro_add_breadcrumb() {
		$options = favblog_pro_get_theme_options();

		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( favblog_pro_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * favblog_pro_simple_breadcrumb hook
				 *
				 * @hooked favblog_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'favblog_pro_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
	}
endif;

if ( ! function_exists( 'favblog_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since FavBlog Pro 1.0.0
	 *
	 */
	function favblog_pro_content_end() {
		?>
        </div><!-- #content -->
		<?php
	}
endif;
add_action( 'favblog_pro_content_end_action', 'favblog_pro_content_end', 10 );

if ( ! function_exists( 'favblog_pro_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since FavBlog Pro 1.0.0
	 *
	 */
	function favblog_pro_footer_start() {
		$options = favblog_pro_get_theme_options(); ?>

		<footer id="colophon" class="site-footer" role="contentinfo">
			<?php if($options['footer_logo_and_social_menu_enable']) : ?>
				<div class="footer-logo-wrapper wrapper">
					<?php if( has_custom_logo( ) ) : ?>
						<div class="footer-logo"><?php the_custom_logo(); ?></div>
					<?php endif;	
									
					if(has_nav_menu( 'social' ) && $options['footer_logo_and_social_menu_enable']):
					
						wp_nav_menu(  array(
							'theme_location' => 'social',
							'container' => 'ul',
							'menu_class' => 'social-icons',
							'echo' => true,
							'depth' => 1,
							'link_before' => '<span class="screen-reader-text">',
							'link_after' => '</span>',
							'fallback_cb' => false,
						) );
						
					endif; ?>
				</div><!-- .footer-logo-wrapper -->
		<?php
			 endif;
	}
endif;
add_action( 'favblog_pro_footer', 'favblog_pro_footer_start', 10 );

if ( ! function_exists( 'favblog_pro_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since FavBlog Pro 1.0.0
	 *
	 */
	function favblog_pro_footer_site_info() {
		$options = favblog_pro_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text'];
		?>
		<span class="double-border-line"></span>
		<div class="site-info">
                <div class="wrapper">
                    <span>
                    <?php 
	                	echo favblog_pro_santize_allow_tag( $copyright_text ); 
	                	if ( function_exists( 'the_privacy_policy_link' ) ) {
							the_privacy_policy_link( ' | ' );
						}
                	?>
                	</span>
                </div><!-- .wrapper -->    
            </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'favblog_pro_footer', 'favblog_pro_footer_site_info', 40 );

if ( ! function_exists( 'favblog_pro_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since FavBlog Pro 1.0.0
	 *
	 */
	function favblog_pro_footer_scroll_to_top() {
		$options  = favblog_pro_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo favblog_pro_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'favblog_pro_footer', 'favblog_pro_footer_scroll_to_top', 40 );

if ( ! function_exists( 'favblog_pro_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since FavBlog Pro 1.0.0
	 *
	 */
	function favblog_pro_footer_end() {
		?>
		</footer>
		<div class="popup-overlay"></div>
		<?php
	}
endif;
add_action( 'favblog_pro_footer', 'favblog_pro_footer_end', 100 );

if ( ! function_exists( 'favblog_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since FavBlog Pro 1.0.0
	 *
	 */
	function favblog_pro_loader() {
		$options = favblog_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
	            <div class="loader-container">
	            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
		                <div id="preloader">
		                    <span></span>
		                    <span></span>
		                    <span></span>
		                    <span></span>
		                    <span></span>
		                </div>
		            <?php else :
		            	echo favblog_pro_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
		            endif; ?>
	            </div>
	        </div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'favblog_pro_before_header', 'favblog_pro_loader', 10 );


if ( ! function_exists( 'favblog_pro_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since FavBlog Pro 1.0.0
	 *
	 */
	function favblog_pro_infinite_loader_spinner() { 
		global $post;
		$options = favblog_pro_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :			
			echo '<div class="blog-loader">' . favblog_pro_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';			
		endif;
	}
endif;
add_action( 'favblog_pro_infinite_loader_spinner_action', 'favblog_pro_infinite_loader_spinner', 10 );
